@@ -64,7 +64,7 @@ NABCExport::NABCExport() {
 	chordDiagramList_.setAutoDelete(true);
 }
 
-void NABCExport::exportStaffs(QString fname, QList<NStaff> *stafflist, int count_of_voices, exportFrm *expWin, NMainFrameWidget *mainWidget) {
+void NABCExport::exportStaffs(QString fname, QPtrList<NStaff> *stafflist, int count_of_voices, exportFrm *expWin, NMainFrameWidget *mainWidget) {
 	NStaff *staff_elem;
 	NVoice *voice_elem;
 	NClef *firstClef;
@@ -73,14 +73,12 @@ void NABCExport::exportStaffs(QString fname, QList<NStaff> *stafflist, int count
 	int voice_count;
 	int current_time;
 	bool something_written;
-	bool ok;
 	bool with_pedal_marks, with_drums;
 	bool voice_with_pedal, voice_with_drum;
 	bool gridsused, firstcall, dummy;
 	chordDiagramName *diagNam;
 	double dval;
 	NMusElement *last_elem;
-	QRegExp reg = QRegExp("/100");
 	QString s;
 
 	out_.open(fname);
@@ -108,32 +106,28 @@ void NABCExport::exportStaffs(QString fname, QList<NStaff> *stafflist, int count
 	out_ << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << endl;
 	out_ << "%                                  %" << endl;
 	out_ << "%   ABC music output generated by  %" << endl;
-	out_ << "%           \"noteedit\"             %" << endl;
+	out_ << "%           \"NoteEdit\"             %" << endl;
 	out_ << "%                                  %" << endl;
 	out_ << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << endl << endl;
 	out_ << "% PAGE LAYOUT" << endl;
 	out_ << '%' << endl;
-	dval =  expWin->ABCWidth->text().toDouble(&ok);
-	if (!ok) dval = 17.0; else dval /= 10.0;
+	// Read options
+	expWin->getABCOptions( abcOpts_ );
+	dval =  abcOpts_.width / 10.0;
 	out_ << "%%pagewidth\t" << dval << "cm" << endl;
-	dval =  expWin->ABCHeight->text().toDouble(&ok);
-	if (!ok) dval = 25.0; else dval /= 10.0;
+	dval =  abcOpts_.height / 10.0;
 	out_ << "%%pageheight\t" << dval << "cm" << endl;
-	s = expWin->ABCscale->text();
-	s.replace (reg, "");
-	dval =  s.toDouble(&ok);
-	if (!ok) dval = 0.75; else dval /= 100.0;
+	dval =  abcOpts_.scale / 100.0;
 	out_ << "%%scale\t\t" << dval << endl;
-	dval =  expWin->ABCStaffSep->text().toDouble(&ok);
-	if (!ok) dval = 1.6; else dval /= 10.0;
+	dval =  abcOpts_.staffSep / 10.0;
 	out_ << "%%staffsep\t" << dval << "cm" << endl;
-	if (expWin->ABCExprAbove->isChecked()) {
+	if (abcOpts_.exprAbove) {
 		out_ << "%%exprabove\ttrue" << endl;
 	}
 	else {
 		out_ << "%%exprabove\tfalse" << endl;
 	}
-	if (expWin->ABCMeasNumInBox->isChecked()) {
+	if (abcOpts_.measNumInBox) {
 		out_ << "%%measurebox\ttrue" << endl;
 	}
 	else {
@@ -183,19 +177,44 @@ void NABCExport::exportStaffs(QString fname, QList<NStaff> *stafflist, int count
 
 	out_ << "X: 1" << endl;
 	if (!mainWidget->scTitle_.isEmpty()) {
-		out_ << "T: " << mainWidget->scTitle_ << endl;
+		out_ << "T: ";
+		if (abcOpts_.useUtf8Encoding)
+			out_ << mainWidget->scTitle_.utf8();
+		else
+			out_ << mainWidget->scTitle_.latin1();
+		out_ << endl;
 	}
 	if (!mainWidget->scSubtitle_.isEmpty()) {
-		out_ << "T: " << mainWidget->scSubtitle_ << endl;
+		out_ << "T: ";
+		if (abcOpts_.useUtf8Encoding)
+			out_ << mainWidget->scSubtitle_.utf8();
+		else
+			out_ << mainWidget->scSubtitle_.latin1();
+		out_ << endl;
 	}
 	if (!mainWidget->scAuthor_.isEmpty()) {
-		out_ << "C: " << mainWidget->scAuthor_<< endl;
+		out_ << "C: ";
+		if (abcOpts_.useUtf8Encoding)
+			out_ << mainWidget->scAuthor_.utf8();
+		else
+			out_ << mainWidget->scAuthor_.latin1();
+		out_ << endl;
 	}
 	if (!mainWidget->scLastAuthor_.isEmpty()) {
-		out_ << "C: " << mainWidget->scLastAuthor_ << endl;
+		out_ << "C: ";
+		if (abcOpts_.useUtf8Encoding)
+			out_ << mainWidget->scLastAuthor_.utf8();
+		else
+			out_ << mainWidget->scLastAuthor_.latin1();
+		out_ << endl;
 	}
 	if (!mainWidget->scCopyright_.isEmpty()) {
-		out_ << "C: copyright: " << mainWidget->scCopyright_ << endl;
+		out_ << "C: copyright: ";
+		if (abcOpts_.useUtf8Encoding)
+			out_ << mainWidget->scCopyright_.utf8();
+		else
+			out_ << mainWidget->scCopyright_.latin1();
+		out_ << endl;
 	}
 	outputMeter(stafflist->first()->getVoiceNr(0)->getFirstTimeSig(), true);
 	out_ << "L: 1/4 % default length" << endl;
@@ -272,8 +291,7 @@ void NABCExport::exportStaffs(QString fname, QList<NStaff> *stafflist, int count
 	if (!badlist_.isEmpty()) {
 		QString output;
 		output = i18n
-			("Noteedit has exported the score to ABC music but there are some\n"
-			 "problems which will probably prevent successful PostScript output.\n");
+			("NoteEdit has exported the score to ABC music format but there are some problems which can prevent successful PostScript/PDF output or can change the final score layout.\n");
 		output += i18n("-----------------------------------------------------\n");
 		for (bad = badlist_.first(); bad; bad = badlist_.next()) {
 			switch (bad->type_) {
@@ -351,17 +369,17 @@ bool NABCExport::writeFirstVoice(NVoice *voice_elem, QString staffName, int staf
 		switch (elem->getType()) {
 			case T_CHORD: voiceStatList_[idx].lastBarSym = 0;
 				      chord = (NChord *) elem;
-				      if (chord->status_ & STAT_TUPLET) {
+				      if (chord->hasProperty( PROP_TUPLET ) ) {
 				      	if (!inTuplet) {
 						inTuplet = true;
-						outputTupletStart(staff_nr, elem);
+						outputTupletStart(staff_nr, elem->playable() );
 					}
 				      }
-				      if (inGrace && !(chord->status_ & STAT_GRACE)) {
+				      if (inGrace && !(chord->hasProperty( PROP_GRACE ))) {
 				      	inGrace = false;
 					out_ << '}';
 				      }
-				      if (chord->status_ & STAT_GRACE) {
+				      if (chord->hasProperty( PROP_GRACE )) {
 				      	if (!inGrace) {
 						inGrace = true;
 						out_ << " {";
@@ -371,7 +389,7 @@ bool NABCExport::writeFirstVoice(NVoice *voice_elem, QString staffName, int staf
 					}
 				      }
 				      if (!inTuplet && chord->getSubType() < QUARTER_LENGTH) {
-				      	if (chord->status_ & STAT_BEAMED) {
+				      	if (chord->hasProperty( PROP_BEAMED ) ) {
 						if (!inBeam) {
 							if (!inGrace) out_ << ' ';
 							inBeam = true;
@@ -397,31 +415,35 @@ bool NABCExport::writeFirstVoice(NVoice *voice_elem, QString staffName, int staf
 						(*lyricsLine_[i]) << " * ";
 					}
 					if (lyrics) {
-						(*lyricsLine_[i]) << lyrics2ABC(lyrics) << ' ';
+						if (abcOpts_.useUtf8Encoding)
+							(*lyricsLine_[i]) << lyrics2ABC(lyrics).utf8();
+						else
+							(*lyricsLine_[i]) << lyrics2ABC(lyrics).latin1();
+						(*lyricsLine_[i]) << ' ';
 					}
-				      }
-				      if ((diag = chord->getChordChordDiagram()) != 0) {
+			      }
+			      if ((diag = chord->getChordChordDiagram()) != 0) {
 					writeChord(diag);
 				      }
 				      writePendingSigns(idx);
-				      if (chord->status_ & STAT_STACC)
+				      if (chord->hasProperty( PROP_STACC ) )
 						out_ << '.';
-				      if (chord->status_ & STAT_SFORZ) 
+				      if (chord->hasProperty( PROP_SFORZ ) )
 					        out_ << "!sfz!";
-				      if (chord->status_ & STAT_PORTA)
+				      if (chord->hasProperty( PROP_PORTA ) )
 					        out_ << "!tenuto!";
-				      if (chord->status_ & STAT_STPIZ)
+				      if (chord->hasProperty( PROP_STPIZ ) )
 					        out_ << "!wedge!";
-				      if (chord->status_ & STAT_SFZND)
+				      if (chord->hasProperty( PROP_SFZND ) )
 					        out_ << "!accent!";
-				      if (chord->status2_ & STAT2_PEDAL_ON) {
+				      if (chord->hasProperty( PROP_PEDAL_ON ) ) {
 				      		out_ << "!ped!";
 				      }
-				      if (chord->status2_ & STAT2_PEDAL_OFF) {
+				      if (chord->hasProperty( PROP_PEDAL_OFF ) ) {
 				      		out_ << "!ped-end!";
 				      }
-				      if (chord->status_ & STAT_FERMT) {
-				      		if (chord->status_ & STAT_STEM_UP) {
+				      if (chord->hasProperty( PROP_FERMT ) ) {
+				      		if (chord->hasProperty( PROP_STEM_UP ) ) {
 							out_ << "!fermata!";
 						}
 						else {
@@ -454,7 +476,7 @@ bool NABCExport::writeFirstVoice(NVoice *voice_elem, QString staffName, int staf
 					voiceStatList_[idx].dynEndPos = chord->getDynamicEnd();
 					voiceStatList_[idx].lastDynSym = (char *) (chord->dynamicAlign_ ? "!crescendo)!" : "!diminuendo)!");
 				      }
-				      if (elem->status_ & STAT_ARPEGG) {
+				      if (chord->hasProperty( PROP_ARPEGG ) ) {
 				      	out_ << "!arpeggio!";
 				      }
 				      inChord = chord->getNoteList()->count() > 1;
@@ -463,10 +485,10 @@ bool NABCExport::writeFirstVoice(NVoice *voice_elem, QString staffName, int staf
 				      }
 				      for (note = chord->getNoteList()->first(); note; note = chord->getNoteList()->next()) {
 				     	outputNote(note, &(actual_staff->actualClef_), inChord);
-					if (!((chord->status_ & STAT_GRACE) && chord->getSubType() == INTERNAL_MARKER_OF_STROKEN_GRACE)) {
-						outputLength(chord->getSubType(), chord->status_, inChord, note->status & BODY_MASK);
+					if (!(chord->hasProperty( PROP_GRACE ) && chord->getSubType() == INTERNAL_MARKER_OF_STROKEN_GRACE)) {
+						outputLength(chord->getSubType(), chord->properties(), inChord, note->properties & BODY_MASK);
 					}
-					if (note->status & STAT_TIED) out_ << '-';
+					if (note->properties & PROP_TIED) out_ << '-';
 				      }
 				      if (inChord) {
 				      	out_ << ']';
@@ -475,17 +497,17 @@ bool NABCExport::writeFirstVoice(NVoice *voice_elem, QString staffName, int staf
 				      	out_ << ')';
 					voiceStatList_[idx].slurDepth--;
 				      }
-				      if (chord->status_ & STAT_LAST_TUPLET) {
+				      if (chord->hasProperty( PROP_LAST_TUPLET ) ) {
 				        inTuplet = false;
 					out_ << ' ';
 				      }
 				      break;
 			case T_REST: voiceStatList_[idx].lastBarSym = 0;
 				     rest = (NRest *) elem;
-				     if (rest->status_ & STAT_TUPLET) {
+				     if (rest->hasProperty( PROP_TUPLET ) ) {
 				     	if (!inTuplet) {
 						inTuplet = true;
-						outputTupletStart(staff_nr, elem);
+						outputTupletStart(staff_nr, elem->playable());
 					}
 				     }
 				     inBeam =false;
@@ -499,14 +521,14 @@ bool NABCExport::writeFirstVoice(NVoice *voice_elem, QString staffName, int staf
 					writeChord(diag);
 				     }
 				     writePendingSigns(idx);
-				     if (rest->status_ & STAT_FERMT) {
+				     if (rest->hasProperty( PROP_FERMT ) ) {
 					out_ << "!fermata!";
 				     }
 				     if (rest->getSubType() == MULTIREST) {
 				     	out_ << 'Z';
 					len = rest->getMultiRestLength() * QUARTER_LENGTH;
 				     }
-				     else if (rest->status_ & STAT_HIDDEN) {
+				     else if (rest->hasProperty( PROP_HIDDEN ) ) {
 				        out_ << 'x';
 					len = rest->getSubType();
 				     }
@@ -514,8 +536,8 @@ bool NABCExport::writeFirstVoice(NVoice *voice_elem, QString staffName, int staf
 				        out_ << 'z';
 					len = rest->getSubType();
 				     }
-				     outputLength(len, rest->status_, true, false);
-				     if (rest->status_ & STAT_LAST_TUPLET) {
+				     outputLength(len, rest->properties(), true, false);
+				     if (rest->hasProperty( PROP_LAST_TUPLET ) ) {
 				        inTuplet = false;
 					out_ << ' ';
 				     }
@@ -652,17 +674,17 @@ bool NABCExport::writeOtherVoicesTill(int staff_nr, int voice_nr, QString staffN
 		handleSpecialElements(actual_staff, elem);
 		switch (elem->getType()) {
 			case T_CHORD: chord = (NChord *) elem;
-				      if (chord->status_ & STAT_TUPLET) {
+				      if (chord->hasProperty( PROP_TUPLET ) ) {
 				      	if (!inTuplet) {
 						inTuplet = true;
-						outputTupletStart(staff_nr, elem);
+						outputTupletStart(staff_nr, elem->playable());
 					}
 				      }
-				      if (inGrace && !(chord->status_ & STAT_GRACE)) {
+				      if (inGrace && !(chord->hasProperty( PROP_GRACE ) ) ) {
 				      	inGrace = false;
 					out_ << '}';
 				      }
-				      if (chord->status_ & STAT_GRACE) {
+				      if (chord->hasProperty( PROP_GRACE ) ) {
 				      	if (!inGrace) {
 						inGrace = true;
 						out_ << '{';
@@ -672,7 +694,7 @@ bool NABCExport::writeOtherVoicesTill(int staff_nr, int voice_nr, QString staffN
 					}
 				      }
 				      if (!inTuplet && chord->getSubType() < QUARTER_LENGTH) {
-				      	if (chord->status_ & STAT_BEAMED) {
+				      	if (chord->hasProperty( PROP_BEAMED ) ) {
 						if (!inBeam) {
 							if (!inGrace) out_ << ' ';
 							inBeam = true;
@@ -692,25 +714,25 @@ bool NABCExport::writeOtherVoicesTill(int staff_nr, int voice_nr, QString staffN
 				      	out_ << '(';
 					voiceStatList_[idx].slurDepth++;
 				      }
-				      if (chord->status_ & STAT_STACC)
+				      if (chord->hasProperty( PROP_STACC ) )
 						out_ << '.';
-				      if (chord->status_ & STAT_SFORZ) 
+				      if (chord->hasProperty( PROP_SFORZ ) )
 					        out_ << "!sfz!";
-				      if (chord->status_ & STAT_PORTA)
+				      if (chord->hasProperty( PROP_PORTA ) )
 					        out_ << "!tenuto!";
-				      if (chord->status_ & STAT_STPIZ)
+				      if (chord->hasProperty( PROP_STPIZ ) )
 					        out_ << "!wedge!";
-				      if (chord->status_ & STAT_SFZND)
+				      if (chord->hasProperty( PROP_SFZND ) )
 					        out_ << "!accent!";
-				      if (chord->status_ & STAT_FERMT) {
-				      		if (chord->status_ & STAT_STEM_UP) {
+				      if (chord->hasProperty( PROP_FERMT ) ) {
+				      		if (chord->hasProperty( PROP_STEM_UP ) ) {
 							out_ << "!fermata!";
 						}
 						else {
 							out_ << "!invertedfermata!";
 						}
 				      }
-				      if (elem->status_ & STAT_ARPEGG) {
+				      if (chord->hasProperty( PROP_ARPEGG ) ) {
 				      	out_ << "!arpeggio!";
 				      }
 				      inChord = chord->getNoteList()->count() > 1;
@@ -721,10 +743,10 @@ bool NABCExport::writeOtherVoicesTill(int staff_nr, int voice_nr, QString staffN
 				      staff_elem->setCorrectClefAccordingTime(elem->midiTime_);
 				      for (note = chord->getNoteList()->first(); note; note = chord->getNoteList()->next()) {
 				     	outputNote(note, &(actual_staff->actualClef_), inChord);
-					if (!((chord->status_ & STAT_GRACE) && chord->getSubType() == INTERNAL_MARKER_OF_STROKEN_GRACE)) {
-						outputLength(chord->getSubType(), chord->status_, inChord, note->status & BODY_MASK);
+					if (!((chord->hasProperty( PROP_GRACE ) ) && chord->getSubType() == INTERNAL_MARKER_OF_STROKEN_GRACE)) {
+						outputLength(chord->getSubType(), chord->properties(), inChord, note->properties & BODY_MASK);
 					}
-					if (note->status & STAT_TIED) out_ << '-';
+					if (note->properties & PROP_TIED) out_ << '-';
 				      }
 				      if (inChord) {
 				      	out_ << ']';
@@ -733,16 +755,16 @@ bool NABCExport::writeOtherVoicesTill(int staff_nr, int voice_nr, QString staffN
 				      	out_ << ')';
 					voiceStatList_[idx].slurDepth--;
 				      }
-				      if (chord->status_ & STAT_LAST_TUPLET) {
+				      if (chord->hasProperty( PROP_LAST_TUPLET ) ) {
 				        inTuplet = false;
 					out_ << ' ';
 				      }
 				      break;
 			case T_REST: rest = (NRest *) elem;
-				     if (rest->status_ & STAT_TUPLET) {
+				     if (rest->hasProperty( PROP_TUPLET ) ) {
 				     	if (!inTuplet) {
 						inTuplet = true;
-						outputTupletStart(staff_nr, elem);
+						outputTupletStart(staff_nr, elem->playable());
 					}
 				     }
 				     inBeam =false;
@@ -751,14 +773,14 @@ bool NABCExport::writeOtherVoicesTill(int staff_nr, int voice_nr, QString staffN
 					out_ << '}';
 				     }
 				     if (!inTuplet) out_ << ' ';
-				     if (rest->status_ & STAT_FERMT) {
+				     if (rest->hasProperty( PROP_FERMT ) ) {
 					out_ << "!fermata!";
 				     }
 				     if (rest->getSubType() == MULTIREST) {
 				     	out_ << 'Z';
 					len = rest->getMultiRestLength() * QUARTER_LENGTH;
 				     }
-				     else if (rest->status_ & STAT_HIDDEN) {
+				     else if (rest->hasProperty( PROP_HIDDEN ) ) {
 				        out_ << 'x';
 					len = rest->getSubType();
 				     }
@@ -766,8 +788,8 @@ bool NABCExport::writeOtherVoicesTill(int staff_nr, int voice_nr, QString staffN
 				        out_ << 'z';
 					len = rest->getSubType();
 				     }
-				     outputLength(len, rest->status_, true, false);
-				     if (rest->status_ & STAT_LAST_TUPLET) {
+				     outputLength(len, rest->properties(), true, false);
+				     if (rest->hasProperty( PROP_LAST_TUPLET ) ) {
 				        inTuplet = false;
 					out_ << ' ';
 				     }
@@ -796,7 +818,7 @@ void NABCExport::handleSpecialElements(NStaff *staff_elem, NMusElement *elem) {
 	else {
 		xpos = (1 << 30);
 	}
-	while (specElem = staff_elem->checkSpecialElement(xpos, &volta)) {
+	while ((specElem = staff_elem->checkSpecialElement(xpos, &volta))>0) {
 		switch (specElem->getType()) {
 			case T_SIGN: ok = false;
 				     switch (specElem->getSubType()) {
@@ -836,7 +858,8 @@ void NABCExport::outputBarSym(NSign *sign, int volta, bool isLast) {
 void NABCExport::writePendingSigns(int idx) {
 	NSign *sign;
 
-	if (sign = voiceStatList_[idx].pendingVolumes) {
+	sign = voiceStatList_[idx].pendingVolumes;
+	if (sign > 0) {
 		voiceStatList_[idx].pendingVolumes = 0;
 		switch (sign->getVolType()) {
 			case V_PPPIANO : out_ << "!ppp!"; break;
@@ -848,14 +871,16 @@ void NABCExport::writePendingSigns(int idx) {
 			default        : out_ << "!mf!"; break;
 		}
 	}
-	if (sign = voiceStatList_[idx].pendingSegnos) {
+	sign = voiceStatList_[idx].pendingSegnos;
+	if (sign > 0) {
 		voiceStatList_[idx].pendingSegnos = 0;
 		switch(sign->getSubType()) {
 			case SEGNO     : out_ << "!segno! "; break;
 			case CODA      : out_ << "!coda! "; break;
 		}
 	}
-	if (sign = voiceStatList_[idx].pendingSegnos2) {
+	sign = voiceStatList_[idx].pendingSegnos2;
+	if (sign > 0) {
 		voiceStatList_[idx].pendingSegnos2 = 0;
 		switch(sign->getSubType()) {
 			case DAL_SEGNO : out_ << "!D.S.! "; break;
@@ -864,7 +889,8 @@ void NABCExport::writePendingSigns(int idx) {
 			case DAL_SEGNO_AL_CODA: out_ << "\"D.S. al coda\" "; break;
 		}
 	}
-	if (sign = voiceStatList_[idx].pendingRitAccel) {
+	sign = voiceStatList_[idx].pendingRitAccel;
+	if (sign > 0) {
 		voiceStatList_[idx].pendingRitAccel = 0;
 		switch(sign->getSubType()) {
 			case ACCELERANDO: out_ << "!acc! "; break;
@@ -885,28 +911,28 @@ void NABCExport::outputNote(NNote *note, NClef *actualClef, bool inInChord) {
 	char notename;
 	bool percussion = actualClef->getSubType() == DRUM_CLEF || actualClef->getSubType() == DRUM_BASS_CLEF;
 	bool prec_note = false;
-	switch (note->status & BODY_MASK) {
-		case STAT_BODY_CROSS:
+	switch (note->properties & BODY_MASK) {
+		case PROP_BODY_CROSS:
 			if (!inInChord) out_ << '[';
 			out_ << "!head-x!";
 			prec_note = true;
 			break;
-		case STAT_BODY_CROSS2:
+		case PROP_BODY_CROSS2:
 			if (!inInChord) out_ << '[';
 			out_ << "!head-cr!";
 			prec_note = true;
 			break;
-		case STAT_BODY_CIRCLE_CROSS:
+		case PROP_BODY_CIRCLE_CROSS:
 			if (!inInChord) out_ << '[';
 			out_ << "!head-ci!";
 			prec_note = true;
 			break;
-		case STAT_BODY_RECT:
+		case PROP_BODY_RECT:
 			if (!inInChord) out_ << '[';
 			out_ << "!head-re!";
 			prec_note = true;
 			break;
-		case STAT_BODY_TRIA:
+		case PROP_BODY_TRIA:
 			if (!inInChord) out_ << '[';
 			out_ << "!head-t!";
 			prec_note = true;
@@ -914,7 +940,7 @@ void NABCExport::outputNote(NNote *note, NClef *actualClef, bool inInChord) {
 	}
 	
 	
-	if (!prec_note && !percussion && (note->needed_acc || (note->status & STAT_FORCE))) {
+	if (!prec_note && !percussion && (note->needed_acc || (note->properties & PROP_FORCE))) {
 		switch(note->offs) {
 			case -2: out_ << "__"; break;
 			case -1: out_ << "_";  break;
@@ -943,13 +969,13 @@ void NABCExport::outputNote(NNote *note, NClef *actualClef, bool inInChord) {
 	for (; octave < 1; octave++) out_ << ',';
 }
 
-void NABCExport::outputLength(int len, unsigned int status, bool inChord, bool drumNote) {
+void NABCExport::outputLength(int len, property_type properties, bool inChord, bool drumNote) {
 	unsigned int k;
-	if (len == QUARTER_LENGTH && !(status & (STAT_SINGLE_DOT | STAT_DOUBLE_DOT))) {
+	if (len == QUARTER_LENGTH && !(properties & (PROP_SINGLE_DOT | PROP_DOUBLE_DOT))) {
 		if (!inChord && drumNote) out_ << ']';
 		return;
 	}
-	if (status & STAT_GRACE) len <<= 1; // Dont' know ???
+	if (properties & PROP_GRACE) len <<= 1; // Dont' know ???
 	if (len > DOUBLE_WHOLE_LENGTH) {
 		out_ << (len / QUARTER_LENGTH);
 		if (!inChord && drumNote) out_ << ']';
@@ -957,30 +983,30 @@ void NABCExport::outputLength(int len, unsigned int status, bool inChord, bool d
 	}
 	switch (len) {
 		case DOUBLE_WHOLE_LENGTH: 
-			switch (status & DOT_MASK) {
-				case STAT_DOUBLE_DOT: out_ << "13"; break;
-				case STAT_SINGLE_DOT: out_ << "12"; break;
+			switch (properties & DOT_MASK) {
+				case PROP_DOUBLE_DOT: out_ << "13"; break;
+				case PROP_SINGLE_DOT: out_ << "12"; break;
 				default: out_ << "8"; break;
 			}
 			break;
 		case WHOLE_LENGTH:
-			switch (status & DOT_MASK) {
-				case STAT_DOUBLE_DOT: out_ << "7"; break;
-				case STAT_SINGLE_DOT: out_ << "6"; break;
+			switch (properties & DOT_MASK) {
+				case PROP_DOUBLE_DOT: out_ << "7"; break;
+				case PROP_SINGLE_DOT: out_ << "6"; break;
 				default: out_ << "4"; break;
 			}
 			break;
 		case HALF_LENGTH:
-			switch (status & DOT_MASK) {
-				case STAT_DOUBLE_DOT: out_ << "14/4"; break;
-				case STAT_SINGLE_DOT: out_ << "3"; break;
+			switch (properties & DOT_MASK) {
+				case PROP_DOUBLE_DOT: out_ << "14/4"; break;
+				case PROP_SINGLE_DOT: out_ << "3"; break;
 				default: out_ << "2"; break;
 			}
 			break;
 		default:
-			switch (status & DOT_MASK) {
-				case STAT_DOUBLE_DOT: out_ << "7/" << ((QUARTER_LENGTH / len) * 4); break;
-				case STAT_SINGLE_DOT: out_ << "3/" << ((QUARTER_LENGTH / len) * 2); break;
+			switch (properties & DOT_MASK) {
+				case PROP_DOUBLE_DOT: out_ << "7/" << ((QUARTER_LENGTH / len) * 4); break;
+				case PROP_SINGLE_DOT: out_ << "3/" << ((QUARTER_LENGTH / len) * 2); break;
 				default: //out_ << '/' << (QUARTER_LENGTH / len); break;
 					 for(k = (QUARTER_LENGTH / len) - 1; k; k >>= 1) {
 					 	out_ << '/';
@@ -992,7 +1018,7 @@ void NABCExport::outputLength(int len, unsigned int status, bool inChord, bool d
 	if (!inChord && drumNote) out_ << ']';
 }
 
-void NABCExport::outputTupletStart (int staff_nr, NMusElement *elem) {
+void NABCExport::outputTupletStart (int staff_nr, NPlayable *elem) {
 	badinfo *bad;
 	int real_note_count;
 	bool play_time_written = false;
@@ -1027,7 +1053,7 @@ void NABCExport::outputTupletStart (int staff_nr, NMusElement *elem) {
 }
 			
 
-void NABCExport::outputStaffAndVoiceDescription(QList<NStaff> *stafflist, NMainFrameWidget *mainWidget) {
+void NABCExport::outputStaffAndVoiceDescription(QPtrList<NStaff> *stafflist, NMainFrameWidget *mainWidget) {
 	NStaff *staff_elem;
 	NVoice *voice_elem;
 	int voice_count;
@@ -1151,7 +1177,12 @@ void NABCExport::outputVoiceParams(NVoice *voice, QString staffName) {
 		staffName.replace ('\n', "\\n"); /* replace all newlines with \n two character symbols */
 		staffName.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */	
 
-		out_ << "name=\"" << staffName << '"';
+		out_ << "name=\"";
+		if (abcOpts_.useUtf8Encoding)
+			out_ << staffName.utf8();
+		else
+			out_ << staffName.latin1();
+		out_ << '"';
 	}
 }
 
@@ -1176,21 +1207,21 @@ bool NABCExport::outputClefInfo(NClef *clef) {
 
 QString NABCExport::createVoiceName(QString staffName,  int staff_nr, int voice_nr) {
 	QString s, t;
-	QRegExp reg = QRegExp("[ \\.]");
-
+	QRegExp nonAlphas_("[^A-Za-z]");
 	if (staffName.isEmpty()) {
 		s = 'S';
 	}
 	else {
 		s = staffName;
 	}
+	s.replace(nonAlphas_, "X");	//replace blanks, dots, numbers, UTF-8 chars with X-es
 	t.sprintf("%d", staff_nr);
 	s += t;
 	if (voice_nr) {
 		t.sprintf("V%d", voice_nr);
 		s += t;
 	}
-	s.replace (reg, "_");
+
 	return s;
 }
 
@@ -1205,13 +1236,14 @@ void NABCExport::outputMeter(NTimeSig *timesig, bool inHeader) {
 }
 
 void NABCExport::outputKeySig(NKeySig *key, bool inHeader) {
-	int kind, count;
+	int count;
+	property_type kind;
 	badinfo *bad;
 	out_ << "K: ";
 
 	if (key->isRegular(&kind, &count)) {
 		switch(kind) {
-			case STAT_CROSS:
+			case PROP_CROSS:
 				switch (count) {
 					case 0: out_ << 'C'; break;
 					case 1: out_ << 'G'; break;
@@ -1224,7 +1256,7 @@ void NABCExport::outputKeySig(NKeySig *key, bool inHeader) {
 					default: NResource::abort("NABCExport::outputKeySig", 1);
 				}
 				break;
-			case STAT_FLAT:
+			case PROP_FLAT:
 				switch (count) {
 					case 0: out_ << 'C'; break;
 					case 1: out_ << 'F'; break;
@@ -1237,7 +1269,7 @@ void NABCExport::outputKeySig(NKeySig *key, bool inHeader) {
 					default: NResource::abort("NABCExport::outputKeySig", 2);
 				}
 				break;
-			case STAT_NO_ACC:
+			case PROP_NO_ACC:
 				out_ << "C";
 				break;
 			default: NResource::abort("NABCExport::outputKeySig", 3);
@@ -1251,7 +1283,7 @@ void NABCExport::outputKeySig(NKeySig *key, bool inHeader) {
 	if (inHeader) out_ << " % key signature" << endl;
 }
 
-void NABCExport::outputMidi(QList<NStaff> *stafflist) {
+void NABCExport::outputMidi(QPtrList<NStaff> *stafflist) {
 	NStaff *staff_elem;
 	NVoice *voice_elem;
 	int voice_count;
@@ -1273,7 +1305,6 @@ void NABCExport::outputMidi(QList<NStaff> *stafflist) {
 QString NABCExport::lyrics2ABC(QString *lyrics) {
 	QString ret;
 	QRegExp reg;
-
 	
 	ret = QString(*lyrics);
 
@@ -1291,20 +1322,21 @@ QString NABCExport::lyrics2ABC(QString *lyrics) {
 		ret = '*';
 		return ret;
 	}
-	reg = QRegExp("");
+	
+/*	reg = QRegExp("ä");
 	ret.replace (reg, "\\\"a");
-	reg = QRegExp("");
+	reg = QRegExp("ö");
 	ret.replace (reg, "\\\"o");
-	reg = QRegExp("");
+	reg = QRegExp("ü");
 	ret.replace (reg, "\\\"u");
-	reg = QRegExp("");
+	reg = QRegExp("Ä");
 	ret.replace (reg, "\\\"A");
-	reg = QRegExp("");
+	reg = QRegExp("Ö");
 	ret.replace (reg, "\\\"O");
-	reg = QRegExp("");
+	reg = QRegExp("Ü");
 	ret.replace (reg, "\\\"U");
-	reg = QRegExp("");
-	ret.replace (reg, "\\ss");
+	reg = QRegExp("ß");
+	ret.replace (reg, "\\ss"); */ //leave in utf8 encoding, we'll call latin1() then for convertable characters
 	reg = QRegExp("_");
 	ret.replace (reg, "\\_");
 	return ret;
