@@ -24,9 +24,11 @@
 
 #define ABCEXPORT_H
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
+#ifndef WITH_SCONS
 #include "config.h"
+#endif
 #if GCC_MAJ_VERS > 2
 #include <sstream>
 #include <fstream>
@@ -44,24 +46,34 @@ class NClef;
 class NText;
 class chordDiagramName;
 
+struct abc_options
+{
+  double  width;
+  double  height;
+  double  scale;
+  double  staffSep;
+  bool    exprAbove;
+  bool    measNumInBox;
+  bool    useUtf8Encoding;
+};
 
 class NABCExport  {
 	public:
 		NABCExport();
-		void exportStaffs(QString fname, QList<NStaff> *stafflist, int count_of_voices, exportFrm *expWin, NMainFrameWidget *mainWidget);
+		void exportStaffs(QString fname, QPtrList<NStaff> *stafflist, int count_of_voices, exportFrm *expWin, NMainFrameWidget *mainWidget);
 	private:
 		bool writeFirstVoice(NVoice *voice_elem, QString staffName, int staff_nr, int voice_count, int measure_count, bool lastStaff);
 		bool writeOtherVoicesTill(int staff_nr, int voice_nr, QString staffName, NVoice *voice_elem, NStaff *staff_elem, int stopTime);
 		void outputNote(NNote *note, NClef *actualClef, bool inInChord);
-		void outputLength(int len, unsigned int status, bool inChord, bool drumNote);
+		void outputLength(int len, property_type status, bool inChord, bool drumNote);
 		void outputKeySig(NKeySig *key, bool inHeader);
-		void outputMidi(QList<NStaff> *stafflist);
-		void outputStaffAndVoiceDescription(QList<NStaff> *stafflist, NMainFrameWidget *mainWidget);
+		void outputMidi(QPtrList<NStaff> *stafflist);
+		void outputStaffAndVoiceDescription(QPtrList<NStaff> *stafflist, NMainFrameWidget *mainWidget);
 		void outputVoiceParams(NVoice *voice, QString staffName);
 		QString lyrics2ABC(QString *lyrics);
 		void outputMeter(NTimeSig *timesig, bool inHeader);
 		void outputBarSym(NSign *sign, int volta, bool isLast);
-		void outputTupletStart(int staff_nr, NMusElement *elem);
+		void outputTupletStart(int staff_nr, NPlayable *elem);
 		bool outputClefInfo(NClef *clef);
 		void outputPedalGlyphs();
 		void outputDrumDefinitions();
@@ -72,7 +84,7 @@ class NABCExport  {
 		void writePendingSigns(int idx);
 		void appendContextChangeList(NVoice *voice_elem);
 		NClef *lastClef_;
-		QList<chordDiagramName> chordDiagramList_;
+		QPtrList<chordDiagramName> chordDiagramList_;
 #if GCC_MAJ_VERS > 2
 		ostringstream *lyricsLine_[NUM_LYRICS];
 #else
@@ -81,6 +93,7 @@ class NABCExport  {
 		int *countOfLyricsLines_;
 		QString createVoiceName(QString staffName,  int staff_nr, int voice_nr);
 		ofstream out_;
+		struct abc_options abcOpts_;
 		class badinfo {
 			public:
 				badinfo(int type, int staffnr, int barnr) {
@@ -90,7 +103,7 @@ class NABCExport  {
 				}
 				int type_, staffnr_, barnr_;
 		};
-		QList<badinfo> badlist_;
+		QPtrList<badinfo> badlist_;
 		class voice_stat_str {
 			public:
 				voice_stat_str() {
