@@ -26,6 +26,7 @@
 
 #include <qpixmap.h>
 #include "muselement.h"
+#include "voice.h"
 
 #define NORMAL_TRILL 1
 #define LONELY_TRILL 2
@@ -42,24 +43,24 @@ struct trill_descr_str {
 	int trill_nr, endpos;
 };
 
-class NChord: public NMusElement {
+class NChord: public NPlayable {
 	public:
-		NChord(main_props_str *main_props, staff_props_str *staff_props, int line, int offs, int length, int voices_stem_policy, unsigned int status = 0, unsigned int status2 = 0);
+		NChord(main_props_str *main_props, staff_props_str *staff_props, NVoice *voice, int line, int offs, int length, int voices_stem_policy, property_type properties = 0 );
 		virtual ~NChord();
 		virtual NChord *clone();
 		virtual void changeLength(int length);
-		virtual void changeBody(unsigned int bodyType);
+		virtual void changeBody(property_type bodyType);
 		virtual void draw(int flags = 0);
 		virtual void moveUp(int up, int voices_stem_policy, NKeySig *key = 0);
 		virtual void moveDown(int up, int voices_stem_policy, NKeySig *key = 0);
 		virtual void moveSemiToneUp(int voices_stem_policy, NClef *clef, NKeySig *ksig = 0);
 		virtual void moveSemiToneDown(int voices_stem_policy, NClef *clef, NKeySig *ksig = 0);
-		virtual QList<NNote> *getNoteList() {return &noteList_;}
+		virtual QPtrList<NNote> *getNoteList() {return &noteList_;}
 		virtual int getSubType() const {return length_;}
 		virtual int getType() const {return T_CHORD;}
 		virtual bool deleteNoteAtLine(int line, int voices_stem_policy);
-		virtual NNote *searchLine(int line, int min);
-		virtual NNote *insertNewNote(int line, int offs, int voices_stem_policy, unsigned int status);
+		virtual NNote *searchLine(int line, unsigned int min);
+		virtual NNote *insertNewNote(int line, int offs, int voices_stem_policy, property_type properties);
 		virtual NChordDiagram *getChordChordDiagram() {return cdiagram_;}
 		void determineStemDir(int voices_stem_policy);
 		virtual void setDotted(int dotcount);
@@ -81,7 +82,7 @@ class NChord: public NMusElement {
 		NChord *getSlurPartner() { return slur_forward_;}
 		NChord *getSlurStart() { return slur_backward_;}
 		virtual void breakBeames();
-		virtual bool lastBeamed() {return ((status_ & STAT_BEAMED) && nextBeamedChord_ == 0);}
+		virtual bool lastBeamed() {return (hasProperty( PROP_BEAMED) && nextBeamedChord_ == 0);}
 		bool beamHasOnlyTwoChords();
 		void removeFromBeam();
 		bool setOctaviationStart(int size);
@@ -90,11 +91,10 @@ class NChord: public NMusElement {
 		virtual int getMidiLength(bool forPlayback = false) const;
 		virtual void calculateDimensionsAndPixmaps();
 		virtual void calculateFlagCount();
-		static void computeBeames(QList<NChord> *beamList, int stemPolicy);
+		static void computeBeames(QPtrList<NChord> *beamList, int stemPolicy);
 		bool setActualNote(int line);
 		bool equalTiedChord(NChord *chord2);
-		virtual void setBeamFlag() { status_ |= STAT_BEAMED; nextBeamedChord_ = (NChord *) 1;}
-		void resetBeamFlag() {status_ &= (~STAT_BEAMED); nextBeamedChord_ = 0; beamList_ = 0;}
+		virtual void setBeamFlag() { addProperty( PROP_BEAMED ); nextBeamedChord_ = (NChord *) 1;}
 		void computeBeames(int stemPolicy);
 		void setStemUp(bool stem_up);
 		int getGraceMidiStartTime() { return u1_.graceNoteStartTime_;}
@@ -119,28 +119,28 @@ class NChord: public NMusElement {
 		void setLyrics(QString *lyrics, int nr);
 		void deleteLyrics(int nr);
 		void computeStemBefore();
-		int countOfLyricsLines();
+		unsigned int countOfLyricsLines();
 		QString *getLyrics(int nr);
-		void setBeamParams(QList<NChord> *beamList, NChord *nextChord, double m, double n);
+		void setBeamParams(QPtrList<NChord> *beamList, NChord *nextChord, double m, double n);
 		void resetBeamFlags();
 		virtual int computeMidiLength() const;
-		QList<NChord> *getBeamList() { return beamList_;}
-		void changeBeamList(QList<NChord> *blist) {beamList_ = blist;}
+		QPtrList<NChord> *getBeamList() { return beamList_;}
+		void setBeamList(QPtrList<NChord> *beamList) {beamList_ = beamList;}
 		void checkAcc();
 		void accumulateAccidentals(NKeySig *key);
 		virtual char getNumNotes() {return numTupNotes_;}
 		virtual char getPlaytime() {return tupRealTime_;}
-		virtual void setTupletParams(QList<NMusElement> *tupletList, 
+		virtual void setTupletParams(QPtrList<NPlayable> *tupletList, 
 			bool last, double m , double n , double tuptexn, int xstart, int xend, char numnotes, char playtime);
 		QString *computeTeXBeam(int maxBeams, unsigned int *beamPool, int *beamNr, int *beamCount, NClef *clef, int maxflags, bool *problem128, bool *toomany);
 		QString *computeTeXTie(unsigned int *tiePool, NClef *clef, int maxtie, bool *toomany, bool spare);
 		QString *computeTeXSlur(unsigned int *slurPool, NClef *clef, int maxslur, bool *toomany);
 		QString *computeTeXTrill(int hline, unsigned int *trillPool, NClef *clef, struct trill_descr_str *trill_descr, 
                                         bool *nested, bool *toomany);
-		QString *computeTeXVa(bool bassa, int hline, unsigned int *vaPool, NClef *clef, struct trill_descr_str *trill_descr,
+		QString *computeTeXVa(int hline, unsigned int *vaPool, NClef *clef, struct trill_descr_str *trill_descr,
 			bool *nested, bool *toomany);
 		void initialize_acc_pos_computation();
-		QList<NNote> *getAccTexRow(int row_nr);
+		QPtrList<NNote> *getAccTexRow(int row_nr);
 		int getNumOfTexAccRows() {return numTexRows_;}
 		union {
 			short TeXSlurNr;
@@ -150,11 +150,18 @@ class NChord: public NMusElement {
 				double increase;
 			} dynamic_descr;
 		} auxInfo_;
+
+		int trill_;
+		int dynamic_;
+		int va_;
+		bool dynamicAlign_;
+
 	private:
-		static void computeLineParams(QList<NChord> *beamList, double *np, double *mp);
+		static void computeLineParams(QPtrList<NChord> *beamList, double *np, double *mp);
 		void drawGraceChord(int flags);
 		void calculateGraceChord();
 		int length_;
+		NVoice* voice_; /* voice, which this chord belongs to */
 		QPoint nbaseLinePoint1_;
 		QPoint nbaseLinePoint2_;
 		QPoint nbaseLinePoint3_;
@@ -162,9 +169,9 @@ class NChord: public NMusElement {
 		NChord *nextBeamedChord_;
 		int *lyricsdist_;
 		QPoint flag_pos_[5];
-		QList<NNote> noteList_;
+		QPtrList<NNote> noteList_;
 		double m_, n_;
-		QList<NChord> *beamList_;
+		QPtrList<NChord> *beamList_;
 		QPoint tuplet0_, tuplet1_;
 		QPoint tuplet00_, tuplet01_;
 		QPoint tupletDigit_;
@@ -191,7 +198,7 @@ class NChord: public NMusElement {
 		int narrow_left_, narrow_right_;
 		int trilly_, vaY_;
 		static int numTexRows_;
-		static QList<NNote> acc_tex_row;
+		static QPtrList<NNote> acc_tex_row;
 		static QPoint StrokeDist1_, StrokeDist2_;
 };
 
