@@ -24,7 +24,6 @@
 #include <qpixmap.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include "keysig.h"
 #include "clef.h"
 #include "resource.h"
 #include "transpainter.h"
@@ -298,7 +297,7 @@ int NClef::getOctave() {
 /* Returns the note pitch on the given note's vertical position. Arguments: int line - note position (0-bottom line, 1-first space, 2-second line, -1-space below the bottom line) ... */
 char NClef::line2Name(int line, int *octave, bool lilyexport, bool abcexport) const {
 	*octave = 0;
-	char c;
+	char c = -3;
 	int kind = clefKind_;
 	if (lilyexport && (kind == DRUM_CLEF || kind == DRUM_BASS_CLEF)) {
 		line += 1;
@@ -341,6 +340,9 @@ char NClef::line2Name(int line, int *octave, bool lilyexport, bool abcexport) co
 		case  3: c = 'a'; break;
 		case  4: c = 'b'; break;
 	}
+	if (c==-3) // line error, c was not set
+		NResource::abort("NClef::line2Name()");
+		
 	return c;
 }
 
@@ -386,6 +388,7 @@ char NClef::line2PMXName(int line, int *octave) const {
 				case  8: c = 'a'; break;
 				case  9: c = 'b'; break;
 			}
+			break;
 		case SOPRANO_CLEF:
 			*octave = 4;
 			while (line > 6) {
@@ -445,35 +448,6 @@ char NClef::line2PMXName(int line, int *octave) const {
 	return c;
 }
 
-int NClef::line2note(int line) const {
-	int c = 0;
-	switch (clefKind_) {
-		case DRUM_BASS_CLEF:
-		case BASS_CLEF:  line -= 5; break;
-		case SOPRANO_CLEF: line -= 2; break;
-		case ALTO_CLEF: line -= 6; break;
-		case TENOR_CLEF: line -= 8; break;
-		default: break;
-	}
-
-	while (line > 4) {
-		line -= 7; 
-	}
-	while (line < -2) {
-		line += 7;
-	}
-	switch (line) {
-		case -2: c = 0; break;
-		case -1: c = 1; break;
-		case  0: c = 2; break;
-		case  1: c = 3; break;
-		case  2: c = 4; break;
-		case  3: c = 5; break;
-		case  4: c = 6; break;
-	}
-	return c;
-}
-
 int NClef::name2Line(char name) const {
 	int line;
 	switch (name) {
@@ -502,10 +476,10 @@ int NClef::name2Line(char name) const {
 	return line;
 }
 
-int NClef::getAccPos(int kind, int nr) {
+int NClef::getAccPos(property_type kind, int nr) {
 	switch (kind) {
-		case STAT_CROSS: return sharpPosTab_[nr];
-		case STAT_FLAT: return flatPosTab_[nr];
+		case PROP_CROSS: return sharpPosTab_[nr];
+		case PROP_FLAT: return flatPosTab_[nr];
 		default: NResource::abort("internal error in NClef::getAccPos");
 	}
 	return 0;
@@ -533,13 +507,38 @@ int NClef::noteNumber2Line(int note_number) const {
 	return note_number;
 }
 
-void NClef::midi2Line(unsigned int midival, int *line, int *offs, NKeySig *ksig) {
-	int i, kind, count;
+int NClef::line2NoteNumber( int line ) const {
+	switch (clefKind_) {
+		case DRUM_BASS_CLEF:
+		case BASS_CLEF:
+			line -= 3;
+			break;
+		case DRUM_CLEF:
+		case TREBLE_CLEF:
+			line -= 5;
+			break;
+		case SOPRANO_CLEF:
+			break;
+		case ALTO_CLEF:
+			line -= 4;
+			break;
+		case TENOR_CLEF:
+			line -= 6;
+			break;
+	}
+
+	while( line < 0 )
+		line += 7;
+
+	return line % 7;
+}
+
+void NClef::midi2Line(unsigned int midival, int *line, int *offs, int ksigType) {
 	*line = 0;
 	*offs = 0;
 
 	midival -= shift_;
-	for (i = 0; i < MAXLINE-MINLINE+1; i++) {
+	for (int i = 0; i < MAXLINE-MINLINE+1; i++) {
 		if (line2midiTab_[i] >= midival) {
 			if (line2midiTab_[i] == midival) {
 				*line = i + MINLINE;
@@ -547,9 +546,7 @@ void NClef::midi2Line(unsigned int midival, int *line, int *offs, NKeySig *ksig)
 			else {
 				*line = i + MINLINE - 1;
 				*offs = 1;
-				if (!ksig) return;
-				if (!ksig->isRegular(&kind, &count)) return;
-				if (kind != STAT_FLAT) return;
+				if (ksigType != PROP_FLAT) return;
 				(*line)++;
 				*offs = -1;
 			}
@@ -558,6 +555,10 @@ void NClef::midi2Line(unsigned int midival, int *line, int *offs, NKeySig *ksig)
 	}
 }
 
+int NClef::line2Midi( int line, int offs ) {
+	return line2midiTab_[ line - MINLINE ] + offs + shift_;
+}
+
 int NClef::chooseClefType(staffInfoClass *staffInfos, unsigned int minMidi, unsigned int maxMidi, bool drumchannel) {
 	int treble_clef, bass_clef;
 
@@ -672,7 +673,7 @@ int NClef::chooseClefType(staffInfoClass *staffInfos, unsigned int minMidi, unsi
 }
 
 void NClef::calculateDimensionsAndPixmaps() {
-	int ypos, yoffs;
+	int ypos = 0, yoffs = 0;
 	if (!staff_props_->base) return;
 	switch (clefKind_) {
 		case TREBLE_CLEF: switch(shift_) {
@@ -784,7 +785,7 @@ void NClef::calculateDimensionsAndPixmaps() {
 		default: NResource::abort("unknown clef");
 				break;
 	}
-	nbaseDrawPoint_ = QPoint (xpos_, ypos+yoffs);
+	nbaseDrawPoint_ = QPoint(xpos_, ypos+yoffs);
 	bbox_ = QRect(xpos_, ypos , pixmapWidth_, pixmapHeight_);
 }
 
@@ -795,7 +796,9 @@ void NClef::draw(int /* dummy */) {
 }
 
 void NClef::drawContextClef() {
-	main_props_->tp->beginUnclippedYtranslated();
-	main_props_->tp->drawPixmap(main_props_->context_clef_xpos, nbaseDrawPoint_.y(), *blackPixmap_);
-	main_props_->tp->end();
+	if (main_props_) {
+		main_props_->tp->beginUnclippedYtranslated();
+		main_props_->tp->drawPixmap(main_props_->context_clef_xpos, nbaseDrawPoint_.y(), *blackPixmap_);
+		main_props_->tp->end();
+	}
 }
