@@ -47,20 +47,20 @@ class NClef : public NMusElement {
 		void drawContextClef();
 		virtual int getSubType() const {return clefKind_;}
 		virtual int getType() const {return T_CLEF;}
-		const unsigned int *line2midiTab_;
 		const char *line2TexTab_;
-		int getAccPos(int kind, int nr);
+		int getAccPos(property_type kind, int nr);
 		int noteNumber2Line(int note_number) const ;
+		int line2NoteNumber(int line ) const;
 		int lineOfC4();
 		char line2PMXName(int line, int *octave) const;
 		char line2Name(int line, int *octave, bool lilyexport, bool abcexport) const;
 		int name2Line(char name) const;
-		int line2note(int line) const;
 		virtual void calculateDimensionsAndPixmaps();
 		int getOctave();
 		int getShift() {return shift_;}
 		void setShift(int octave);
-		void midi2Line(unsigned int midival,int *line, int *offs, NKeySig *ksig = 0);
+		void midi2Line(unsigned int midival,int *line, int *offs, int ksigType = PROP_NO_ACC);
+		int line2Midi(int line, int offs);
 		static int chooseClefType(staffInfoClass *staffInfos, unsigned int minMidi, unsigned int MaxMidi, bool drumchannel);
 	private:
 		QPixmap *redPixmap_;
@@ -69,6 +69,7 @@ class NClef : public NMusElement {
 		int clefKind_;
 		int shift_;
 		const char *sharpPosTab_, *flatPosTab_;
+		const unsigned int *line2midiTab_;
 		static const unsigned int line2midiTreble_[MAXLINE-MINLINE+1];
 		static const unsigned int line2midiBass_[MAXLINE-MINLINE+1];
 		static const unsigned int line2midiSoprano_[MAXLINE-MINLINE+1];
