@@ -88,8 +88,8 @@ void NFileHandler::pitchOut( const NNote *note, NClef *ac_clef, bool with_tie) {
 	int i, octave;
 
 	out_ << ac_clef->line2Name(note->line, &octave, false, false);
-	if (!(note->status & STAT_PART_OF_TIE) && with_tie) {
-		if (note->status & STAT_FORCE) {
+	if (!(note->properties & PROP_PART_OF_TIE) && with_tie) {
+		if (note->properties & PROP_FORCE) {
 			switch (note->offs) {
 				case  1: out_ << "#"; break;
 				case -1: out_ << "&"; break;
@@ -99,12 +99,12 @@ void NFileHandler::pitchOut( const NNote *note, NClef *ac_clef, bool with_tie) {
 			}
 		}
 		else {
-			switch (note->status & ACC_MASK) {
-				case STAT_CROSS: out_ << "#";  break;
-				case STAT_FLAT: out_ << "&";   break;
-				case STAT_NATUR: out_ << "n";  break;
-				case STAT_DCROSS: out_ << "x"; break;
-				case STAT_DFLAT: out_ << "&&"; break;
+			switch (note->properties & ACC_MASK) {
+				case PROP_CROSS: out_ << "#";  break;
+				case PROP_FLAT: out_ << "&";   break;
+				case PROP_NATUR: out_ << "n";  break;
+				case PROP_DCROSS: out_ << "x"; break;
+				case PROP_DFLAT: out_ << "&&"; break;
 			}
 		}
 	}
@@ -118,19 +118,19 @@ void NFileHandler::pitchOut( const NNote *note, NClef *ac_clef, bool with_tie) {
 			out_ << "-";
 		}
 	}
-	if ((note->status & STAT_TIED) && with_tie) out_ << "~";
-	switch (note->status & BODY_MASK) {
-		case STAT_BODY_CROSS: out_ << " bcr "; break;
-		case STAT_BODY_CROSS2: out_ << " bcr2 "; break;
-		case STAT_BODY_CIRCLE_CROSS: out_ << " bcrc "; break;
-		case STAT_BODY_TRIA: out_ << " btr "; break;
-		case STAT_BODY_RECT: out_ << " brec "; break;
+	if ((note->properties & PROP_TIED) && with_tie) out_ << "~";
+	switch (note->properties & BODY_MASK) {
+		case PROP_BODY_CROSS: out_ << " bcr "; break;
+		case PROP_BODY_CROSS2: out_ << " bcr2 "; break;
+		case PROP_BODY_CIRCLE_CROSS: out_ << " bcrc "; break;
+		case PROP_BODY_TRIA: out_ << " btr "; break;
+		case PROP_BODY_RECT: out_ << " brec "; break;
 	}
 }
 
 
 	
-bool NFileHandler::writeStaffs(QString fname, QList<NStaff> *stafflist, NMainFrameWidget *mainWidget, bool showErrors) {
+bool NFileHandler::writeStaffs(QString fname, QPtrList<NStaff> *stafflist, NMainFrameWidget *mainWidget, bool showErrors) {
 	NVoice *voice_elem;
 	NStaff *staff_elem;
 	NMusElement *last_elem;
@@ -194,45 +194,51 @@ bool NFileHandler::writeStaffs(QString fname, QList<NStaff> *stafflist, NMainFra
 	out_ << "header" << endl;
 	if (!mainWidget->scTitle_.isEmpty()) {
 		outstring = mainWidget->scTitle_;
-		outstring.replace('\\', "\\\\"); /* replace all backslashes with \\ two character backslashes */
-		outstring.replace (newLines_, "\\n"); /* replace all newlines with \n two character symbols */
-		outstring.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */
+		//replace non-ordinary characters with their escape sequence characters
+		outstring.replace('\\', "\\\\");
+		outstring.replace (newLines_, "\\n");
+		outstring.replace('"', "\\\"");
 		out_ << "\ttitle bold (" <<  SC_TITLE_FONT_SIZE << ") \"" << outstring.utf8() << '"' << endl;
 	}
 	if (!mainWidget->scSubtitle_.isEmpty()) {
 		outstring = mainWidget->scSubtitle_;
-		outstring.replace('\\', "\\\\"); /* replace all backslashes with \\ two character backslashes */
-		outstring.replace (newLines_, "\\n"); /* replace all newlines with \n two character symbols */
-		outstring.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */
+		//replace non-ordinary characters with their escape sequence characters
+		outstring.replace('\\', "\\\\");
+		outstring.replace (newLines_, "\\n");
+		outstring.replace('"', "\\\"");
 		out_ << "\ttitle bold (" << SC_SUBTITLE_FONT_SIZE << ") \"" << outstring.utf8() << '"' << endl;
 	}
 	if (!mainWidget->scAuthor_.isEmpty()) {
 		outstring = mainWidget->scAuthor_;
-		outstring.replace('\\', "\\\\"); /* replace all backslashes with \\ two character backslashes */
-		outstring.replace (newLines_, "\\n"); /* replace all newlines with \n two character symbols */
-		outstring.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */
+		//replace non-ordinary characters with their escape sequence characters
+		outstring.replace('\\', "\\\\");
+		outstring.replace (newLines_, "\\n");
+		outstring.replace('"', "\\\"");
 		out_ << "\ttitle bold (" << SC_AUTHOR_FONT_SIZE << ") \"" << outstring.utf8() << '"' << endl;
 	}
 	if (!mainWidget->scLastAuthor_.isEmpty()) {
 		outstring = mainWidget->scLastAuthor_;
-		outstring.replace('\\', "\\\\"); /* replace all backslashes with \\ two character backslashes */
-		outstring.replace (newLines_, "\\n"); /* replace all newlines with \n two character symbols */
-		outstring.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */
+		//replace non-ordinary characters with their escape sequence characters
+		outstring.replace('\\', "\\\\");
+		outstring.replace (newLines_, "\\n");
+		outstring.replace('"', "\\\"");
 		out_ << "\ttitle bold (" << SC_LAST_AUTHOR_FONT_SIZE << ") \"" << outstring.utf8() << '"' << endl;
 	}
 	if (!mainWidget->scComment_.isEmpty()) {
 		outstring = mainWidget->scComment_;
-		outstring.replace('\\', "\\\\"); /* replace all backslashes with \\ two character backslashes */
-		outstring.replace (newLines_, "\\n"); /* replace all newlines with \n two character symbols */
-		outstring.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */
+		//replace non-ordinary characters with their escape sequence characters
+		outstring.replace('\\', "\\\\");
+		outstring.replace (newLines_, "\\n");
+		outstring.replace('"', "\\\"");
 		out_ << "\ttitle bold (" << SC_COMMENT_FONT_SIZE << ") \"" <<  outstring.utf8() << '"' << endl;
 	}
 	if (!mainWidget->scCopyright_.isEmpty()) {
 		out_ << "footer" << endl;
+		//replace non-ordinary characters with their escape sequence characters
 		outstring = mainWidget->scCopyright_;
-		outstring.replace('\\', "\\\\"); /* replace all backslashes with \\ two character backslashes */
-		outstring.replace (newLines_, "\\n"); /* replace all newlines with \n two character symbols */
-		outstring.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */
+		outstring.replace('\\', "\\\\");
+		outstring.replace (newLines_, "\\n");
+		outstring.replace('"', "\\\"");
 		out_ << "\ttitle bold (" << SC_COPYRIGHT_FONT_SIZE << ") \"" <<  outstring.utf8() << '"' << endl;
 	}
 	out_ << "score" << endl;
@@ -316,7 +322,7 @@ bool NFileHandler::writeStaffs(QString fname, QList<NStaff> *stafflist, NMainFra
 		for (i = 1, staff_elem = stafflist->first(); staff_elem; staff_elem = stafflist->next(), i++) {
 			voice_elem = staff_elem->getVoiceNr(0);
 			hasClef_ = false;
-			writeScoreInfo(i, voice_elem, first, mainWidget);
+			writeScoreInfo(i, voice_elem, first);
 		}
  		if (!musicmode_ || (first && !music_written_)) {
 			musicmode_ = true;
@@ -449,10 +455,10 @@ bool NFileHandler::writeStaffs(QString fname, QList<NStaff> *stafflist, NMainFra
 				out_ << pedals_ << endl;
 			}
 			if (!textsigns_above_.isEmpty()) {
-				out_ << textsigns_above_ << endl;
+				out_ << textsigns_above_.utf8() << endl;
 			}
 			if (!textsigns_below_.isEmpty()) {
-				out_ << textsigns_below_ << endl;
+				out_ << textsigns_below_.utf8() << endl;
 			}
 			if (!signs_.isEmpty()) {
 				if (!some_notes_or_rests_written_) {
@@ -674,7 +680,7 @@ bool NFileHandler::writeStaffs(QString fname, QList<NStaff> *stafflist, NMainFra
 	return true;
 }
 
-void NFileHandler::writeScoreInfo(int staff_nr, NVoice *voi, bool firstcall, NMainFrameWidget *mainWidget) {
+void NFileHandler::writeScoreInfo(int staff_nr, NVoice *voi, bool firstcall) {
 	NMusElement *elem;
 	NVoice *voice_elem;
 	int voice_count, i;
@@ -779,12 +785,13 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 	int part, tt;
 	NNote *note, *note2;
 	NChord *chord;
+	NRest *rest;
 	NSign *sign;
 	NClef *clef;
 	NKeySig *ksig;
 	NText *textSign;
 	bool ok;
-	int tupletsum;
+	int tupletsum=0;
 	int subtype;
 	int dist;
 	int dest_measure_start_time;
@@ -899,20 +906,20 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 				     some_notes_or_rests_written_ = true;
 				     chord = (NChord *) elem;
 				     part = elem->getSubType(); 
-				     if (!(elem->status_ & STAT_GRACE)) {
-					     if (elem->status_ & STAT_TUPLET) {
-						total += elem->getPlaytime() * part / elem->getNumNotes();
+				     if (!(chord->hasProperty( PROP_GRACE ) )) {
+					     if (chord->hasProperty( PROP_TUPLET ) ) {
+						total += elem->chord()->getPlaytime() * part / elem->chord()->getNumNotes();
 						tupletsum += part;
 					     }
 					     else {
 						total += part;
 					     }
-					     switch (elem->status_ & DOT_MASK) {
+					     switch (chord->properties() & DOT_MASK) {
 						case 1: total += part / 2; break;
 						case 2: total += 3 * part / 4; break;
 					     }
 				     }
-				     if ((elem->status_ & STAT_TUPLET) && !voi->inTuplet_) {
+				     if ((chord->hasProperty( PROP_TUPLET ) ) && !voi->inTuplet_) {
 					voi->inTuplet_ = true;
 					tupletsum = part;
 					out_ << "{ ";
@@ -922,27 +929,27 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 					bad = new badmeasure(ERR_NOTE_COUNT, staff_nr, bar_nr_, total / 3, countof128th_);
 					badlist_.append(bad);
 				     }
-				     if (chord->status_ & STAT_SFORZ || chord->status_ & STAT_PORTA ||
-				         chord->status_ & STAT_STPIZ || chord->status_ & STAT_SFZND ||
-					 chord->status_ & STAT_STACC || chord->status_ & STAT_FERMT) {
+				     if (chord->hasProperty( PROP_SFORZ ) || chord->hasProperty( PROP_PORTA ) ||
+				         chord->hasProperty( PROP_STPIZ ) || chord->hasProperty( PROP_SFZND ) ||
+					 chord->hasProperty( PROP_STACC ) || chord->hasProperty( PROP_FERMT ) ) {
 				    	    out_ << "[with ";
-				    	    if (chord->status_ & STAT_STACC)
+				    	    if (chord->hasProperty( PROP_STACC ) )
 						out_ << ".";
-				    	    if (chord->status_ & STAT_SFORZ) 
+				    	    if (chord->hasProperty( PROP_SFORZ ) )
 					        out_ << "^";
-					    if (chord->status_ & STAT_PORTA)
+					    if (chord->hasProperty( PROP_PORTA ) )
 					        out_ << "-";
-					    if (chord->status_ & STAT_STPIZ)
+					    if (chord->hasProperty( PROP_STPIZ ) )
 					        out_ << ",";
-					    if (chord->status_ & STAT_SFZND)
+					    if (chord->hasProperty( PROP_SFZND ) )
 					        out_ << ">";
-					    if (chord->status_ & STAT_FERMT)
+					    if (chord->hasProperty( PROP_FERMT ) )
 						out_ << "\"\\(ferm)\"";
 				    	    out_ << ']';
 				     }
-				     if (chord->status_ & STAT_GRACE) {
+				     if (chord->hasProperty( PROP_GRACE ) ) {
 						inGrace = true;
-						if (!beam_grace_problem_reported && (chord->status_ & STAT_BEAMED)) {
+						if (!beam_grace_problem_reported && (chord->hasProperty( PROP_BEAMED ) )) {
 							beam_grace_problem_reported = true;
 
 							bad = new badmeasure(ERR_BEAMS_IN_GRACES, staff_nr, bar_nr_, total / 3, countof128th_);
@@ -958,36 +965,36 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 					inGrace = false;
 					beam_grace_problem_reported = false;
 				     }
-				     if (!(chord->status_ & STAT_GRACE) && chord->getSubType() <= HALF_LENGTH) {
-					if (((chord->status_ & STAT_STEM_UP) && 
+				     if (!(chord->hasProperty( PROP_GRACE ) ) && chord->getSubType() <= HALF_LENGTH) {
+					if (((chord->hasProperty( PROP_STEM_UP ) ) && 
 						(chord->getNoteList()->first()->line > 3 || voi->stemPolicy_ == STEM_POL_DOWN))  ||
-					    (!(chord->status_ & STAT_STEM_UP) && 
+					    (!(chord->hasProperty( PROP_STEM_UP ) ) && 
 					    	(chord->getNoteList()->first()->line  < 4 || voi->stemPolicy_ == STEM_POL_UP))) {
-						out_ << ((chord->status_ & STAT_STEM_UP) ? "[up]" : "[down] ");
+						out_ << ((chord->hasProperty( PROP_STEM_UP ) ) ? "[up]" : "[down] ");
 					}
 				     }
 				     if (part == DOUBLE_WHOLE_LENGTH) {
 					out_ << "1/2";
 				     }
-				     else if ((chord->status_ & STAT_GRACE) && (chord->getSubType() == INTERNAL_MARKER_OF_STROKEN_GRACE)) {
+				     else if ((chord->hasProperty( PROP_GRACE ) ) && (chord->getSubType() == INTERNAL_MARKER_OF_STROKEN_GRACE)) {
 					out_ << "8";
 				     }
 				     else {
 				     	out_ << WHOLE_LENGTH / part;
 				     }
-				     switch (elem->status_ & DOT_MASK) {
+				     switch (chord->properties() & DOT_MASK) {
 					case 1:	out_ << "."; break;
 					case 2:	out_ << ".."; break;
 				     }
-			  	     for (note = elem->getNoteList()->first(); note; note = elem->getNoteList()->next()) {
+			  	     for (note = chord->getNoteList()->first(); note; note = chord->getNoteList()->next()) {
 					     pitchOut(note, &(actual_staff->actualClef_), true);
-					     if (!drum_problem_written_ && (note->status & BODY_MASK)) {
+					     if (!drum_problem_written_ && (note->properties & BODY_MASK)) {
 						drum_problem_written_ = true;
 						bad = new badmeasure(ERR_DRUM_STAFF, staff_nr, 0 /*dummy */, 3 /* dummy */, countof128th_);
 						badlist_.append(bad);
 					     }
 					     /* if (loop2) { */
-						if ((chord->status_ & STAT_SLURED) && (chord->status_ & STAT_GRACE)) { /* otherwise it is made by phrases */
+						if ((chord->hasProperty( PROP_SLURED ) ) && (chord->hasProperty( PROP_GRACE ))) { /* otherwise it is made by phrases */
 							dist = voi->computeSlurDist(chord);
 							if (dist > 1) { // possibly failes if there is a bar :-(
 								bad = new badmeasure(ERR_GRACE_SLUR, staff_nr, bar_nr_, 0, 0);
@@ -1006,7 +1013,7 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 #ifdef IS_MADE_WITH_PHRASES
 					     if (loop2) {
 						loop2 = false;
-						if (chord->status_ & STAT_SLURED) {
+						if (chord->hasProperty( PROP_SLURED ) ) {
 							dist = voi->computeSlurDist(chord);
 							if (dist > 1) {
 								bad = new badmeasure(ERR_SLUR, staff_nr, bar_nr_, 0, 0);
@@ -1024,30 +1031,30 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 					    }
 #endif
 				     }
-				     if (elem->status_ & STAT_BEAMED) {
+				     if (chord->hasProperty( PROP_BEAMED ) ) {
 					if (!voi->inBeam_) {
 						out_ << " bm";
 						voi->inBeam_ = true;
 					 }
-				     	 else if (elem->lastBeamed()) {
+				     	 else if (chord->lastBeamed()) {
 						out_ << " ebm";
 						voi->inBeam_ = false;
 					 }
 				     }
 				     out_ << "; ";
-				     if (elem->status_ & STAT_LAST_TUPLET) {
+				     if (chord->hasProperty( PROP_LAST_TUPLET ) ) {
 					voi->inTuplet_ = false;
 					out_ << " } above  " <<
-						computeTripletString(tupletsum, elem->getNumNotes(), elem->getPlaytime(), &ok) << "; ";
+						computeTripletString(tupletsum, elem->chord()->getNumNotes(), elem->chord()->getPlaytime(), &ok) << "; ";
 					if (!ok) {
 						bad = new badmeasure(ERR_TUPLET, staff_nr, bar_nr_, total / 3, countof128th_);
 						badlist_.append(bad);
 					}
 				     }
-				     if (elem->trill_) {
+				     if (chord->trill_) {
 					dest_measure_start_time = *measure_start_time;
 					tt = voi->findTimeOfTrillEnd((NChord *) elem, &dest_measure_start_time, &count_of_measures);
-					if (elem->trill_ > 0) {
+					if (chord->trill_ > 0) {
 #if GCC_MAJ_VERS > 2
 						if (ornaments_->tellp() < 1) {
 #else
@@ -1073,14 +1080,14 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 					else {
 						timestring.sprintf("%f", endtime + 1.0);
 					}
-					if (elem->trill_ > 0) {
+					if (chord->trill_ > 0) {
 						*ornaments_ << (starttime + 1.0) << " \"tr\" til " << timestring << ';';
 					}
 					else {
 						*trillsyms_ << (starttime + 1.0) << " \"~\" til " << timestring << ';';
 					}
 				     }
-				     if (elem->dynamic_) {
+				     if (chord->dynamic_) {
 					dest_measure_start_time = *measure_start_time;
 					tt = voi->findTimeOfDynamicEnd(chord, measure_start_time,
 						 &dest_measure_start_time, &count_of_measures);
@@ -1105,10 +1112,10 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 							(starttime + 1.0) << " til " << timestring << ';';
 				        }
 				     }
-				     if (elem->va_) {
+				     if (chord->va_) {
 					dest_measure_start_time = *measure_start_time;
 					tt = voi->findTimeOfVaEnd((NChord *) elem, &dest_measure_start_time, &count_of_measures);
-					if (elem->va_ > 0) {
+					if (chord->va_ > 0) {
 #if GCC_MAJ_VERS > 2
 						if (valines_->tellp() < 1) {
 #else
@@ -1134,14 +1141,14 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 					else {
 						timestring.sprintf("%f", endtime + 1.0);
 					}
-					if (elem->va_ > 0) {
+					if (chord->va_ > 0) {
 						*valines_ << (starttime + 1.0) << " \"8va\" til " << timestring << ';';
 					}
 					else {
 						*valines_ << (starttime + 1.0) << " \"8va bassa\" til " << timestring << ';';
 					}
 				     }
-				     if ((elem->status_ & STAT_SLURED) && !(chord->status_ & STAT_GRACE)) {
+				     if ((chord->hasProperty( PROP_SLURED ) ) && !(chord->hasProperty( PROP_GRACE ) )) {
 					dest_measure_start_time = *measure_start_time;
 					chord = ((NChord *) elem);
 					tt = voi->findTimeOfSlurEnd((NChord *) elem, &dest_measure_start_time, &count_of_measures);
@@ -1162,7 +1169,7 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 					}
 					*phrases_ << (starttime + 1.0) << " til " << timestring << ';';
 				     }
-				     if (elem->status_ & STAT_ARPEGG) {
+				     if (chord->hasProperty( PROP_ARPEGG ) ) {
 					   starttime = ((chord->midiTime_ - *measure_start_time) / MULTIPLICATOR) / (double) (128 / curr_denom_);
 					   if (rolls_.isEmpty()) {
 					   	rolls_.sprintf("roll %d 1: ",  staff_nr);
@@ -1170,7 +1177,7 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 					   timestring.sprintf("%f;", starttime + 1.0);
 					   rolls_ += timestring;
 				     }
-				     if (elem->status2_ & STAT2_PEDAL_ON) {
+				     if (chord->hasProperty( PROP_PEDAL_ON ) ) {
 					   starttime = ((chord->midiTime_ - *measure_start_time) / MULTIPLICATOR) / (double) (128 / curr_denom_);
 					   if (pedals_.isEmpty()) {
 					   	pedals_.sprintf("pedal %d: ",  staff_nr);
@@ -1178,7 +1185,7 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 					   timestring.sprintf("%f;", starttime + 1.0);
 					   pedals_ += timestring;
 				     }
-				     if (elem->status2_ & STAT2_PEDAL_OFF) {
+				     if (chord->hasProperty( PROP_PEDAL_OFF ) ) {
 					   starttime = ((chord->midiTime_ - *measure_start_time) / MULTIPLICATOR) / (double) (128 / curr_denom_);
 					   if (pedals_.isEmpty()) {
 					   	pedals_.sprintf("pedal %d: ",  staff_nr);
@@ -1186,11 +1193,11 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 					   timestring.sprintf("%f*;", starttime + 1.0);
 					   pedals_ += timestring;
 				     }
-				     if ((diag = elem->getChordChordDiagram())) {
+				     if ((diag = chord->getChordChordDiagram())) {
 					starttime = ((elem->midiTime_ - *measure_start_time) / MULTIPLICATOR) / (double) (128 / curr_denom_);
 					writeChord(staff_nr, starttime, diag);
 				     }
-				     if (!(chord->getNoteList()->first()->status & STAT_PART_OF_TIE) && !(chord->status_ & STAT_GRACE)) {
+				     if (!(chord->getNoteList()->first()->properties & PROP_PART_OF_TIE) && !(chord->hasProperty( PROP_GRACE ))) {
 				        for (i = 0; i < NUM_LYRICS; i++) {
 				     		lyrics = chord->getLyrics(i);
 				     		if (lyrics) {
@@ -1210,7 +1217,8 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 					}
 				     }
 				     break;
-			case T_REST: if (inGrace) {
+			case T_REST: rest = elem->rest();
+				     if (inGrace) {
 					inGrace = false;
 					beam_grace_problem_reported = false;
 					bad = new badmeasure(ERR_GRACE_AFTER, staff_nr, bar_nr_, total / 3, countof128th_);
@@ -1225,25 +1233,25 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 				     if (part == MULTIREST) {
 					bad = new badmeasure(ERR_MULTIREST, staff_nr, bar_nr_, total / 3, countof128th_);
 					fatallist_.append(bad);
-					if (divide_multi_rest(staff_nr, 1, ((NRest *) elem)->getMultiRestLength())) {
+					if (divide_multi_rest(staff_nr, 1, rest->getMultiRestLength())) {
 						total = MULTIPLICATOR*countof128th_;
 						return SIMPLE_BAR;
 					}
 					break;
 				     }
 
-				     if (elem->status_ & STAT_TUPLET) {
-					total += elem->getPlaytime() * part / elem->getNumNotes();
+				     if (rest->hasProperty( PROP_TUPLET ) ) {
+					total += rest->getPlaytime() * part / rest->getNumNotes();
 					tupletsum += part;
 				     }
 				     else {
 					total += part;
 				     }
-				     switch (elem->status_ & DOT_MASK) {
+				     switch (rest->properties() & DOT_MASK) {
 					case 1: total += part / 2; break;
 					case 2: total += 3 * part / 4; break;
 				     }
-				     if ((elem->status_ & STAT_TUPLET) && !voi->inTuplet_) {
+				     if ((rest->hasProperty( PROP_TUPLET ) ) && !voi->inTuplet_) {
 					voi->inTuplet_ = true;
 					tupletsum = part;
 					out_ << "{ ";
@@ -1253,25 +1261,25 @@ int NFileHandler::writeStaffUntilBar(int staff_nr, NVoice *voi, bool first, int
 					bad = new badmeasure(ERR_NOTE_COUNT, staff_nr, bar_nr_, total / 3, countof128th_);
 					badlist_.append(bad);
 				     }
-				     if (elem->status_ & STAT_FERMT) {
+				     if (rest->hasProperty( PROP_FERMT ) ) {
 					out_ << "[with ";
 					out_ << "\"\\(ferm)\"";
 					out_ << ']';
 				     }
 				     out_ << WHOLE_LENGTH / part;
-				     switch (elem->status_ & DOT_MASK) {
+				     switch (rest->properties() & DOT_MASK) {
 					case 1:	out_ << "."; break;
 					case 2:	out_ << ".."; break;
 				     }
-				     out_ << ((elem->status_ & STAT_HIDDEN) ? "s; " : "r; ");
-				     if ((diag = elem->getChordChordDiagram())) {
-					starttime = ((elem->midiTime_ - *measure_start_time) / MULTIPLICATOR) / (double) (128 / curr_denom_);
+				     out_ << ((rest->hasProperty( PROP_HIDDEN ) ) ? "s; " : "r; ");
+				     if (diag = rest->getChordChordDiagram()) {
+					starttime = ((elem->midiTime_ - (*measure_start_time)) / MULTIPLICATOR) / (double) (128 / curr_denom_);
 					writeChord(staff_nr, starttime, diag);
 				     }
-				     if (elem->status_ & STAT_LAST_TUPLET) {
+				     if (rest->hasProperty( PROP_LAST_TUPLET ) ) {
 					voi->inTuplet_ = false;
 					out_ << " } above  " <<
-						computeTripletString(tupletsum, elem->getNumNotes(), elem->getPlaytime(), &ok) << "; ";
+						computeTripletString(tupletsum, rest->getNumNotes(), rest->getPlaytime(), &ok) << "; ";
 					if (!ok) {
 						bad = new badmeasure(ERR_TUPLET, staff_nr, bar_nr_, total / 3, countof128th_);
 						badlist_.append(bad);
@@ -1547,7 +1555,7 @@ void NFileHandler::writeStaffLayout(NMainFrameWidget *mainWidget, int staffCount
 
 }
 
-int NFileHandler::determineMultiRest(QList<NStaff> *stafflist) {
+int NFileHandler::determineMultiRest(QPtrList<NStaff> *stafflist) {
 	NStaff *staff_elem;
 	int len;
 
@@ -1645,10 +1653,11 @@ bool NFileHandler::writeClef(NClef * clef, int voice_nr) {
 }
 
 void NFileHandler::writeKeySig(NKeySig * ksig, int voice_nr, bool only_regulaer) {
-	int kind, count;
+	property_type kind;
+	int count;
 	if (ksig == 0) return; /* no clef found => no key signature available */
 	if (ksig->isRegular(&kind, &count)) {
-		out_ << "\tkey = " << count << ((kind == STAT_CROSS) ? "#" : "&") << endl;
+		out_ << "\tkey = " << count << ((kind == PROP_CROSS) ? "#" : "&") << endl;
 	}
 	else {
 		if (only_regulaer) {
@@ -1658,7 +1667,7 @@ void NFileHandler::writeKeySig(NKeySig * ksig, int voice_nr, bool only_regulaer)
 		else {
 			badmeasure *bad = new badmeasure(ERR_IRREGULAER, voice_nr, bar_nr_, 3 /* dummy */, countof128th_);
 			badlist_.append(bad);
-			out_ << "//\tirregular = " << ksig->printKeys() << endl;
+			out_ << "//\tirregular = " << ksig->toString() << endl;
 		}
 	}
 }
@@ -1670,6 +1679,7 @@ void NFileHandler::writeVoiceElemsTill(int staff_nr, int voice_nr, NVoice *voi,
 	int part, tt;
 	NNote *note, *note2;
 	NChord *chord, *partner;
+	NRest *rest;
 	bool something_written = false;
 	int dest_measure_start_time;
 	bool inGrace = false;
@@ -1679,7 +1689,7 @@ void NFileHandler::writeVoiceElemsTill(int staff_nr, int voice_nr, NVoice *voi,
 	int count_of_measures;
 	QString timestring;
 	double starttime, endtime;
-	int tupletsum;
+	int tupletsum=0;
 	bool loop1 = true, loop2;
 	badmeasure *bad;
 	NStaff *actual_staff;
@@ -1693,25 +1703,26 @@ void NFileHandler::writeVoiceElemsTill(int staff_nr, int voice_nr, NVoice *voi,
 	}
 	while (elem && elem->midiTime_ < stopTime) {
 		switch (elem->getType()) {
-			case T_CHORD: if (loop1) {
+			case T_CHORD: chord = (NChord *) elem;
+				      if (loop1) {
 					loop1 = false;
 					out_ << staff_nr << " " << voice_nr << ": ";
 				     }
 				     part = elem->getSubType(); 
-				     if (!(elem->status_ & STAT_GRACE)) {
-					if (elem->status_ & STAT_TUPLET) {
-						total += elem->getPlaytime() * part / elem->getNumNotes();
+				     if (!(chord->hasProperty( PROP_GRACE ))) {
+					if (chord->hasProperty( PROP_TUPLET )) {
+						total += chord->getPlaytime() * part / chord->getNumNotes();
 						tupletsum += part;
 					}
 					else {
 						total += part;
 					}
-					switch (elem->status_ & DOT_MASK) {
+					switch (chord->properties() & DOT_MASK) {
 						case 1: total += part / 2; break;
 						case 2: total += 3 * part / 4; break;
 				     	}
 				     }
-				     if ((elem->status_ & STAT_TUPLET) && !voi->inTuplet_) {
+				     if ((chord->hasProperty( PROP_TUPLET )) && !voi->inTuplet_) {
 					voi->inTuplet_ = true;
 					tupletsum = part;
 					out_ << "{ ";
@@ -1721,29 +1732,28 @@ void NFileHandler::writeVoiceElemsTill(int staff_nr, int voice_nr, NVoice *voi,
 					bad = new badmeasure(ERR_NOTE_COUNT, staff_nr, bar_nr_, total / 3, countof128th_);
 					badlist_.append(bad);
 				     }
-				     chord = (NChord *) elem;
 
-				     if (chord->status_ & STAT_SFORZ || chord->status_ & STAT_PORTA ||
-				         chord->status_ & STAT_STPIZ || chord->status_ & STAT_SFZND ||
-					 chord->status_ & STAT_STACC || chord->status_ & STAT_FERMT) {
+				     if (chord->hasProperty( PROP_SFORZ ) || chord->hasProperty( PROP_PORTA ) ||
+				         chord->hasProperty( PROP_STPIZ ) || chord->hasProperty( PROP_SFZND ) ||
+					 chord->hasProperty( PROP_STACC ) || chord->hasProperty( PROP_FERMT ) ) {
 				    	    out_ << "[with ";
-				    	    if (chord->status_ & STAT_STACC)
+				    	    if (chord->hasProperty( PROP_STACC ) )
 						out_ << ".";
-				    	    if (chord->status_ & STAT_SFORZ) 
+				    	    if (chord->hasProperty( PROP_SFORZ ) )
 					        out_ << "^";
-					    if (chord->status_ & STAT_PORTA)
+					    if (chord->hasProperty( PROP_PORTA ) )
 					        out_ << "-";
-					    if (chord->status_ & STAT_STPIZ)
+					    if (chord->hasProperty( PROP_STPIZ ) )
 					        out_ << ",";
-					    if (chord->status_ & STAT_SFZND)
+					    if (chord->hasProperty( PROP_SFZND ) )
 					        out_ << ">";
-					    if (chord->status_ & STAT_FERMT)
+					    if (chord->hasProperty( PROP_FERMT ) )
 						out_ << "\"\\(ferm)\"";
 					    out_ << "] ";
 				     }
-				     if (chord->status_ & STAT_GRACE) {
+				     if (chord->hasProperty( PROP_GRACE ) ) {
 						inGrace = true;
-						if (!beam_grace_problem_reported && (chord->status_ & STAT_BEAMED)) {
+						if (!beam_grace_problem_reported && (chord->hasProperty( PROP_BEAMED ))) {
 							beam_grace_problem_reported = true;
 
 							bad = new badmeasure(ERR_BEAMS_IN_GRACES, staff_nr, bar_nr_, total / 3, countof128th_);
@@ -1759,41 +1769,41 @@ void NFileHandler::writeVoiceElemsTill(int staff_nr, int voice_nr, NVoice *voi,
 					inGrace = false;
 					beam_grace_problem_reported = false;
 				     }
-				     if (!(chord->status_ & STAT_GRACE) && chord->getSubType() <= HALF_LENGTH) {
-					if (((chord->status_ & STAT_STEM_UP) && 
+				     if (!(chord->hasProperty( PROP_GRACE )) && chord->getSubType() <= HALF_LENGTH) {
+					if (((chord->hasProperty( PROP_STEM_UP )) && 
 						(chord->getNoteList()->first()->line > 3 || voi->stemPolicy_ == STEM_POL_DOWN))  ||
-					    (!(chord->status_ & STAT_STEM_UP) && 
+					    (!(chord->hasProperty( PROP_STEM_UP )) && 
 					    	(chord->getNoteList()->first()->line  < 4 || voi->stemPolicy_ == STEM_POL_UP))) {
-						out_ << ((chord->status_ & STAT_STEM_UP) ? "[up]" : "[down] ");
+						out_ << ((chord->hasProperty( PROP_STEM_UP )) ? "[up]" : "[down] ");
 					}
 				     }
 				     if (part == DOUBLE_WHOLE_LENGTH) {
 					out_ << "1/2";
 				     }
-				     else if ((chord->status_ & STAT_GRACE) && (chord->getSubType() == INTERNAL_MARKER_OF_STROKEN_GRACE)) {
+				     else if ((chord->hasProperty( PROP_GRACE )) && (chord->getSubType() == INTERNAL_MARKER_OF_STROKEN_GRACE)) {
 					out_ << "8";
 				     }
 				     else {
 				     	out_ << WHOLE_LENGTH / part;
 				     }
-				     switch (elem->status_ & DOT_MASK) {
+				     switch (chord->properties() & DOT_MASK) {
 					case 1:	out_ << "."; break;
 					case 2:	out_ << ".."; break;
 				     }
 				     loop2 = true;
-			  	     for (note = elem->getNoteList()->first(); note; note = elem->getNoteList()->next()) {
+			  	     for (note = chord->getNoteList()->first(); note; note = chord->getNoteList()->next()) {
 					     pitchOut( note, &(actual_staff->actualClef_), true);
-					     if (!drum_problem_written_  && (note->status & BODY_MASK)) {
+					     if (!drum_problem_written_  && (note->properties & BODY_MASK)) {
 						drum_problem_written_ = true;
 						bad = new badmeasure(ERR_DRUM_STAFF, staff_nr, 0 /*dummy */, 3 /* dummy */, countof128th_);
 						badlist_.append(bad);
 					     }
 					     if (loop2) {
 						loop2 = false;
-						if ((chord->status_ & STAT_SLURED) && (voice_nr > 2 || (chord->status_ & STAT_GRACE))) { /* otherwise it is made by phrases */
+						if ((chord->hasProperty( PROP_SLURED ) ) && (voice_nr > 2 || (chord->hasProperty( PROP_GRACE )))) { /* otherwise it is made by phrases */
 							dist = voi->computeSlurDist(chord);
 							if (dist > 1) { /* Note! There is no bar in 2nd, 3rd ... measure. So the index diff can be used */
-								if (chord->status_ & STAT_GRACE) {
+								if (chord->hasProperty( PROP_GRACE ) ) {
 									bad = new badmeasure(ERR_GRACE_SLUR, staff_nr, bar_nr_, 0, 0);
 								}
 								else {
@@ -1812,27 +1822,27 @@ void NFileHandler::writeVoiceElemsTill(int staff_nr, int voice_nr, NVoice *voi,
 						}
 					    }
 				     }
-				     if (elem->status_ & STAT_BEAMED) {
+				     if (chord->hasProperty( PROP_BEAMED ) ) {
 					if (!voi->inBeam_) {
 						out_ << " bm";
 						voi->inBeam_ = true;
 					 }
-				     	 else if (elem->lastBeamed()) {
+				     	 else if (chord->lastBeamed()) {
 						out_ << " ebm";
 						voi->inBeam_ = false;
 					 }
 				     }
 				     out_ << "; ";
-				     if (elem->status_ & STAT_LAST_TUPLET) {
+				     if (chord->hasProperty( PROP_LAST_TUPLET ) ) {
 					voi->inTuplet_ = false;
 					out_ << " } above  " <<
-						computeTripletString(tupletsum, elem->getNumNotes(), elem->getPlaytime(), &ok) << "; ";
+						computeTripletString(tupletsum, chord->getNumNotes(), chord->getPlaytime(), &ok) << "; ";
 					if (!ok) {
 						bad = new badmeasure(ERR_TUPLET, staff_nr, bar_nr_, total / 3, countof128th_);
 						badlist_.append(bad);
 					}
 				     }
-				     if (!(chord->status_ & STAT_GRACE) && voice_nr == 2 && (elem->status_ & STAT_SLURED)) { /* slurs for voices > 2 are incompatible */
+				     if (!(chord->hasProperty( PROP_GRACE ) ) && voice_nr == 2 && (chord->hasProperty( PROP_SLURED ) )) { /* slurs for voices > 2 are incompatible */
 					dest_measure_start_time = measure_start_time;
 					chord = ((NChord *) elem);
 					tt = voi->findTimeOfSlurEnd((NChord *) elem, &dest_measure_start_time, &count_of_measures);
@@ -1853,7 +1863,7 @@ void NFileHandler::writeVoiceElemsTill(int staff_nr, int voice_nr, NVoice *voi,
 					}
 					*phrases_ << (starttime + 1.0) << " til " << timestring << ';';
 				     }
-				     if (elem->status_ & STAT_ARPEGG) {
+				     if (chord->hasProperty( PROP_ARPEGG ) ) {
 					   starttime = ((chord->midiTime_ - measure_start_time) / MULTIPLICATOR) / (double) (128 / curr_denom_);
 					   if (rolls_.isEmpty()) {
 					   	rolls_.sprintf("roll %d %d: ", staff_nr, voice_nr);
@@ -1861,13 +1871,14 @@ void NFileHandler::writeVoiceElemsTill(int staff_nr, int voice_nr, NVoice *voi,
 					   timestring.sprintf("%f;", starttime + 1.0);
 					   rolls_ += timestring;
 				     }
-				     if (elem->status2_ & (STAT2_PEDAL_ON | STAT2_PEDAL_OFF)) {
+				     if (chord->properties() & (PROP_PEDAL_ON | PROP_PEDAL_OFF)) {
 					bad = new badmeasure(ERR_PEDAL_IN_2ND, staff_nr, bar_nr_, total / 3, countof128th_);
 					fatallist_.append(bad);
 				     }
 				     something_written = true;
 				     break;
-			case T_REST: if (inGrace) {
+			case T_REST: rest = elem->rest();
+				     if (inGrace) {
 					inGrace = false;
 					beam_grace_problem_reported = false;
 					bad = new badmeasure(ERR_GRACE_AFTER, staff_nr, bar_nr_, total / 3, countof128th_);
@@ -1878,18 +1889,18 @@ void NFileHandler::writeVoiceElemsTill(int staff_nr, int voice_nr, NVoice *voi,
 					out_ << staff_nr << " " << voice_nr << ": ";
 				     }
 				     part = elem->getSubType(); 
-				     if (elem->status_ & STAT_TUPLET) {
-					total += elem->getPlaytime() * part / elem->getNumNotes();
+				     if (rest->hasProperty( PROP_TUPLET ) ) {
+					total += rest->getPlaytime() * part / rest->getNumNotes();
 					tupletsum += part;
 				     }
 				     else {
 					total += part;
 				     }
-				     switch (elem->status_ & DOT_MASK) {
+				     switch (rest->properties() & DOT_MASK) {
 					case 1: total += part / 2; break;
 					case 2: total += 3 * part / 4; break;
 				     }
-				     if ((elem->status_ & STAT_TUPLET) && !voi->inTuplet_) {
+				     if ((rest->hasProperty( PROP_TUPLET ) ) && !voi->inTuplet_) {
 					voi->inTuplet_ = true;
 					tupletsum = part;
 					out_ << "{ ";
@@ -1899,21 +1910,21 @@ void NFileHandler::writeVoiceElemsTill(int staff_nr, int voice_nr, NVoice *voi,
 					bad = new badmeasure(ERR_NOTE_COUNT, staff_nr, bar_nr_, total / 3, countof128th_);
 					badlist_.append(bad);
 				     }
-				     if (elem->status_ & STAT_FERMT) {
+				     if (rest->hasProperty( PROP_FERMT ) ) {
 					out_ << "[with ";
 					out_ << "\"\\(ferm)\"";
 					out_ << ']';
 				     }
 				     out_ << WHOLE_LENGTH / part;
-				     switch (elem->status_ & DOT_MASK) {
+				     switch (rest->properties() & DOT_MASK) {
 					case 1:	out_ << "."; break;
 					case 2:	out_ << ".."; break;
 				     }
-				     out_ << ((elem->status_ & STAT_HIDDEN) ? "s; " : "r; ");
-				     if (elem->status_ & STAT_LAST_TUPLET) {
+				     out_ << ((rest->hasProperty( PROP_HIDDEN ) ) ? "s; " : "r; ");
+				     if (rest->hasProperty( PROP_LAST_TUPLET ) ) {
 					voi->inTuplet_ = false;
 					out_ << " } above  " <<
-						computeTripletString(tupletsum, elem->getNumNotes(), elem->getPlaytime(), &ok) << "; ";
+						computeTripletString(tupletsum, rest->getNumNotes(), rest->getPlaytime(), &ok) << "; ";
 					if (!ok) {
 						bad = new badmeasure(ERR_TUPLET, staff_nr, bar_nr_, total / 3, countof128th_);
 						badlist_.append(bad);
@@ -1927,7 +1938,7 @@ void NFileHandler::writeVoiceElemsTill(int staff_nr, int voice_nr, NVoice *voi,
 	if (something_written) out_ << endl;
 }
 	
-bool NFileHandler::readStaffs(const char *fname, QList<NVoice> *voilist, QList<NStaff> *stafflist, NMainFrameWidget *mainWidget) {
+bool NFileHandler::readStaffs(const char *fname, QPtrList<NVoice> *voilist, QPtrList<NStaff> *stafflist, NMainFrameWidget *mainWidget) {
 	FILE *fp;
 	int i;
 	extern int YYRESTART(FILE *fp);
@@ -1936,8 +1947,8 @@ bool NFileHandler::readStaffs(const char *fname, QList<NVoice> *voilist, QList<N
 	int parser_return;
 	NVoice *voice_elem;
 	NStaff *staff_elem;
-	QList<NVoice> newVoices;
-	QList<NStaff> newStaffs;
+	QPtrList<NVoice> newVoices;
+	QPtrList<NStaff> newStaffs;
 	layoutDef *layoutinfo;
 	int staffCount;
 
