@@ -23,6 +23,7 @@
 #include <stdio.h>
 #include <qpainter.h>
 #include <qbitmap.h>
+#include <iostream>
 #include "keysig.h"
 #include "resource.h"
 #include "transpainter.h"
@@ -48,33 +49,35 @@ int NKeySig::nameTab_[7] = {'c', 'd', 'e', 'f', 'g', 'a', 'b'};
 
 char NKeySig::str[128];
 
-NClef NKeySig::defaultClef_(&NResource::nullMainProps_, &NResource::nullprops_);
+NClef NKeySig::defaultClef_(0, &NResource::nullprops_);
 
 
 NKeySig::NKeySig(main_props_str *main_props, staff_props_str *staff_props) :
 	NMusElement(main_props, staff_props) {
+	int i;
+	accents_ = new property_type[7];
+	tempAccents_ = new property_type[MAXLINE-MINLINE+1];
 
-	noteState_ = new char[7];
-	tempNoteState_ = new char[MAXLINE-MINLINE+1];
-
-	memset(noteState_, STAT_NATUR, 7);
-	memset(tempNoteState_, STAT_NO_ACC, MAXLINE-MINLINE+1);
-	stateChanged_ = true;
+	/* clear the accents_ and tempAccents_ arrays to PROP_NATUR and PROP_NO_ACC */
+	for (i=0; i<7; accents_[i++] = PROP_NATUR);
+	for (i=0; i<(MAXLINE-MINLINE+1); tempAccents_[i++]=PROP_NO_ACC);
+	
+	statusChanged_ = true;
 	acClef_ = &defaultClef_;
 	actual_ = false;
 	pixmapWidth_ = 5;
 	resolv_redPixmap_ = resolvPixmap_ = keyPixmap_ = key_redPixmap_ = 0;
-	noSignes_ = true;
+	drawable_ = false;
 	resPixmapWidth_ = resolvOffs_ = 0;
 	computedPreviousKeySig_ = previousKeySig_ = 0;
-	if (staff_props_->base) calculateDimensionsAndPixmaps();
+	calculateDimensionsAndPixmaps();
 }
 
 void NKeySig::change(NKeySig *ksig) {
-	stateChanged_ = true;
+	statusChanged_ = true;
 	NMusElement::change(ksig);
-	memcpy(noteState_, ksig->noteState_, 7);
-	memcpy(tempNoteState_, ksig->noteState_, 7);
+	memcpy(accents_, ksig->accents_, sizeof(property_type)*7);
+	memcpy(tempAccents_, ksig->accents_, sizeof(property_type)*7);
 	acClef_ = ksig->acClef_;
 	actual_ = false;
 	pixmapWidth_ = 5;
@@ -85,7 +88,7 @@ void NKeySig::change(NKeySig *ksig) {
 	resolv_redPixmap_ = resolvPixmap_ = keyPixmap_ = key_redPixmap_ = 0;
 	resPixmapWidth_ = resolvOffs_ = 0;
 	computedPreviousKeySig_ = 0;
-	if (staff_props_->base) calculateDimensionsAndPixmaps();
+	calculateDimensionsAndPixmaps();
 }
 
 void NKeySig::setPreviousKeySig(NKeySig *prevKeySig) {
@@ -93,44 +96,56 @@ void NKeySig::setPreviousKeySig(NKeySig *prevKeySig) {
 } 
 
 bool NKeySig::isEqual(NKeySig *otherKeysig) {
-	int i;
 	if (!otherKeysig) return false;
-	for (i = 0; i < 7; ++i) {
-		if (noteState_[i] != otherKeysig->noteState_[i]) return false;
+	for (int i = 0; i < 7; ++i) {
+		if (accents_[i] != otherKeysig->accents_[i]) return false;
 	}
 	return true;
 }
 
+int NKeySig::getSubType() const {
+	property_type type = PROP_NO_ACC;
+	for( int i = 0; i < 7; i++ ) {
+		if( accents_[ i ] != PROP_NATUR ) {
+			if( type != PROP_NO_ACC && type != accents_[ i ] )
+				return PROP_NO_ACC;
+			type = accents_[ i ];
+		}
+	}
+	return type;
+}
+
 void NKeySig::setClef(NClef * ac_clef) {
 	acClef_ = ac_clef;
 
-	stateChanged_ = true;
+	statusChanged_ = true;
 	if (keyPixmap_) delete keyPixmap_;
 	if (key_redPixmap_) delete key_redPixmap_;
 	keyPixmap_ = 0;
         key_redPixmap_ = 0;
-	if (staff_props_->base) calculateDimensionsAndPixmaps();
+	calculateDimensionsAndPixmaps();
 }
 
 void NKeySig::changeHalfTone(NNote *note) {
-	int notenr = acClef_->line2note(note->line);
-	int kind, count;
-	stateChanged_ = true;
+	int notenr = acClef_->line2NoteNumber(note->line);
+	property_type kind;
+	int count;
+	statusChanged_ = true;
 	switch (note->offs) {
 		case  1: if (isRegular(&kind, &count))  {
-				if (kind == STAT_FLAT) {
+				if (kind == PROP_FLAT) {
 					(note->line)++; note->offs = -1;
 				}
-			 } else if (noteState_[(notenr+1) % 7] == STAT_FLAT) {
+			 } else if (accents_[(notenr+1) % 7] == PROP_FLAT) {
 				(note->line)++; note->offs = -1; 
 			 }
 			 break;
 		case -1: if (isRegular(&kind, &count)) {
-				if (kind == STAT_CROSS) {
+				if (kind == PROP_CROSS) {
 					(note->line)--; note->offs = 1;
 				}
 			 }
-			 else if (noteState_[(notenr+6) % 7] == STAT_CROSS) {
+			 else if (accents_[(notenr+6) % 7] == PROP_CROSS) {
 				(note->line)--; note->offs = 1;
 			 }
 			 break;
@@ -138,73 +153,61 @@ void NKeySig::changeHalfTone(NNote *note) {
 }
 
 NKeySig *NKeySig::clone() {
-	char *tmp1, *tmp2;
+	property_type *tmp1;
+	property_type *tmp2;
 	NKeySig *ckeysig;
 	ckeysig = new NKeySig(main_props_, staff_props_);
 
-	tmp1 = ckeysig->noteState_;
-	tmp2 = ckeysig->tempNoteState_;
+	tmp1 = ckeysig->accents_;
+	tmp2 = ckeysig->tempAccents_;
 
 	*ckeysig = *this;
 
-	ckeysig->noteState_ = tmp1;
-	ckeysig->tempNoteState_ = tmp2;
-	memset(ckeysig->tempNoteState_, STAT_NO_ACC, MAXLINE-MINLINE+1);
-	memcpy(ckeysig->noteState_, noteState_, 7);
+	ckeysig->accents_ = tmp1;
+	ckeysig->tempAccents_ = tmp2;
+
+	/* clear tempAccents_ array with PROP_NO_ACC */
+	for (int i=0; i<(MAXLINE-MINLINE+1); tempAccents_[i++]=PROP_NO_ACC);
+	memcpy(ckeysig->accents_, accents_, sizeof(property_type)*7);
+
 	ckeysig->resolv_redPixmap_ = ckeysig->resolvPixmap_ = ckeysig->keyPixmap_ = ckeysig->key_redPixmap_ = 0;
 	ckeysig->previousKeySig_ = ckeysig->computedPreviousKeySig_ = 0;
 	ckeysig->resolvOffs_ = 0;
-	ckeysig->stateChanged_ = true;
+	ckeysig->statusChanged_ = true;
 
 	return ckeysig;
 }
 
 
 NKeySig::~NKeySig() {
-	delete noteState_;
-	delete tempNoteState_;
+	delete accents_;
+	delete tempAccents_;
 	if (keyPixmap_ != 0) delete keyPixmap_;
 	if (key_redPixmap_ != 0) delete key_redPixmap_;
 	if (resolv_redPixmap_ != 0) delete resolv_redPixmap_; 
 	if (resolvPixmap_ != 0) delete resolvPixmap_;
 }
 
-int NKeySig::line2Range(int line) {
-	int i;
-	if (line < 3) {
-		while (line < 3) line += 7;
-	}
-	else if (line > 9) {
-		while (line > 9) line -= 7;
-	}
-	for (i = 0; i < 7; ++i) {
-		if (acClef_->noteNumber2Line(i) == line) return i;
-		
-	}
-	NResource::abort("line2Range: internal error");
-	return 0;
-}
-
 #ifdef KEYSIG_DEBUG
 void NKeySig::print() {
 	int i;
 	printf("stat: ");
 	for (i = 0; i < 7; ++i) {
-		switch (noteState_[i]) {
-			case STAT_CROSS: printf("#");break;
-			case STAT_FLAT: printf("&");break;
-			case STAT_NATUR: printf("n");break;
-			case STAT_NO_ACC: printf(".");break;
+		switch (accents_[i]) {
+			case PROP_CROSS: printf("#");break;
+			case PROP_FLAT: printf("&");break;
+			case PROP_NATUR: printf("n");break;
+			case PROP_NO_ACC: printf(".");break;
 			default: printf("?"); break;
 		}
 	}
 	printf("; tmp: ");
 	for (i = 0; i < 7; ++i) {
-		switch (tempNoteState_[i]) {
-			case STAT_CROSS: printf("#");break;
-			case STAT_FLAT: printf("&");break;
-			case STAT_NATUR: printf("n");break;
-			case STAT_NO_ACC: printf(".");break;
+		switch (tempAccents_[i]) {
+			case PROP_CROSS: printf("#");break;
+			case PROP_FLAT: printf("&");break;
+			case PROP_NATUR: printf("n");break;
+			case PROP_NO_ACC: printf(".");break;
 			default: printf("?"); break;
 		}
 	}
@@ -220,62 +223,69 @@ void NKeySig::print() {
 }
 #endif
 
-int NKeySig::computeOffs(int line) {
-	int pp, idx, state;
+int NKeySig::getOffset(int line) {
+	int pp, idx;
+	property_type status;
 
 	idx = LINE2TABIDX(line);
-	if ((state = tempNoteState_[idx]) == STAT_NO_ACC) {
-		pp = line2Range(line);
-		state = noteState_[pp];
+	if ((status = tempAccents_[idx]) == PROP_NO_ACC) {
+		pp = acClef_->line2NoteNumber(line);
+		status = accents_[pp];
 	}
-	switch (state) {
-		case STAT_CROSS: return 1; break;
-		case STAT_FLAT: return -1; break;
-		case STAT_DCROSS: return 2; break;
-		case STAT_DFLAT: return -2; break;
+	switch (status) {
+		case PROP_CROSS: return 1; break;
+		case PROP_FLAT: return -1; break;
+		case PROP_DCROSS: return 2; break;
+		case PROP_DFLAT: return -2; break;
 	}
 	return 0;
 }
 
 int NKeySig::determineDistanceUp(NNote *note) {
 	int midival1, midival2, offs2, line2;
-	midival1 = acClef_->line2midiTab_[note->line+LINE_OVERFLOW]+note->offs;
+	midival1 = acClef_->line2Midi( note->line, note->offs );
 	line2 = note->line+1;
-	offs2 = computeOffs(line2);
-	midival2 = acClef_->line2midiTab_[note->line+1+LINE_OVERFLOW]+offs2;
+	offs2 = getOffset(line2);
+	midival2 = acClef_->line2Midi( line2, offs2 );
 	return midival2 - midival1;
 }
 
 	
 
-int NKeySig::accNeeded(int line, int offs) {
-	int note, state, idx;
+property_type NKeySig::accentNeeded(int line, int offs) {
+	int note, idx;
+	property_type status;
 
 	idx = LINE2TABIDX(line);
-	if ((state = tempNoteState_[idx]) == STAT_NO_ACC) {
-		note = line2Range(line);
-		state = noteState_[note]; 
+	if ((status = tempAccents_[idx]) == PROP_NO_ACC) {
+		note = acClef_->line2NoteNumber(line);
+		status = accents_[note]; 
 	}
-	if (offs == -1 && state == STAT_FLAT) return STAT_NO_ACC;
-	if (offs ==  1 && state == STAT_CROSS) return STAT_NO_ACC;
-	if (offs == -2 && state == STAT_DFLAT) return STAT_NO_ACC;
-	if (offs ==  2 && state == STAT_DCROSS) return STAT_NO_ACC;
-	if (offs ==  0 && (state == STAT_FLAT || state == STAT_CROSS || state == STAT_DCROSS || state == STAT_DFLAT)) return STAT_NATUR;
-	if (offs ==  1) return STAT_CROSS;
-	if (offs == -1) return STAT_FLAT;
-	if (offs ==  2) return STAT_DCROSS;
-	if (offs == -2) return STAT_DFLAT;
-	return STAT_NO_ACC;
+	if (offs == -1 && status == PROP_FLAT) return PROP_NO_ACC;
+	if (offs ==  1 && status == PROP_CROSS) return PROP_NO_ACC;
+	if (offs == -2 && status == PROP_DFLAT) return PROP_NO_ACC;
+	if (offs ==  2 && status == PROP_DCROSS) return PROP_NO_ACC;
+	if (offs ==  0 && (status == PROP_FLAT || status == PROP_CROSS || status == PROP_DCROSS || status == PROP_DFLAT)) return PROP_NATUR;
+	if (offs ==  1) return PROP_CROSS;
+	if (offs == -1) return PROP_FLAT;
+	if (offs ==  2) return PROP_DCROSS;
+	if (offs == -2) return PROP_DFLAT;
+	return PROP_NO_ACC;
 }
 
-void NKeySig::resetAtBar() {
-	memset(tempNoteState_, STAT_NO_ACC, MAXLINE-MINLINE+1);
+void NKeySig::deleteTempAccents() {
+	/* clear tempAccents_ array to PROP_NO_ACC */
+	for (int i=0; i<(MAXLINE-MINLINE+1); tempAccents_[i++]=PROP_NO_ACC);
 }
 	
 void NKeySig::reset() {
-	stateChanged_ = true;
-	memset(noteState_, STAT_NATUR, 7); 
-	memset(tempNoteState_, STAT_NO_ACC, MAXLINE-MINLINE+1); 
+	statusChanged_ = true;
+	int i;
+
+	/* clear the accents_ and tempAccents_ arrays to PROP_NATUR and PROP_NO_ACC */
+	for (i=0; i<7; accents_[i++] = PROP_NATUR);
+	for (i=0; i<(MAXLINE-MINLINE+1); tempAccents_[i++]=PROP_NO_ACC);
+
 	if (keyPixmap_) delete keyPixmap_;
 	if (key_redPixmap_) delete key_redPixmap_;
 	keyPixmap_ = 0;
@@ -283,106 +293,106 @@ void NKeySig::reset() {
 	acClef_ = &defaultClef_;
 }
 
-int NKeySig::getState(int note) {
+	
+void NKeySig::setTempAccent(int line, property_type kind) {
+	tempAccents_[LINE2TABIDX(line)] = kind;
+	
+}
+
+property_type NKeySig::getAccent(int note) {
 	if (note < 0 || note > 6) {
-		NResource::abort("getState: internal error");
+		NResource::abort("getAccent(): internal error");
 	}
-	return noteState_[note];
+	return accents_[note];
 }
 
-	
-void NKeySig::setTempAcc(int line, int kind) {
-	tempNoteState_[LINE2TABIDX(line)] = kind;
-	
-}
-
-void NKeySig::setKey(int note, int kind) {
+void NKeySig::setAccent(int note, property_type kind) {
 	if (note < 0 || note > 7) {
-		NResource::abort("setKey: internal error");
+		NResource::abort("setAccent(): internal error");
 	}
-	noteState_[note] = kind;
+	accents_[note] = kind;
 	if (keyPixmap_) delete keyPixmap_;
 	if (key_redPixmap_) delete key_redPixmap_;
 	keyPixmap_ = 0;
         key_redPixmap_ = 0;
 }
 
-void NKeySig::setRegular(int count, int kind) {
+void NKeySig::setRegular(int count, property_type kind) {
 	int i, *tab;
 	if (count > 7) return;
-	stateChanged_ = true;
+	statusChanged_ = true;
 	reset();
 	switch (kind) {
-		case STAT_CROSS: tab = crossTab_;
+		case PROP_CROSS: tab = crossTab_;
 				  break;
-		case STAT_FLAT:  tab = flatTab_;
+		case PROP_FLAT:  tab = flatTab_;
 				  break;
-		default: NResource::abort("setRegular: unknown kind");
+		default: NResource::abort("setRegular(): unknown kind");
+				  return; // eliminate warnings
 	}
-	for (i = 0; i < count; ++i) {
-		noteState_[tab[i]] = kind;
-	}
-	if (staff_props_->base) calculateDimensionsAndPixmaps();
+	for (i = 0; i < count; ++i)
+		accents_[tab[i]] = kind;
+	calculateDimensionsAndPixmaps();
 }
 
-int NKeySig::accCount() {
+int NKeySig::accentCount() {
 	int i, count = 0;
 
 	for (i = 0; i < 7; ++i) {
-		if (noteState_[i] != STAT_NATUR) count++;
+		if (accents_[i] != PROP_NATUR) count++;
 	}
 	return count;
 }
 
-bool NKeySig::isRegular(int *kind, int *count) {
+bool NKeySig::isRegular(property_type *kind, int *count) {
 	bool ok[7];
 	int i;
-	*kind = STAT_NO_ACC;
+	*kind = PROP_NO_ACC;
 	*count = 0;
 
-	if (accCount() == 0)  return true;
+	if (accentCount() == 0)  return true;
 
 	for (i = 0; i < 7; ok[i++] = false);
 
 	for (i = 0; i < 7; ++i) {
-		if (noteState_[i] != STAT_NATUR) {
+		if (accents_[i] != PROP_NATUR) {
 			(*count)++;
 			ok[i] = true;
-			if (*kind == STAT_NO_ACC) {
-				*kind = noteState_[i];
+			if (*kind == PROP_NO_ACC) {
+				*kind = accents_[i];
 			}
-			else if (*kind != noteState_[i]) return false;
+			else if (*kind != accents_[i]) return false;
 		}
 	}
 	switch (*kind) {
-		case STAT_CROSS:
+		case PROP_CROSS:
 			for (i = 0; i < *count; ++i) {
 				if (!ok[crossTab_[i]]) return false;
 			}
 			return true;
-		case STAT_FLAT:
+		case PROP_FLAT:
 			for (i = 0; i < *count; ++i) {
 				if (!ok[flatTab_[i]]) return false;
 			}
 			return true;
-		case STAT_NO_ACC:
-		case STAT_NATUR: return false;
-		default: NResource::abort("isRegular: internal error");
+		case PROP_NO_ACC:
+		case PROP_NATUR: return false;
+		default: NResource::abort("isRegular(): internal error");
 	}
 	return false;
 }
 
-char *NKeySig::printKeys() {
+char *NKeySig::toString() {
 	char *cptr;
 	int i;
 	cptr = NKeySig::str;
 	for (i = 0; i < 7; ++i) {
-		switch (noteState_[i]) {
-			case STAT_CROSS: *cptr++ = nameTab_[i];
+		switch (accents_[i]) {
+			case PROP_CROSS: *cptr++ = nameTab_[i];
 				      *cptr++ = '#';
 				      *cptr++ = ' ';
 				      break;
-			case STAT_FLAT:  *cptr++ = nameTab_[i];
+			case PROP_FLAT:  *cptr++ = nameTab_[i];
 				      *cptr++ = '&';
 				      *cptr++ = ' ';
 				      break;
@@ -392,21 +402,18 @@ char *NKeySig::printKeys() {
 	return NKeySig::str;
 }
 
-void NKeySig::addSign(int kind, char pitch) {
-	int i;
-	bool found = false;
-	stateChanged_ = true;
-	i = 0;
-	while (!found && i < 7) {
-		if (!(found = pitch == nameTab_[i])) ++i;
-	}
-	if (!found) return;
-	noteState_[i] = kind;
+void NKeySig::setAccentByNoteName(char pitch, property_type kind) {
+	for( int i=0; i < 7; i++ )
+		if( pitch == nameTab_[i] ) {
+			setAccent(i, kind );
+			return;
+		}
 }
 
 void NKeySig::calculateDimensionsAndPixmaps() {
-	int kind, count;
-	int i, j, *tab;
+	property_type kind;
+	int count;
+	int i, j;
 	int draw_offs;
 	bool noSignesInPrevKey = true;
 	QPainter painter;
@@ -423,10 +430,14 @@ void NKeySig::calculateDimensionsAndPixmaps() {
 
 	if (previousKeySig_ != computedPreviousKeySig_) {
 		computedPreviousKeySig_ = previousKeySig_;
-		if (previousKeySig_ && !isEqual(previousKeySig_) && previousKeySig_->accCount() != 0) {
-			stateChanged_ = true;
+		int naturKeyCount = 0;
+		for( i=0; i != 7; i++ )
+			if( accents_[ i ] != previousKeySig_->accents_[ i ] && previousKeySig_->accents_[ i ] != PROP_NATUR )
+				naturKeyCount++;
+		if (previousKeySig_ && !isEqual(previousKeySig_) && naturKeyCount != 0) {
+			statusChanged_ = true;
 			resPixmapWidth_ = NResource::naturPixmap_->width();
-			resPixmapWidth_ += SIGN_DIST * previousKeySig_->accCount();
+			resPixmapWidth_ += SIGN_DIST * naturKeyCount;
 			resolvOffs_ = resPixmapWidth_;
 
 			if (resolvPixmap_) delete resolvPixmap_;
@@ -437,18 +448,14 @@ void NKeySig::calculateDimensionsAndPixmaps() {
 			if (previousKeySig_->isRegular(&kind, &count)) {
 				if (count) noSignesInPrevKey = false;
 				draw_offs = NATUR_DRAW_OFFS;
-				if (kind == STAT_CROSS) {
-					tab = crossTab_;
-				}
-				else {
-					tab = flatTab_;
-				}
 				painter.begin(resolvPixmap_);
 				painter.setPen(NResource::noPen_);
 				painter.setBrush(NResource::backgroundBrush_);
 				painter.fillRect(0, 0, resPixmapWidth_, PIXMAP_HEIGHT, NResource::backgroundBrush_);
-				for (i = 0; i < count; ++i) {
-					painter.drawPixmap(i*SIGN_DIST,4*LINE_DIST+draw_offs-acClef_->getAccPos(kind, i)*LINE_DIST/2, *NResource::naturPixmap_);
+				for (i = j = 0; i < count; ++i) {
+					int note = ( kind == PROP_FLAT ) ? flatTab_[ i ] : crossTab_[ i ];
+					if( accents_[ note ] != previousKeySig_->accents_[ note ] && previousKeySig_->accents_[ note ] != PROP_NATUR )
+						painter.drawPixmap(j++*SIGN_DIST,4*LINE_DIST+draw_offs-acClef_->getAccPos(kind, i)*LINE_DIST/2, *NResource::naturPixmap_);
 				}
 				painter.end();
 		
@@ -456,8 +463,10 @@ void NKeySig::calculateDimensionsAndPixmaps() {
 				painter.setPen(NResource::noPen_);
 				painter.setBrush(NResource::backgroundBrush_);
 				painter.fillRect(0, 0, resPixmapWidth_, PIXMAP_HEIGHT, NResource::backgroundBrush_);
-				for (i = 0; i < count; ++i) {
-					painter.drawPixmap(i*SIGN_DIST,4*LINE_DIST+draw_offs-acClef_->getAccPos(kind, i)*LINE_DIST/2, *NResource::naturPixmap_);
+				for (i = j = 0; i < count; ++i) {
+					int note = ( kind == PROP_FLAT ) ? flatTab_[ i ] : crossTab_[ i ];
+					if( accents_[ note ] != previousKeySig_->accents_[ note ] && previousKeySig_->accents_[ note ] != PROP_NATUR )
+						painter.drawPixmap(j++*SIGN_DIST,4*LINE_DIST+draw_offs-acClef_->getAccPos(kind, i)*LINE_DIST/2, *NResource::naturPixmap_);
 				}
 			
 				painter.end();
@@ -467,17 +476,11 @@ void NKeySig::calculateDimensionsAndPixmaps() {
 				painter.setPen(NResource::noPen_);
 				painter.setBrush(NResource::backgroundBrush_);
 				painter.fillRect(0, 0, resPixmapWidth_, PIXMAP_HEIGHT, NResource::backgroundBrush_);
+				draw_offs = NATUR_DRAW_OFFS;
 				for (j = 0, i = 0; i < 7; ++i) {
-					draw_offs = NATUR_DRAW_OFFS;
-					if (noteState_[i] == STAT_NATUR) continue;
-					if (noteState_[i] == STAT_CROSS) {
-						tab = crossTab_;
-						noSignesInPrevKey = false;
-					}
-					else {
-						tab = flatTab_;
-						noSignesInPrevKey = false;
-					}
+					if (previousKeySig_->accents_[i] == PROP_NATUR) continue;
+					noSignesInPrevKey = false;
+					if (previousKeySig_->accents_[i] == accents_[ i ] ) continue;
 					painter.drawPixmap(j++*SIGN_DIST,4*LINE_DIST+draw_offs-acClef_->noteNumber2Line(i)*LINE_DIST/2, *NResource::naturPixmap_);
 				}
 				painter.end();
@@ -487,7 +490,8 @@ void NKeySig::calculateDimensionsAndPixmaps() {
 				painter.setBrush(NResource::backgroundBrush_);
 				painter.fillRect(0, 0, resPixmapWidth_, PIXMAP_HEIGHT, NResource::backgroundBrush_);
 				for (j = 0, i = 0; i < 7; ++i) {
-					if (noteState_[i] == STAT_NATUR) continue;
+					if (previousKeySig_->accents_[i] == PROP_NATUR) continue;
+					if (previousKeySig_->accents_[i] == accents_[ i ] ) continue;
 					painter.drawPixmap(j++*SIGN_DIST,4*LINE_DIST+draw_offs-acClef_->noteNumber2Line(i)*LINE_DIST/2, *NResource::naturPixmap_);
 				}
 				painter.setPen(NResource::blackWidePen_);
@@ -507,11 +511,11 @@ void NKeySig::calculateDimensionsAndPixmaps() {
 		}
 	}
 
-	if (stateChanged_) {
-		stateChanged_ = false;
-		if (accCount() != 0) {
+	if (statusChanged_) {
+		statusChanged_ = false;
+		if (accentCount() != 0) {
 			pixmapWidth_ = NResource::crossPixmap_->width();
-			pixmapWidth_ += SIGN_DIST * accCount();
+			pixmapWidth_ += SIGN_DIST * accentCount();
 		
 			if (keyPixmap_) delete keyPixmap_;
 			if (key_redPixmap_) delete key_redPixmap_;
@@ -519,15 +523,13 @@ void NKeySig::calculateDimensionsAndPixmaps() {
 			key_redPixmap_ = new QPixmap(pixmapWidth_, PIXMAP_HEIGHT);
 		
 			if (isRegular(&kind, &count)) {
-				noSignes_ = count == 0;
-				if (kind == STAT_CROSS) {
+				drawable_ = count != 0;
+				if (kind == PROP_CROSS) {
 					pix = NResource::crossPixmap_;
-					tab = crossTab_;
 					draw_offs = CROSS_DRAW_OFFS;
 				}
 				else {
 					pix = NResource::flatPixmap_;
-					tab = flatTab_;
 					draw_offs = FLAT_DRAW_OFFS;
 				}
 				painter.begin(keyPixmap_);
@@ -539,7 +541,7 @@ void NKeySig::calculateDimensionsAndPixmaps() {
 				}
 				painter.end();
 		
-				pix = (kind == STAT_CROSS) ?  NResource::crossRedPixmap_ : NResource::flatRedPixmap_;
+				pix = (kind == PROP_CROSS) ?  NResource::crossRedPixmap_ : NResource::flatRedPixmap_;
 				painter.begin(key_redPixmap_);
 				painter.setPen(NResource::noPen_);
 				painter.setBrush(NResource::backgroundBrush_);
@@ -555,20 +557,18 @@ void NKeySig::calculateDimensionsAndPixmaps() {
 				painter.setPen(NResource::noPen_);
 				painter.setBrush(NResource::backgroundBrush_);
 				painter.fillRect(0, 0, pixmapWidth_, PIXMAP_HEIGHT, NResource::backgroundBrush_);
-				noSignes_ = true;
+				drawable_ = false;
 				for (j=0, i = 0; i < 7; ++i) {
-					if (noteState_[i] == STAT_NATUR) continue;
-					if (noteState_[i] == STAT_CROSS) {
+					if (accents_[i] == PROP_NATUR) continue;
+					if (accents_[i] == PROP_CROSS) {
 						pix = NResource::crossPixmap_;
-						tab = crossTab_;
 						draw_offs = CROSS_DRAW_OFFS;
-						noSignes_ = false;
+						drawable_ = true;
 					}
 					else {
 						pix = NResource::flatPixmap_;
-						tab = flatTab_;
 						draw_offs = FLAT_DRAW_OFFS;
-						noSignes_ = false;
+						drawable_ = true;
 					}
 					painter.drawPixmap(j++*SIGN_DIST,4*LINE_DIST+draw_offs-acClef_->noteNumber2Line(i)*LINE_DIST/2, *pix);
 				}
@@ -579,8 +579,9 @@ void NKeySig::calculateDimensionsAndPixmaps() {
 				painter.setBrush(NResource::backgroundBrush_);
 				painter.fillRect(0, 0, pixmapWidth_, PIXMAP_HEIGHT, NResource::backgroundBrush_);
 				for (j = 0, i = 0; i < 7; ++i) {
-					if (noteState_[i] == STAT_NATUR) continue;
-					pix = (noteState_[i] == STAT_CROSS) ? NResource::crossRedPixmap_ : NResource::flatRedPixmap_;
+					if (accents_[i] == PROP_NATUR) continue;
+					pix = (accents_[i] == PROP_CROSS) ? NResource::crossRedPixmap_ : NResource::flatRedPixmap_;
+					draw_offs = (accents_[i] == PROP_CROSS) ? CROSS_DRAW_OFFS : FLAT_DRAW_OFFS;
 					painter.drawPixmap(j++*SIGN_DIST,4*LINE_DIST+draw_offs-acClef_->noteNumber2Line(i)*LINE_DIST/2, *pix);
 				}
 				painter.setPen(NResource::blackWidePen_);
@@ -600,11 +601,11 @@ void NKeySig::calculateDimensionsAndPixmaps() {
 			pixmapWidth_ = 0;
 		}
 	}
-	noSignes_ = noSignes_ && noSignesInPrevKey;
+	drawable_ = drawable_ || !noSignesInPrevKey;
 }
 
 void NKeySig::draw(int /* dummy */) {
-	if (noSignes_) return;
+	if (!drawable_) return;
 	main_props_->tp->beginTranslated();
 	if (resolvPixmap_) {
 		main_props_->tp->drawPixmap(resolvDrawPoint_, actual_ ?  *resolv_redPixmap_ : *resolvPixmap_);
@@ -618,29 +619,24 @@ void NKeySig::draw(int /* dummy */) {
 /* ------------------------------- methods for context keysig ------------------------------------------*/
 
 void NKeySig::drawContextKeySig() {
-	if (noSignes_) return;
+	if (!drawable_) return;
 	main_props_->tp->beginUnclippedYtranslated();
 	main_props_->tp->drawPixmap(main_props_->context_keysig_xpos, nbaseDrawPoint_.y(), *keyPixmap_);
 	main_props_->tp->end();
 }
 
-void NKeySig::setClefInContextKeysig(NClef * ac_clef) {
-	acClef_ = ac_clef;
-
-	if (staff_props_->base) calculateContextPixmap();
-}
-
 void NKeySig::changeInContextKeySig(NKeySig *ksig) {
 	NMusElement::change(ksig);
 	acClef_ = ksig->acClef_;
-	memcpy(noteState_, ksig->noteState_, 7);
+	memcpy(accents_, ksig->accents_, sizeof(property_type)*7);
 	pixmapWidth_ = 5;
 	if (staff_props_->base) calculateContextPixmap();
 }
 
 void NKeySig::calculateContextPixmap() { /* for faster computation of context key */
-	int kind, count;
-	int i, j, *tab;
+	property_type kind;
+	int count;
+	int i, j;
 	int draw_offs;
 	QPainter painter;
 	QPixmap *pix;
@@ -650,22 +646,20 @@ void NKeySig::calculateContextPixmap() { /* for faster computation of context ke
 	nbaseDrawPoint_ = QPoint (xpos_+resolvOffs_, staff_props_->base-Y_BORDER_UP);
 	bbox_ = QRect(xpos_, staff_props_->base , pixmapWidth_, PIXMAP_HEIGHT);
 
-	if (accCount() == 0) {noSignes_ = true; return;}
+	if (accentCount() == 0) {drawable_ = false; return;}
 	pixmapWidth_ = NResource::crossPixmap_->width();
-	pixmapWidth_ += SIGN_DIST * accCount();
+	pixmapWidth_ += SIGN_DIST * accentCount();
 	
 	keyPixmap_ = new QPixmap(pixmapWidth_, PIXMAP_HEIGHT);
 	
 	if (isRegular(&kind, &count)) {
-		noSignes_ = count == 0;
-		if (kind == STAT_CROSS) {
+		drawable_ = count != 0;
+		if (kind == PROP_CROSS) {
 			pix = NResource::crossPixmap_;
-			tab = crossTab_;
 			draw_offs = CROSS_DRAW_OFFS;
 		}
 		else {
 			pix = NResource::flatPixmap_;
-			tab = flatTab_;
 			draw_offs = FLAT_DRAW_OFFS;
 		}
 		painter.begin(keyPixmap_);
@@ -682,20 +676,18 @@ void NKeySig::calculateContextPixmap() { /* for faster computation of context ke
 		painter.setPen(NResource::noPen_);
 		painter.setBrush(NResource::backgroundBrush_);
 		painter.fillRect(0, 0, pixmapWidth_, PIXMAP_HEIGHT, NResource::backgroundBrush_);
-		noSignes_ = true;
+		drawable_ = false;
 		for (j=0, i = 0; i < 7; ++i) {
-			if (noteState_[i] == STAT_NATUR) continue;
-			if (noteState_[i] == STAT_CROSS) {
+			if (accents_[i] == PROP_NATUR) continue;
+			if (accents_[i] == PROP_CROSS) {
 				pix = NResource::crossPixmap_;
-				tab = crossTab_;
 				draw_offs = CROSS_DRAW_OFFS;
-				noSignes_ = false;
+				drawable_ = true;
 			}
 			else {
 				pix = NResource::flatPixmap_;
-				tab = flatTab_;
 				draw_offs = FLAT_DRAW_OFFS;
-				noSignes_ = false;
+				drawable_ = true;
 			}
 			painter.drawPixmap(j++*SIGN_DIST,4*LINE_DIST+draw_offs-acClef_->noteNumber2Line(i)*LINE_DIST/2, *pix);
 		}
