@@ -50,7 +50,7 @@
 #define TEXTOFFS  (2*STAFF_LINE_DIST)
 
 
-NStaffLayout::NStaffLayout(int staffCount, layoutDef *braceMatrix, layoutDef *bracketMatrix, layoutDef *barCont, QList<NStaff> *stafflist, QWidget *parent, char *name) :
+NStaffLayout::NStaffLayout(int staffCount, layoutDef *braceMatrix, layoutDef *bracketMatrix, layoutDef *barCont, QPtrList<NStaff> *stafflist, QWidget *parent, char *name) :
 	QDialog(parent, name), 
 	quit_("Ok", this), cancel_(i18n ("Cancel"), this), brace_(i18n ("Set brace"), this), bracket_(i18n ("Set bracket"), this), bar_ ( i18n ("Continue bar"), this),
 	rembrace_( i18n ("Remove brace"), this), rembracket_(i18n("Remove bracket"), this), rembar_ ( i18n ("Discontinue bar"), this),
@@ -302,6 +302,7 @@ void NStaffLayout::slSetBrace() {
 			}
 		}
 	}
+	
 	for (i = 0; i < staffCount_; i++) {
 		if (!localBracketMatrix_[i].valid) continue;
 		if (minh_ >= localBracketMatrix_[i].beg && minh_ <= localBracketMatrix_[i].end && maxh_ > localBracketMatrix_[i].end ||
@@ -312,6 +313,7 @@ void NStaffLayout::slSetBrace() {
 			}
 		}
 	}
+	
 	for (i = 0; i < staffCount_; i++) {
 		if (!localBraceMatrix_[i].valid) {
 			localBraceMatrix_[i].beg = minh_;
@@ -321,6 +323,7 @@ void NStaffLayout::slSetBrace() {
 			return;
 		}
 	}
+	
 	NResource::abort("slSetBrace: internal error");
 }
 
@@ -330,7 +333,8 @@ void NStaffLayout::slSetBracket() {
 	if (!selRectValid_) return;
 	if (minh_ == LAYOUT_MANY) return;
 	if (maxh_ == -LAYOUT_MANY) return;
-
+	if (maxh_ - minh_ < 1) return;	
+	
 	for (i = 0; i < staffCount_; i++) {
 		if (!localBracketMatrix_[i].valid) continue;
 		if (localBracketMatrix_[i].end >= minh_ && localBracketMatrix_[i].end <= maxh_ || localBracketMatrix_[i].beg >= minh_ && localBracketMatrix_[i].beg <= maxh_ ||
@@ -341,16 +345,15 @@ void NStaffLayout::slSetBracket() {
 			}
 		}
 	}
+	
+	/* if brace is found crossing the bracket, remove it. If inside it, or not related at all, leave it. */
 	for (i = 0; i < staffCount_; i++) {
 		if (!localBraceMatrix_[i].valid) continue;
-		if (minh_ >= localBraceMatrix_[i].beg && minh_ <= localBraceMatrix_[i].end && maxh_ > localBraceMatrix_[i].end ||
-		    maxh_ >= localBraceMatrix_[i].beg && maxh_ <= localBraceMatrix_[i].end && minh_ < localBraceMatrix_[i].beg) {
-			localBraceMatrix_[i].end = minh_ - 1;
-			if (localBraceMatrix_[i].end <= localBraceMatrix_[i].beg) {
+		if (!( minh_ <= localBraceMatrix_[i].beg && maxh_ >= localBraceMatrix_[i].end ||
+		       maxh_ < localBraceMatrix_[i].beg || minh_ > localBraceMatrix_[i].end ))
 				localBraceMatrix_[i].valid = false;
-			}
-		}
 	}
+	
 	for (i = 0; i < staffCount_; i++) {
 		if (!localBracketMatrix_[i].valid) {
 			localBracketMatrix_[i].beg = minh_;
@@ -360,8 +363,7 @@ void NStaffLayout::slSetBracket() {
 			return;
 		}
 	}
-	NResource::abort("slSetBracket: internal error");
-			
+	NResource::abort("slSetBracket: internal error");			
 }
 
 void NStaffLayout::slContBar() {
@@ -371,6 +373,7 @@ void NStaffLayout::slContBar() {
 	if (minh_ == LAYOUT_MANY) return;
 	if (maxh_ == -LAYOUT_MANY) return;
 	if (maxh_ - minh_ < 1) return;
+	
 	for (i = 0; i < staffCount_; i++) {
 		if (!localBarCont_[i].valid) continue;
 		if (localBarCont_[i].end >= minh_ && localBarCont_[i].end <= maxh_ || localBarCont_[i].beg >= minh_ && localBarCont_[i].beg <= maxh_ ||
@@ -381,6 +384,7 @@ void NStaffLayout::slContBar() {
 			}
 		}
 	}
+	
 	for (i = 0; i < staffCount_; i++) {
 		if (!localBarCont_[i].valid) {
 			localBarCont_[i].beg = minh_;
@@ -390,6 +394,7 @@ void NStaffLayout::slContBar() {
 			return;
 		}
 	}
+	
 	NResource::abort("slContBar: internal error");
 }
 	
