@@ -27,7 +27,9 @@
 #include <sys/time.h>
 #include <qtimer.h>
 #include <qthread.h>
+#ifndef WITH_SCONS
 #include "config.h"
+#endif
 #include <kmainwindow.h>
 #include <kaction.h>
 #if QT_VERSION >= 300
@@ -39,7 +41,7 @@
 #include "tempotrack.h"
 
 #define COUNT_OFFSBUTTONS 5
-#define COUNT_CHORDBUTTONS 13
+#define COUNT_CHORDBUTTONS 12
 
 class NMidiMapper;
 class NVoice;
@@ -68,6 +70,7 @@ class QPushButton;
 class NChordDiagram;
 class ChordSelector;
 class tupletDialogImpl;
+class NPreviewPrint;
 
 #ifdef WITH_TSE3
 #include <tse3/PhraseEdit.h>
@@ -83,6 +86,7 @@ class KRadioAction;
 class scaleFrm;
 class staffPropFrm;
 class exportFrm;
+class saveParametersFrm;
 class QSlider;
 class QCheckBox;
 class NMusElement;
@@ -116,11 +120,12 @@ class NMainFrameWidget : public QWidget
 		bool loadFile( const QString & fileName );
 		void readStaffsFromXMLFile( const char *fname );
 		void setEdited(bool = true);
+		void setSelectedSign(int type) {selectedSign_ = type;}; // Set the current selected sign to sign type
 		void reloadRecentFileList();
 		void synchronizeRecentFiles();
 		void processMouseEvent(QMouseEvent * evt);
 		void processMoveEvent(QMouseEvent * evt);
-		void processWeelEvent(QWheelEvent * e );
+		void processWheelEvent(QWheelEvent * e );
 		void stopTimer() {autoscrollTimer_.stop();}
 		void generateClef(int type, int shift);
 		void createTuplet(char numNotes, char playtime);
@@ -148,7 +153,7 @@ class NMainFrameWidget : public QWidget
 		void setWithMeasureNums(bool with);
 		QString scTitle_, scSubtitle_, scAuthor_, scLastAuthor_, scCopyright_, scComment_;
 
-		QList<NMusElement> *getClipBoard(int clipBoardNr);
+		QPtrList<NMusElement> *getClipBoard(int clipBoardNr);
 		main_props_str main_props_;
 		void exportMusixTeXImm();
 		void exportLilyPondImm();
@@ -190,7 +195,6 @@ class NMainFrameWidget : public QWidget
 		virtual void paintEvent( QPaintEvent * );
 	private slots:
 /*-------------------------- reaction on pushbutton events ----------------------------- */
-		void setToSelect(bool on);
 		void setToDFull(bool on);
 		void setToFull(bool on);
 		void setToHalf(bool on);
@@ -200,9 +204,9 @@ class NMainFrameWidget : public QWidget
 		void setToN32(bool on);
 		void setToN64(bool on);
 		void setToN128(bool on);
-		void setToTN8(bool on);
-		void setToTN16(bool on);
-		void setToTNS8(bool on);
+		void setToGN8(bool on);
+		void setToGN16(bool on);
+		void setToGNS8(bool on);
 		void setDotted(bool);
 		void setDDotted(bool);
 		void setActualTied(bool);
@@ -234,6 +238,7 @@ class NMainFrameWidget : public QWidget
 		void setNatur(bool);
 		void setStemUp(bool);
 		void setStemDown(bool);
+		void setSelectMode();
 		void setEditMode(bool);
 		void allowKbInsert(bool);
 		void setKbMode(bool);
@@ -268,11 +273,8 @@ class NMainFrameWidget : public QWidget
 		void fileOpenRecent(const KURL &);
 		void fileSave();
 		void fileSaveAs();
-/*------------------------------ printing--------------------------------------------*/
-    void filePrint(bool);  // Jorge Windmeisser Oliver
-    void filePrintPreview();
-    void filePrintNoPreview();
-/*-----------------------------------------------------------------------------------*/        
+	    void filePrintPreview();
+	    void filePrintNoPreview();
 		void exportMusiXTeX();
 		void exportPMX();
 		void exportABC();
@@ -313,6 +315,7 @@ class NMainFrameWidget : public QWidget
 		void insertLine();
 		void insertText();
 		void clefDialog();
+		void specialBarlineDialog();
 		void changeClefDialog();
 		void redAccidentals();
 		void collChords();
@@ -332,9 +335,11 @@ class NMainFrameWidget : public QWidget
 		void KE_moveRight();
 		void KE_delete();
 		void KE_play();
+		void KE_leaveCurrentMode();
 		void KE_edit();
 		void KE_insertnote();
 		void KE_insertchordnote();
+		void KE_0();
 		void KE_1();
 		void KE_2();
 		void KE_3();
@@ -344,19 +349,29 @@ class NMainFrameWidget : public QWidget
 		void KE_7();
 		void KE_8();
 		void KE_9();
+		void KE_voice1();
+		void KE_voice2();
+		void KE_voice3();
+		void KE_voice4();
+		void KE_voice5();
+		void KE_voice6();
+		void KE_voice7();
+		void KE_voice8();
+		void KE_voice9();
 		void KE_tie();
 		void KE_dot();
 		void KE_flat();
 		void KE_sharp();
 		void KE_natural();
 		void KE_bar();
+		void KE_barDialog();
 		void KE_remove();
 		void KE_removechordnote();
 		void KE_tab();
-		void KE_space();
+		void KE_insertRest();
 		void KE_underscore();
-		void KE_keybordInsert();
-
+		void KE_keyboardInsert();
+		
 /*------------------------- "note" keys -----------------------------------------------*/
 
 		void KE_pitch_C();
@@ -379,8 +394,8 @@ class NMainFrameWidget : public QWidget
 		void changeKey(int idx);
 
 /*-------------------------- reaction on scroll events ---------------------------------*/
-		void xscrollFromWidget(int val);
-		void yscroll(int val);
+		inline void xscroll(int val, bool _repaint = true);
+		inline void yscroll(int val, bool _repaint = true);
 		void trillLengthChanged(int val); // located in mainframewidget2.cpp
 		void trillDisabled();
 		void dynamicPosChanged(int val);
@@ -395,7 +410,7 @@ class NMainFrameWidget : public QWidget
 		void enableCriticalButtons(bool enable);
 		void pitchToLine(int pitchNumber);
 		KAccel *keys_;
-		QList<KAction> criticalButtons_;
+		QPtrList<KAction> criticalButtons_;
 		KToggleAction *playbutton_;
 		KToggleAction *stemUpbutton_;
 		KToggleAction *stemDownbutton_;
@@ -416,6 +431,7 @@ class NMainFrameWidget : public QWidget
 		KToggleAction *pedoffbutton_;
 		NNumberDisplay *voiceDisplay_;
 		KToggleAction *offs_buttons_[COUNT_OFFSBUTTONS];
+		KToggleAction *selectbutton_;		
 		KToggleAction *editbutton_;
 		KToggleAction *allowKbInsertButton_;
 		KToggleAction *gluebutton_;
@@ -427,7 +443,6 @@ class NMainFrameWidget : public QWidget
 		KToggleAction *recordButton_;
 #endif
 		KToggleAction *note_buttons_[COUNT_CHORDBUTTONS];
-		KToggleAction *note_dymmy_;
 		KToggleAction *crossDrumBu_;
 		KToggleAction *cross2DrumBu;
 		KToggleAction *crossCricDrumBu_;
@@ -436,7 +451,7 @@ class NMainFrameWidget : public QWidget
 		NInfoTable *about_;
 		NDbufferWidget *notePart_; //main view of the score
 		KAction *lilyPort_;
-		int voiceNr_;
+		unsigned int voiceNr_;
 /*------------------------------ Dialogs ------------------------------------------------*/
 
 		QDialog *channelDialog_;
@@ -460,6 +475,7 @@ class NMainFrameWidget : public QWidget
 		timesigDiaFrm *timesigDialog_;
 		staffFrm *multistaffDialog_;
 		staffelFrm *clefDialog_;
+		staffelFrm *specialBarlineDialog_;
 		staffPropFrm *staffPropFrm_;
 //		voiceDiaFrm *voiceDialog_; //deprecated
 		tupletDialogImpl *tupletDialog_;
@@ -489,15 +505,15 @@ class NMainFrameWidget : public QWidget
 /*----------------------------- internal reaction on resize --------------------------*/
 		void setScrollableNotePage();
 		void preparePixmaps();
-		int width_, height_;
-		int lastXpos_, lastYHeight_, oldLastXpos_;
-		int nettoWidth_, nettoHeight_;
-		int paperWidth_, paperHeight_;
-		int paperScrollWidth_, paperScrollHeight_;
-                int leftx_, topy_, boty_;
+		unsigned int width_, height_;
+		unsigned int lastXpos_, lastYHeight_, oldLastXpos_;
+		unsigned int nettoWidth_, nettoHeight_;
+		unsigned int paperWidth_, paperHeight_;
+		unsigned int paperScrollWidth_, paperScrollHeight_;
+		unsigned int leftx_, topy_, boty_;
 /*----------------------------- update of buttons due to selection ------------------*/
 		void setButton(int nr);
-		void stateButtonChange(int state, int state2);
+		void updateInterface(property_type properties, int length);
 		void playButtonReset();
 /*-----------------------------(re-)storing ----------------------------------------*/
 		void writeStaffs(const char *fname);
@@ -507,6 +523,7 @@ class NMainFrameWidget : public QWidget
 		MusicXMLParser *musicxmlFileReader_;
 		NLilyExport *lilyexport_;
 		exportFrm *exportDialog_;
+		saveParametersFrm *saveParametersDialog_;
 		void exportManager( int type );
 
 /*------------------------------ TSE3 -----------------------------------------------*/
@@ -514,22 +531,23 @@ class NMainFrameWidget : public QWidget
 		NTSE3Handler *tse3Handler_;
 #endif
 /*---------------------------- positioning ------------------------------------------*/
-		void xscrollDuringReplay(int val);
+		void xscrollDuringReplay(unsigned int val);
 		void computeMidiTimes(bool insertBars, bool doAutoBeam = false);
-		QList<NMidiEventStr> currentEvents_, nextEvents_;
-		QList<NMidiEventStr> *nextToPlay_, *nextToSearch_;
+		QPtrList<NMidiEventStr> currentEvents_, nextEvents_;
+		QPtrList<NMidiEventStr> *nextToPlay_, *nextToSearch_;
 		QScrollBar  *scrollx_, *scrolly_;
 		int lastBarNr_;
 /*------------------------------- selection ---------------------------------------*/
 		bool editMode_;
-		unsigned int state_before_edit_mode_;
-		int x0_, y0_, x1_;
+		property_type props_before_edit_mode_; /* selected buttons before going to edit mode */
+		int length_before_edit_mode_; /* selected note/rest length button before going to edit mode */
+		unsigned int x0_, y0_, x1_;
 		int xori_;
 		QRect   selRect_;
-		int checkAllStaffsForNoteInsertion(const int line, const QPoint p, int *state, int *state2, bool *playable, bool *delete_elem, bool *insert_new_note);
+		int checkAllStaffsForNoteInsertion(const int line, const QPoint p, property_type *properties, bool *playable, bool *delete_elem, bool *insert_new_note);
 		bool checkStaffIntersection(const QPoint p);
-		QList<NVoice> voiceList_;
-		QList<NStaff> staffList_;
+		QPtrList<NVoice> voiceList_;
+		QPtrList<NStaff> staffList_;
 		NVoice *currentVoice_;
 		NStaff *currentStaff_;
 		void nextElement();
@@ -578,11 +596,12 @@ class NMainFrameWidget : public QWidget
 		int actualOffs_;
 		int staffCount_;
 		int keyLine_, keyOffs_;
-		void forceAccent(unsigned int acc, bool val);
+		void forceAccent(property_type acc, bool val);
 		void manageToolElement(bool becauseOfInsertion);
 /*-------------------------------- layout --------------------------------------*/
 		void renewStaffLayout();
-		void  appendStaffLayoutElem();
+		void appendStaffLayoutElem();
+		inline void computeLastYHeight();
 		QPixmap *layoutPixmap_;
 /*-------------------------------- playing --------------------------------------*/
 		int contextWidth_;
@@ -591,7 +610,7 @@ class NMainFrameWidget : public QWidget
 		int tempofactor_;
 		int changePlayMethodItemId_;
 		int notesToPlay_;
-		int turnOverOffset_;
+		unsigned int turnOverOffset_;
 		bool playing_;
 		NTempoTrack SortedTempoSigs_;
 		bool firstNoteActive_; // avoid overwriting first red colored note
@@ -613,54 +632,12 @@ class NMainFrameWidget : public QWidget
 		QTimer midiInTimer_;
 #endif
 		double tempo_;
-		QList<NMidiEventStr> stopList_;
+		QPtrList<NMidiEventStr> stopList_;
 		void cleanupSelections();
-/*-------------------------------- static dadabase -------------------------------*/
 		static const char *keySigTab_[15];
+		#ifdef WITH_DIRECT_PRINTING
+		NPreviewPrint *prvprint_;
+		#endif
 };
 
-#ifdef WITH_DIRECT_PRINTING
-
-// Jorge Windmeisser Oliver
-
-#include <kdeprint/kprintdialogpage.h>
-#include <kprinter.h>
-#include <unistd.h>
-//#include <qscrollview.h>
-class IntPrinter : public KPrinter
- {
- public:
- IntPrinter(QString fileName) { fileName_=fileName; }
-// ~IntPrinter() { unlink(fileName_); unlink(fileName_+".ps"); }
-// void printFiles(QStringList files,bool remove) {printFiles(files,remove);}
- void doPreparePrinting() { preparePrinting(); }
- QString fileName_;
- }; 
-
- class ABCDialogPage : public KPrintDialogPage
- {
- public:
-   ABCDialogPage( exportFrm *formFrom, exportFrm *&formTo, QWidget *tab, QWidget *parent = 0, const char *name = 0 );
-   ~ABCDialogPage();
-
-   //reimplement virtual functions
-   void getOptions( QMap<QString,QString>& opts, bool incldef = false );
-   void setOptions( const QMap<QString,QString>& opts );
-   bool isValid( QString& msg );
-
-   exportFrm *copyFrom;
-   exportFrm **copyTo;
-
-   QWidget *tab_;
-
- private:
-//   QScrollView *mainScroller;
-   QString title;
-   bool doneReparenting;
-   int position;
-   QPoint rep;
- };
-
-#endif /* WITH_DIRECT_PRINTING */
-
 #endif // MYFRAME_WIDGET_H
