@@ -20,13 +20,15 @@
 /*											*/
 /****************************************************************************************/
 
+#ifndef WITH_SCONS
 #include "config.h"
+#endif
 #if GCC_MAJ_VERS > 2
 #include <sstream>
 #else
 #include <strstream.h>
 #endif
-#include <qlist.h>
+#include <qptrlist.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 #include "midiexport.h"
@@ -74,7 +76,7 @@ void NMidiExport::writeDWord(unsigned int dw) {
 	putc(0xff & dw, midiout_);
 }
 
-void NMidiExport::writeString(char *s) {
+void NMidiExport::writeString(const char *s) {
 	while (*s) {
 		putc(0xff & (*s++), midiout_);
 	}
@@ -131,7 +133,7 @@ void NMidiExport::writeCtlChange(int time, unsigned char chn, unsigned char ctl,
 	writeByte(pgm);
 }
 
-void NMidiExport::exportMidi(const char *fname, QList<NVoice> *voilist, char *miditext) {
+void NMidiExport::exportMidi(const char *fname, QPtrList<NVoice> *voilist, const char *miditext) {
 	NVoice *voice_elem;
 	NTimeSig *timesig;
 #if GCC_MAJ_VERS > 2
@@ -163,7 +165,7 @@ void NMidiExport::exportMidi(const char *fname, QList<NVoice> *voilist, char *mi
 	writeCtrlTrack(voilist, "Music generated by \"NoteEdit\"", miditext, timesig, 0/* , 60000000 / tempo*/);
 
 	for (voice_elem = voilist->first(); voice_elem; voice_elem = voilist->next()) {
-		writeTrack(voice_elem, timesig);
+		writeTrack(voice_elem);
 	}
 	fclose(midiout_);
 }
@@ -222,7 +224,7 @@ void NMidiExport::writeTempo(int time, unsigned int tempo) {
 }
 
 
-void NMidiExport::writeCtrlTrack(QList<NVoice> *voilist, char *Title, char *miditext, NTimeSig *firstTsig, int keysig) {
+void NMidiExport::writeCtrlTrack(QPtrList<NVoice> *voilist, const char *Title, const char *miditext, NTimeSig *firstTsig, int keysig) {
 	long pos0, pos1;
 	unsigned int length;
 	int lastEventTime = 0;
@@ -260,26 +262,27 @@ void NMidiExport::writeCtrlTrack(QList<NVoice> *voilist, char *Title, char *midi
 	fseek(midiout_, pos1, SEEK_SET);
 }
 
-void NMidiExport::writeTrack(NVoice *voice, NTimeSig *firstTsig) {
+void NMidiExport::writeTrack(NVoice *voice) {
 	long pos0, pos1;
 	int lyricsLines;
 	unsigned int length;
 	int i;
 	NNote *note;
-	NVoice *firstVoice;
+	NVoice *firstVoice = 0;
 	NMidiEventStr *m_evt, *m_evt2, *m_events;
 	int myTime, lastEventTime = 0, noteoff;
-	int sign = 0, kind;
+	int sign = 0;
+	property_type kind;
 	NTimeSig *timesig;
 	QString *lyrics;
-	QList<NMidiEventStr> stopList;
+	QPtrList<NMidiEventStr> stopList;
 	stopList.setAutoDelete(false);
 
 	timesig = voice->getFirstTimeSig();
 
 	voice->getStaff()->startPlaying();  /* necessary to reset some member variables in all staffs (EndIdx_) */
 	if (voice->getStaff()->actualKeysig_.isRegular(&kind, &sign)) {
-		if (kind == STAT_FLAT) {
+		if (kind == PROP_FLAT) {
 			sign = -sign;
 		}
 	}
@@ -330,7 +333,7 @@ void NMidiExport::writeTrack(NVoice *voice, NTimeSig *firstTsig) {
 				if (m_events->ev_time <= m_evt->ev_time) {
 					noteoff = MY2MIDITIME(m_events->ev_time) - 3;
 					for (note = m_events->notelist->first(); note; note = m_events->notelist->next()) {
-						if (!(note->status & STAT_TIED) || (m_evt->special & TRILL_SPECS)) {
+						if (!(note->properties & PROP_TIED) || (m_evt->special & TRILL_SPECS)) {
 							writeNoteOff(noteoff - lastEventTime, m_events->midi_channel, note->midiPitch+m_events->trilloffs, m_events->volume);
 							lastEventTime = noteoff;
 						}
@@ -369,7 +372,7 @@ void NMidiExport::writeTrack(NVoice *voice, NTimeSig *firstTsig) {
 					}
 				}
 				for (i = 0, note = m_evt->notelist->first(); note; note = m_evt->notelist->next(), i++) {
-			   		if ((note->status & STAT_PART_OF_TIE) && !(m_evt->special & TRILL_SPECS)) {
+			   		if ((note->properties & PROP_PART_OF_TIE) && !(m_evt->special & TRILL_SPECS)) {
 						note->midiPitch = note->tie_backward->midiPitch; /* for note off */
 					}
 			   		else if (m_evt->special != SPEC_ARPEGGIO || i == m_evt->arpegg_current) {
@@ -416,7 +419,7 @@ void NMidiExport::writeTrack(NVoice *voice, NTimeSig *firstTsig) {
 	while (m_events) {
 		noteoff = MY2MIDITIME(m_events->ev_time) - 3;
 		for (note = m_events->notelist->first(); note; note = m_events->notelist->next()) {
-			if (!(note->status & STAT_TIED) || (m_events->special & TRILL_SPECS)) {
+			if (!(note->properties & PROP_TIED) || (m_events->special & TRILL_SPECS)) {
 				writeNoteOff(noteoff - lastEventTime, m_events->midi_channel, note->midiPitch, m_events->volume);
 				lastEventTime = noteoff;
 			}
