@@ -20,7 +20,7 @@
 /*											*/
 /****************************************************************************************/
 
-#include "config.h"
+#include "midimapper.h"
 #if GCC_MAJ_VERS > 2
 #ifndef WITH_TSE3
 #include <iostream>
@@ -43,7 +43,6 @@
 #include <qpushbutton.h>
 #include <qdatetime.h>
 #include "resource.h"
-#include "midimapper.h"
 #include "voice.h"
 #include "chord.h"
 
@@ -128,7 +127,7 @@ NMidiMapper::~NMidiMapper() {
 }
 
 
-void NMidiMapper::stopAllNotes(QList<NMidiEventStr> *play_list) {
+void NMidiMapper::stopAllNotes(QPtrList<NMidiEventStr> *play_list) {
 	NMidiEventStr *m_evt;
 	NNote *note;
 	int i;
@@ -149,7 +148,7 @@ void NMidiMapper::stopAllNotes(QList<NMidiEventStr> *play_list) {
 	devMan_->sync();
 }
 
-void NMidiMapper::play_list(QList<NMidiEventStr> *play_list, int playTime) {
+void NMidiMapper::play_list(QPtrList<NMidiEventStr> *play_list, int playTime) {
 	NMidiEventStr *m_evt;
 	int i;
 	NNote *note;
@@ -167,7 +166,7 @@ void NMidiMapper::play_list(QList<NMidiEventStr> *play_list, int playTime) {
 		if (m_evt->ev_time != playTime || m_evt->midi_cmd != MNOTE_OFF) continue;
 		if (!m_evt->valid) continue;
 		for (note = m_evt->notelist->first(); note; note = m_evt->notelist->next()) {
-			if (!(note->status & STAT_TIED) || (m_evt->special & TRILL_SPECS)) {
+			if (!(note->properties & PROP_TIED) || (m_evt->special & TRILL_SPECS)) {
 				devMan_->noteOff(m_evt->midi_channel, note->midiPitch+m_evt->trilloffs, 0);
 			}
 		}
@@ -194,7 +193,7 @@ void NMidiMapper::play_list(QList<NMidiEventStr> *play_list, int playTime) {
 				}
 			}
 			for (i = 0, note = m_evt->notelist->first(); note; note = m_evt->notelist->next(), i++) {
-			   if ((note->status & STAT_PART_OF_TIE) && !(m_evt->special & TRILL_SPECS)) {
+			   if ((note->properties & PROP_PART_OF_TIE) && !(m_evt->special & TRILL_SPECS)) {
 					note->midiPitch = note->tie_backward->midiPitch; /* for note off */
 				}
 			   	else if (m_evt->special != SPEC_ARPEGGIO || i == m_evt->arpegg_current) {
@@ -242,7 +241,7 @@ void NMidiMapper::changeDevice(unsigned int index) {
 void NMidiMapper::playImmediately(NClef *clef, NChord *chord, int pgm, int chn, int vol, int transpose) {
 	if (actualDevice_nr_ < 0) return;
 	if (isInUse_) return;
-	QList<NNote> *notelist;
+	QPtrList<NNote> *notelist;
 	NNote *note;
 	struct dir_notes_str *immListElem;
 	if (!immList_.isEmpty())  {
@@ -252,7 +251,7 @@ void NMidiMapper::playImmediately(NClef *clef, NChord *chord, int pgm, int chn,
 	devMan_->chnPatchChange(chn, pgm);
 	for (note = notelist->first(); note; note = notelist->next()) {
 		immListElem = new dir_notes_str;
-		immListElem->pitch = clef->line2midiTab_[note->line+LINE_OVERFLOW]+note->offs+clef->getShift()+transpose;
+		immListElem->pitch = clef->line2Midi( note->line, note->offs )+transpose;
 		immListElem->chan = chn;
 		immList_.append(immListElem);
 		devMan_->noteOn(chn, immListElem->pitch, vol);
@@ -270,7 +269,7 @@ void NMidiMapper::playImmediately(NClef *clef, int keyline, int offs, int pgm, i
 	}
 	devMan_->chnPatchChange(chn, pgm);
 	immListElem = new dir_notes_str;
-	immListElem->pitch = clef->line2midiTab_[keyline+LINE_OVERFLOW]+offs+clef->getShift()+transpose;
+	immListElem->pitch = clef->line2Midi( keyline, offs )+transpose;
 	immListElem->chan = chn;
 	immList_.append(immListElem);
 	devMan_->noteOn(chn, immListElem->pitch, vol);
@@ -446,7 +445,7 @@ void NMidiMapper::openDevice() {
 }
 
 
-void NMidiMapper::stopAllNotes(QList<NMidiEventStr> *play_list) {
+void NMidiMapper::stopAllNotes(QPtrList<NMidiEventStr> *play_list) {
 	NMidiEventStr *m_evt;
 	NNote *note;
 	int i;
@@ -468,7 +467,7 @@ void NMidiMapper::stopAllNotes(QList<NMidiEventStr> *play_list) {
 	}
 }
 
-void NMidiMapper::play_list(QList<NMidiEventStr> *play_list, int playTime) {
+void NMidiMapper::play_list(QPtrList<NMidiEventStr> *play_list, int playTime) {
 	NMidiEventStr *m_evt;
 	NNote *note;
 	int i;
@@ -486,7 +485,7 @@ void NMidiMapper::play_list(QList<NMidiEventStr> *play_list, int playTime) {
 		if (m_evt->ev_time != playTime || m_evt->midi_cmd != MNOTE_OFF) continue;
 		if (!m_evt->valid) continue;
 		for (note = m_evt->notelist->first(); note; note = m_evt->notelist->next()) {
-			if (!(note->status & STAT_TIED) || (m_evt->special & TRILL_SPECS)) {
+			if (!(note->properties & PROP_TIED) || (m_evt->special & TRILL_SPECS)) {
 				
 				theScheduler_->tx(TSE3::MidiCommand(TSE3::MidiCommand_NoteOff,
 						   m_evt->midi_channel, actualDevice_nr_, note->midiPitch+m_evt->trilloffs, 0));
@@ -517,7 +516,7 @@ void NMidiMapper::play_list(QList<NMidiEventStr> *play_list, int playTime) {
 				}
 			}
 			for (i = 0, note = m_evt->notelist->first(); note; note = m_evt->notelist->next(), i++) {
-			   if ((note->status & STAT_PART_OF_TIE) && !(m_evt->special & TRILL_SPECS)) {
+			   if ((note->properties & PROP_PART_OF_TIE) && !(m_evt->special & TRILL_SPECS)) {
 			        note->midiPitch = note->tie_backward->midiPitch; /* for note off */
 			   }
 			   else if (m_evt->special != SPEC_ARPEGGIO || i == m_evt->arpegg_current) {
@@ -575,7 +574,7 @@ void NMidiMapper::changeDevice(unsigned int index) {
 void NMidiMapper::playImmediately(NClef *clef, NChord *chord, int pgm, int chn, int vol, int transpose) {
 	if (actualDevice_nr_ < 0) return;
 	if (isInUse_) return;
-	QList<NNote> *notelist;
+	QPtrList<NNote> *notelist;
 	NNote *note;
 	struct dir_notes_str *immListElem;
 	if (!immList_.isEmpty())  {
@@ -585,7 +584,7 @@ void NMidiMapper::playImmediately(NClef *clef, NChord *chord, int pgm, int chn,
 	theScheduler_->tx(TSE3::MidiCommand(TSE3::MidiCommand_ProgramChange, chn, actualDevice_nr_, pgm));
 	for (note = notelist->first(); note; note = notelist->next()) {
 		immListElem = new dir_notes_str;
-		immListElem->pitch = clef->line2midiTab_[note->line+LINE_OVERFLOW]+note->offs+clef->getShift()+transpose;
+		immListElem->pitch = clef->line2Midi( note->line, note->offs ) + transpose;
 		immListElem->chan = chn;
 		immList_.append(immListElem);
 		theScheduler_->tx(TSE3::MidiCommand(TSE3::MidiCommand_NoteOn, chn, actualDevice_nr_,
@@ -603,7 +602,7 @@ void NMidiMapper::playImmediately(NClef *clef, int keyline, int offs, int pgm, i
 	}
 	theScheduler_->tx(TSE3::MidiCommand(TSE3::MidiCommand_ProgramChange, chn, actualDevice_nr_, pgm));
 	immListElem = new dir_notes_str;
-	immListElem->pitch = clef->line2midiTab_[keyline+LINE_OVERFLOW]+offs+clef->getShift()+transpose;
+	immListElem->pitch = clef->line2Midi( keyline, offs ) + transpose;
 	immListElem->chan = chn;
 	immList_.append(immListElem);
 	theScheduler_->tx(TSE3::MidiCommand(TSE3::MidiCommand_NoteOn, chn, actualDevice_nr_,
@@ -728,14 +727,14 @@ NMidiMapper::NMidiMapper() : QObject() {
 }
 
 
-void NMidiMapper::stopAllNotes(QList<NMidiEventStr> * /* dummy */) {
+void NMidiMapper::stopAllNotes(QPtrList<NMidiEventStr> * /* dummy */) {
 	int i;
 	for ( i = 0; i < synthDevs_ + midiDevs_; i++ ) {
 		ioctl(seqfd, SNDCTL_SEQ_RESET, i);
 	}
 }
 
-void NMidiMapper::play_list(QList<NMidiEventStr> *play_list, int playTime) {
+void NMidiMapper::play_list(QPtrList<NMidiEventStr> *play_list, int playTime) {
 	(this->*play_func_)(play_list, playTime);
 }
 
@@ -783,7 +782,7 @@ void NMidiMapper::changePan(int chn, int pan) {
 	}
 }
 
-void NMidiMapper::playMidiDev(QList<NMidiEventStr> *play_list, int playTime) const{
+void NMidiMapper::playMidiDev(QPtrList<NMidiEventStr> *play_list, int playTime) const{
 	int i;
 	NMidiEventStr *m_evt;
 	NNote *note;
@@ -802,7 +801,7 @@ void NMidiMapper::playMidiDev(QList<NMidiEventStr> *play_list, int playTime) con
 		if (m_evt->ev_time != playTime || m_evt->midi_cmd != MNOTE_OFF) continue;
 		if (!m_evt->valid) continue;
 		for (note = m_evt->notelist->first(); note; note = m_evt->notelist->next()) {
-			if (!(note->status & STAT_TIED) || (m_evt->special & TRILL_SPECS)) {
+			if (!(note->properties & PROP_TIED) || (m_evt->special & TRILL_SPECS)) {
 				SEQ_MIDIOUT(actualDevice_nr_, MIDI_NOTEOFF|m_evt->midi_channel);
 				SEQ_MIDIOUT(actualDevice_nr_, note->midiPitch+m_evt->trilloffs);
 				SEQ_MIDIOUT(actualDevice_nr_, 0);
@@ -838,7 +837,7 @@ void NMidiMapper::playMidiDev(QList<NMidiEventStr> *play_list, int playTime) con
 				}
 			}
 			for (i = 0, note = m_evt->notelist->first(); note; note = m_evt->notelist->next(), i++) {
-				if ((note->status & STAT_PART_OF_TIE) && !(m_evt->special & TRILL_SPECS)) {
+				if ((note->properties & PROP_PART_OF_TIE) && !(m_evt->special & TRILL_SPECS)) {
 					note->midiPitch = note->tie_backward->midiPitch; /* for note off */
 				}
 			   	else if (m_evt->special != SPEC_ARPEGGIO || i == m_evt->arpegg_current) {
@@ -859,7 +858,7 @@ void NMidiMapper::playMidiDev(QList<NMidiEventStr> *play_list, int playTime) con
 	SEQ_DUMPBUF();
 }
 
-void NMidiMapper::playSynthDev(QList<NMidiEventStr> *play_list, int playTime) const{
+void NMidiMapper::playSynthDev(QPtrList<NMidiEventStr> *play_list, int playTime) const{
 	NNote *note;
 	NMidiEventStr *m_evt;
 	int i;
@@ -878,7 +877,7 @@ void NMidiMapper::playSynthDev(QList<NMidiEventStr> *play_list, int playTime) co
 		if (m_evt->ev_time != playTime || m_evt->midi_cmd != MNOTE_OFF) continue;
 		if (!m_evt->valid) continue;
 		for (note = m_evt->notelist->first(); note; note = m_evt->notelist->next()) {
-			if (!(note->status & STAT_TIED) || (m_evt->special & TRILL_SPECS)) {
+			if (!(note->properties & PROP_TIED) || (m_evt->special & TRILL_SPECS)) {
 				SEQ_STOP_NOTE(actualDevice_nr_, m_evt->midi_channel, note->midiPitch+m_evt->trilloffs, 0);
 			}
 		}
@@ -897,7 +896,7 @@ void NMidiMapper::playSynthDev(QList<NMidiEventStr> *play_list, int playTime) co
 				SEQ_CONTROL(actualDevice_nr_, m_evt->midi_channel, CTL_MAIN_VOLUME, m_evt->volum_ctrl_change);
 			}
 			for (i = 0, note = m_evt->notelist->first(); note; note = m_evt->notelist->next(), i++) {
-				if ((note->status & STAT_PART_OF_TIE) && !(m_evt->special & TRILL_SPECS)) {
+				if ((note->properties & PROP_PART_OF_TIE) && !(m_evt->special & TRILL_SPECS)) {
 					note->midiPitch = note->tie_backward->midiPitch; /* for note off */
 				}
 			   	else if (m_evt->special != SPEC_ARPEGGIO || i == m_evt->arpegg_current) {
@@ -914,7 +913,7 @@ void NMidiMapper::playSynthDev(QList<NMidiEventStr> *play_list, int playTime) co
 	SEQ_DUMPBUF();
 }
 
-void NMidiMapper::playNull(QList<NMidiEventStr> *play_list, int playTime) const{
+void NMidiMapper::playNull(QPtrList<NMidiEventStr> *play_list, int playTime) const{
 	NMidiEventStr *m_evt;
 
 	for (m_evt = play_list->first(); m_evt; m_evt = play_list->next()) {
@@ -954,7 +953,7 @@ void NMidiMapper::changeDevice(unsigned int index) {
 void NMidiMapper::playImmediately(NClef *clef, NChord *chord, int pgm, int chn, int vol, int transpose) {
 	if (actualDevice_nr_ < 0) return;
 	if (isInUse_) return;
-	QList<NNote> *notelist;
+	QPtrList<NNote> *notelist;
 	NNote *note;
 	struct dir_notes_str *immListElem;
 	if (!immList_.isEmpty())  {
@@ -969,7 +968,7 @@ void NMidiMapper::playImmediately(NClef *clef, NChord *chord, int pgm, int chn,
 	}
 	for (note = notelist->first(); note; note = notelist->next()) {
 		immListElem = new dir_notes_str;
-		immListElem->pitch = clef->line2midiTab_[note->line+LINE_OVERFLOW]+note->offs+clef->getShift()+transpose;
+		immListElem->pitch = clef->line2Midi( note->line, note->offs ) + transpose;
 		immListElem->chan = chn;
 		immList_.append(immListElem);
 		switch (devices_[actualDevice_nr_].dev_type) {
@@ -998,7 +997,7 @@ void NMidiMapper::playImmediately(NClef *clef, int keyline, int offs, int pgm, i
 				break;
 	}
 	immListElem = new dir_notes_str;
-	immListElem->pitch = clef->line2midiTab_[keyline+LINE_OVERFLOW]+offs+clef->getShift()+transpose;
+	immListElem->pitch = clef->line2Midi( keyline, offs ) + transpose;
 	immListElem->chan = chn;
 	immList_.append(immListElem);
 	switch (devices_[actualDevice_nr_].dev_type) {
@@ -1036,10 +1035,10 @@ void NMidiMapper::setPaintDevice(NDbufferWidget *pd) {
 }
 
 #ifdef WITH_TSE3
-QList<int> *NMidiMapper::readEvents() {
+QPtrList<int> *NMidiMapper::readEvents() {
 	TSE3::MidiEvent evt;
 	TSE3::MidiCommand *midiOnCommand;
-	QList<int> *pitches = 0;
+	QPtrList<int> *pitches = 0;
 	bool first = true;
 	if (!theScheduler_) return 0;
 	while (1) {
@@ -1054,7 +1053,7 @@ QList<int> *NMidiMapper::readEvents() {
 				}
 				if (first) {
 					first = false;
-					pitches = new QList<int>();
+					pitches = new QPtrList<int>();
 					pitches->setAutoDelete(true);
 					readTime_.start();
 				}
