@@ -20,9 +20,8 @@
 /*											*/
 /****************************************************************************************/
 
-#include "config.h"
-#ifdef WITH_TSE3
 #include "miditimescale.h"
+#ifdef WITH_TSE3
 #include "resource.h"
 #include "staff.h"
 #include "clef.h"
@@ -621,7 +620,7 @@ void NMidiTimeScale::initialize_desicion_tree(unrolled_midi_events_str *ptr, uns
 		}
 		else if ((ptr1->eventType & EVT_CLASS_NOTE) && (ptr->eventType & EVT_CLASS_NOTE)){
 			ptr->decision_tree[j].costs = (int) (PITCH_DIST_COST_FAC * fabs(ptr->ave_pitch - ptr1->ave_pitch) +
-								START_DIST_FAC * fabs(ptr1->start_time -  ptr->stop_time));
+								START_DIST_FAC * fabs((double)(ptr1->start_time -  ptr->stop_time)));
 		}
 		j++;
 	}
@@ -1234,7 +1233,7 @@ void NMidiTimeScale::createVoice(int nr, main_props_str *main_props, staff_props
 	unsigned int newVolume;
 	unsigned int voiceTime = 0;
 	unsigned int nextstart = 0, start = 0, stop = 0;
-	unsigned int status, body;
+	property_type properties, body;
 	bool inTriplet = false;
 	int dotcount;
 	int voldist;
@@ -1248,7 +1247,7 @@ void NMidiTimeScale::createVoice(int nr, main_props_str *main_props, staff_props
 	NChord *chord = 0, *chord2;
 	NRest *rest;
 	NSign *sign;
-	QList<NMusElement> *tupletList = 0;
+	QPtrList<NPlayable> *tupletList = 0;
 	struct unrolled_midi_events_str *ptr, *nptr;
 	l = array_len_;
 	voiceTime = 0;
@@ -1280,19 +1279,19 @@ void NMidiTimeScale::createVoice(int nr, main_props_str *main_props, staff_props
 				}
 				len -= len3;
 				voiceTime += len3;
-				status = 0;
+				properties = 0;
 				if (dotcount) {
-					status = STAT_SINGLE_DOT;
+					properties = PROP_SINGLE_DOT;
 				}
 				if (!first) {
-					status |= STAT_HIDDEN;
+					properties |= PROP_HIDDEN;
 				}
-				rest = new NRest(main_props, staff_props, &(voice->yRestOffs_), len2, status);
+				rest = new NRest(main_props, staff_props, &(voice->yRestOffs_), len2, properties);
 				voice->appendElem(rest);
 #ifdef YYY
 				if (triplet) {
 					if (!inTriplet) {
-						tupletList = new QList<NMusElement>();
+						tupletList = new QPtrList<NPlayable>();
 						inTriplet = true;
 					}
 					tupletList->append(rest);
@@ -1302,7 +1301,7 @@ void NMidiTimeScale::createVoice(int nr, main_props_str *main_props, staff_props
 						tupletList->clear();
 					}
 					else {
-						NMusElement::computeTuplet(tupletList, 3, 2);
+						NPlayable::computeTuplet(tupletList, 3, 2);
 					}
 					tupletList = 0;
 					inTriplet = false;
@@ -1315,7 +1314,7 @@ void NMidiTimeScale::createVoice(int nr, main_props_str *main_props, staff_props
 			}
 		}
 		stop = ((ptr->eventType & EVT_CLASS_REST) || (ptr->eventType & (EVT_NORMAL_EVENT |  EVT_LAST_IN_TRIPLET))) ?  ptr->stop_time : ptr->U.norm_evt.triplet_stop_time;
-		status = 0;
+		properties = 0;
 		len = stop - start;
 		triplet = (ptr->eventType & (EVT_PART_OF_TRIPLET | EVT_LAST_IN_TRIPLET | EVT_FIRST_IN_TRIPLET));
 		stacatto = false;
@@ -1375,16 +1374,16 @@ void NMidiTimeScale::createVoice(int nr, main_props_str *main_props, staff_props
 				voiceTime += len3;
 				if (addRest) {
 					if (dotcount) {
-						status = STAT_SINGLE_DOT;
+						properties = PROP_SINGLE_DOT;
 					}
 					if (!first) {
-						status |= STAT_HIDDEN;
+						properties |= PROP_HIDDEN;
 					}
-					rest = new NRest(main_props, staff_props, &(voice->yRestOffs_), len2, status);
+					rest = new NRest(main_props, staff_props, &(voice->yRestOffs_), len2, properties);
 					voice->appendElem(rest);
 					if (triplet) {
 						if (!inTriplet) {
-							tupletList = new QList<NMusElement>();
+							tupletList = new QPtrList<NPlayable>();
 							inTriplet = true;
 						}
 						tupletList->append(rest);
@@ -1392,7 +1391,7 @@ void NMidiTimeScale::createVoice(int nr, main_props_str *main_props, staff_props
 				}
 				else {
 					clef->midi2Line(ptr->U.norm_evt.pitches[0], &line, &offs);
-					status = dotcount ? STAT_SINGLE_DOT : 0;
+					properties = dotcount ? PROP_SINGLE_DOT : 0;
 					if (computeAverageVolume) {
 						newVolume = (int) (averageVolume + dynamic / 127.0 * (double) (ptr->U.norm_evt.volume - averageVolume));
 					}
@@ -1427,24 +1426,24 @@ void NMidiTimeScale::createVoice(int nr, main_props_str *main_props, staff_props
 					else {
 						body = 0;
 						if (drum_channel) {
-							body = (STAT_BODY_CROSS << ((line + LINE_OVERFLOW) % 5));
+							body = (PROP_BODY_CROSS << ((line + LINE_OVERFLOW) % 5));
 						}
 						if (stacatto) {
-							status |= STAT_STACC;
+							properties |= PROP_STACC;
 						}
-						chord = new NChord(main_props, staff_props, line, offs, len2, ptr->stem_policy, status | body);
+						chord = new NChord(main_props, staff_props, voice, line, offs, len2, ptr->stem_policy, properties | body);
 						for (j = 1; j < ptr->U.norm_evt.num_pitches; j++) {
 							clef->midi2Line(ptr->U.norm_evt.pitches[j], &line, &offs);
 							body = 0;
 							if (drum_channel) {
-								body = (STAT_BODY_CROSS << ((line + LINE_OVERFLOW) % 5));
+								body = (PROP_BODY_CROSS << ((line + LINE_OVERFLOW) % 5));
 							}
-							chord->insertNewNote(line, offs, ptr->stem_policy, status | body);
+							chord->insertNewNote(line, offs, ptr->stem_policy, properties | body);
 						}
 						voice->appendElem(chord);
 						if (triplet && !before_triplet)  {
 							if (!inTriplet) {
-								tupletList = new QList<NMusElement>();
+								tupletList = new QPtrList<NPlayable>();
 								inTriplet = true;
 							}
 							tupletList->append(chord);
@@ -1454,7 +1453,7 @@ void NMidiTimeScale::createVoice(int nr, main_props_str *main_props, staff_props
 						if (before_triplet) {
 							before_triplet = false;
 							len = stop - ptr->split_time;
-							tupletList = new QList<NMusElement>();
+							tupletList = new QPtrList<NPlayable>();
 							inTriplet = true;
 						}
 						if (potential_after_triplet) {
@@ -1464,7 +1463,7 @@ void NMidiTimeScale::createVoice(int nr, main_props_str *main_props, staff_props
 								tupletList->clear();
 							}
 							else {
-								NMusElement::computeTuplet(tupletList, 3, 2);
+								NPlayable::computeTuplet(tupletList, 3, 2);
 							}
 							tupletList = 0;
 							triplet = inTriplet = false;
@@ -1482,7 +1481,7 @@ void NMidiTimeScale::createVoice(int nr, main_props_str *main_props, staff_props
 				tupletList->clear();
 			}
 			else {
-				NMusElement::computeTuplet(tupletList, 3, 2);
+				NPlayable::computeTuplet(tupletList, 3, 2);
 			}
 			tupletList = 0;
 			inTriplet = false;
