@@ -19,13 +19,15 @@
 /*											*/
 /****************************************************************************************/
 
+#ifndef WITH_SCONS
 #include "config.h"
+#endif
 #ifndef MUSICXMLCOMMON_H
 
 // link MusicXML chord kind to step values
 
 struct MusicXMLChord {
-	char * kind;
+	const char * kind;
 	short int s3;
 	short int s5;
 	short int s7;
