@@ -48,6 +48,7 @@ Status overview of features implemented
 Accidentals	supported: sharp, flat and natural, including double sharp and flat
 Accents		supported: staccato, sforzato, portato, strong pizzicato, sforzando, fermate,
 			   arpeggio and pedal on/off
+Arbitrary text	supported, including above/below position
 Bar separators	supported: simple, double, end
 Beams		supported
 Clefs		supported: treble, bass, soprano, alto and tenor clef, not supported: drum and drum_bass clef
@@ -111,6 +112,7 @@ Note shapes: body as cross, alternative cross, cross with circle, rectangle, tri
 #include "rest.h"
 #include "chord.h"
 #include "chorddiagram.h"
+#include "text.h"
 #include "layout.h"
 #include "uiconnect.h"
 #include "../kguitar_excerpt/global.h"
@@ -131,7 +133,7 @@ void NMusicXMLExport::debugDumpElem(NMusElement *elem) {
 	NClef *clef;
 	int count;
 	NKeySig *key;
-	int kind;
+	property_type kind;
 	NNote *note;
 	NSign *sign;
 	NTimeSig *timesig;
@@ -142,11 +144,10 @@ void NMusicXMLExport::debugDumpElem(NMusElement *elem) {
 //		<< " bbox-l,r=" << elem->getBbox()->left()
 //		<< "," << elem->getBbox()->right()
 		<< hex
-		<< " status=" << elem->status_
-		<< " status2=" << elem->status2_
+		<< " properties=" <<  ( elem->playable() ? elem->playable()->properties() : 0 )
 		<< dec << " ";
-	if (elem->va_) {
-		out_ << "va=" << elem->va_ << " ";
+	if (elem->chord() && elem->chord()->va_) {
+		out_ << "va=" << elem->chord()->va_ << " ";
 	}
 	switch (elem->getType()) {
 		case T_CHORD:
@@ -161,7 +162,7 @@ void NMusicXMLExport::debugDumpElem(NMusElement *elem) {
 					note = chord->getNoteList()->next()) {
 				out_ << endl << "  note"
 					<< hex
-					<< " status=" << note->status
+					<< " properties=" << note->properties
 					<< dec
 					<< " line=" << (int) note->line
 					<< " offs=" << (int) note->offs;
@@ -211,7 +212,7 @@ void NMusicXMLExport::debugDumpElem(NMusElement *elem) {
 			key = (NKeySig *) elem;
 			if (key->isRegular(&kind, &count)) {
 				out_ << " fifths=";
-				if (kind == STAT_FLAT) {
+				if (kind == PROP_FLAT) {
 					out_ << "-";
 				}
 				out_ << count;
@@ -251,7 +252,7 @@ void NMusicXMLExport::debugDumpStaff(NStaff * staff_elem) {
 }
 
 
-void NMusicXMLExport::debugDump(QList<NStaff> *stafflist, NMainFrameWidget *mainWidget) {
+void NMusicXMLExport::debugDump(QPtrList<NStaff> *stafflist, NMainFrameWidget *mainWidget) {
 	if (!mainWidget->scTitle_.isEmpty()) {
 		out_ << "scTitle=" << mainWidget->scTitle_ << endl;
 	}
@@ -297,7 +298,7 @@ NMusicXMLExport::NMusicXMLExport() {
 
 // export all staffs
 
-void NMusicXMLExport::exportStaffs(QString fname, QList<NStaff> *stafflist, int count_of_voices, exportFrm * /* expWin */, NMainFrameWidget *mainWidget) {
+void NMusicXMLExport::exportStaffs(QString fname, QPtrList<NStaff> *stafflist, int count_of_voices, exportFrm * /* expWin */, NMainFrameWidget *mainWidget) {
 	NStaff *staff_elem;
 	NVoice *voice_elem;
 	NClef *firstClef;
@@ -458,8 +459,7 @@ void NMusicXMLExport::exportStaffs(QString fname, QList<NStaff> *stafflist, int
 	if (!badlist_.isEmpty()) {
 		QString output;
 		output = i18n
-			("Noteedit has exported the score to MusicXML\n"
-			 "but there are some problems.\n");
+			("NoteEdit has exported the score to MusicXML but there are some problems.\n");
 		output += i18n("-----------------------------------------------------\n");
 		for (bad = badlist_.first(); bad; bad = badlist_.next()) {
 			switch (bad->type_) {
@@ -548,14 +548,14 @@ bool NMusicXMLExport::writeFirstVoice(NVoice *voice_elem, int staff_nr) {
 				      // In MusicXML pedal on/off are expressed as directions
 				      // containing direction-type pedal before the chord
 				      // they apply to.
-				      // In NoteEdit it is a status bit in the chord and cannot
+				      // In NoteEdit it is a property bit in the chord and cannot
 				      // occur in a rest. Sometimes both pedal on and off are found,
 				      // in which case pedal on has priority.
 				      // LVIFIX: may need to add relative-x,y and offset for proper positioning
-				      if (chord->status2_ & STAT2_PEDAL_ON) {
+				      if (chord->hasProperty( PROP_PEDAL_ON ) ) {
 					outputDirection("\t\t\t\t\t<pedal type=\"start\"/>\n",
 							"below");
-				      } else if (chord->status2_ & STAT2_PEDAL_OFF) {
+				      } else if (chord->hasProperty( PROP_PEDAL_OFF ) ) {
 					outputDirection("\t\t\t\t\t<pedal type=\"stop\"/>\n",
 							"below");
 				      }
@@ -618,7 +618,7 @@ bool NMusicXMLExport::writeFirstVoice(NVoice *voice_elem, int staff_nr) {
 				     	  outputNote(note, voice_elem, &(actual_staff->actualClef_), va, staff_nr, 1, n);
 					  n++;
 				      }
-				      curTime_ += calcDuration(chord->getSubType(), chord->status_);
+				      curTime_ += calcDuration(chord->getSubType(), chord->properties());
 				      if (chord == dynEndChord) {
 				        // dynamic ends after this chord
 					// LVIFIX: may need to add relative-x,y for proper positioning
@@ -643,7 +643,7 @@ bool NMusicXMLExport::writeFirstVoice(NVoice *voice_elem, int staff_nr) {
 				      break;
 			case T_REST:
 //				     out_ << "T_REST" << endl;
-				     rest = (NRest *) elem;
+					 rest = (NRest *) elem;
 				     if (rest->getSubType() == MULTIREST) {
 					voiceStatList_->pendingMultiRest = rest;
 				     }
@@ -652,7 +652,7 @@ bool NMusicXMLExport::writeFirstVoice(NVoice *voice_elem, int staff_nr) {
 				     if (rest->getSubType() == MULTIREST) {
 					/* already handled */ ;
 				     }
-				     else if (rest->status_ & STAT_HIDDEN) {
+				     else if (rest->hasProperty( PROP_HIDDEN ) ) {
 					len = rest->getSubType();
 					calcLength(rest, duration, noteType);
 					out_ << "\t\t\t<forward>\n";
@@ -660,6 +660,7 @@ bool NMusicXMLExport::writeFirstVoice(NVoice *voice_elem, int staff_nr) {
 						<< duration
 						<< "</duration>\n";
 					out_ << "\t\t\t</forward>\n";
+					curTime_ += duration;
 				     }
 				     else {
 				        // real, visible rest
@@ -675,18 +676,18 @@ bool NMusicXMLExport::writeFirstVoice(NVoice *voice_elem, int staff_nr) {
 					outputTimeMod(rest);
 					bool needNotations = false;
 					bool fermata = false;
-					if (rest->status_ & STAT_FERMT) {
+					if (rest->hasProperty( PROP_FERMT ) ) {
 						fermata = true;
 						needNotations = true;
 					}
 					bool tupletStart = false;
-					if ((rest->status_ & STAT_TUPLET)
+					if ((rest->hasProperty( PROP_TUPLET ) )
 					     && rest->isFirstInTuplet()) {
 						tupletStart = true;
 						needNotations = true;
 					}
 					bool tupletStop = false;
-					if (rest->status_ & STAT_LAST_TUPLET) {
+					if (rest->hasProperty( PROP_LAST_TUPLET ) ) {
 						tupletStop = true;
 						needNotations = true;
 					}
@@ -773,6 +774,13 @@ bool NMusicXMLExport::writeFirstVoice(NVoice *voice_elem, int staff_nr) {
 				     voiceStatList_->pendingKeySig = (NKeySig *) elem;
 				     voiceStatList_->lastBarSym = 0;
 				     break;
+			case T_TEXT:
+					out_ << "\t\t\t<direction placement=\"" << ((elem->getSubType() == TEXT_DOWNTEXT) ? "below" : "above") << "\">\n";
+					out_ << "\t\t\t\t<direction-type>\n";
+					out_ << "\t\t\t\t\t<words>" << ((NText*)(elem))->getText() << "</words>\n";
+					out_ << "\t\t\t\t</direction-type>\n";
+					out_ << "\t\t\t</direction>\n";
+					break;
 			default:
 //				     out_ << "default" << endl;
 				     voiceStatList_->lastBarSym = 0;
@@ -827,7 +835,7 @@ bool NMusicXMLExport::writeOtherVoicesTill(int staff_nr, int voice_nr, NVoice *v
 				     	  outputNote(note, voice_elem, &(actual_staff->actualClef_), va, staff_nr, voice_nr, n);
 					  n++;
 				      }
-				      curTime_ += calcDuration(chord->getSubType(), chord->status_);
+				      curTime_ += calcDuration(chord->getSubType(), chord->properties());
 #if 0
 // LVIFIX reenable when octava end is allowed in other voices than the first voice
 				      if (chord == vaEndChord) {
@@ -850,7 +858,7 @@ bool NMusicXMLExport::writeOtherVoicesTill(int staff_nr, int voice_nr, NVoice *v
 					out_ << "<!-- multi rest (not supported in this voice) -->" << endl;
 					len = rest->getMultiRestLength() * QUARTER_LENGTH;
 				     }
-				     else if (rest->status_ & STAT_HIDDEN) {
+				     else if (rest->hasProperty( PROP_HIDDEN ) ) {
 					len = rest->getSubType();
 					calcLength(rest, duration, noteType);
 					out_ << "\t\t\t<forward>\n";
@@ -858,6 +866,7 @@ bool NMusicXMLExport::writeOtherVoicesTill(int staff_nr, int voice_nr, NVoice *v
 						<< duration
 						<< "</duration>\n";
 					out_ << "\t\t\t</forward>\n";
+					curTime_ += duration;
 				     }
 				     else {
 				        // real, visible rest
@@ -873,18 +882,18 @@ bool NMusicXMLExport::writeOtherVoicesTill(int staff_nr, int voice_nr, NVoice *v
 					outputTimeMod(rest);
 					bool needNotations = false;
 					bool fermata = false;
-					if (rest->status_ & STAT_FERMT) {
+					if (rest->hasProperty( PROP_FERMT ) ) {
 						fermata = true;
 						needNotations = true;
 					}
 					bool tupletStart = false;
-					if ((rest->status_ & STAT_TUPLET)
+					if ((rest->hasProperty( PROP_TUPLET ) )
 					     && rest->isFirstInTuplet()) {
 						tupletStart = true;
 						needNotations = true;
 					}
 					bool tupletStop = false;
-					if (rest->status_ & STAT_LAST_TUPLET) {
+					if (rest->hasProperty( PROP_LAST_TUPLET ) ) {
 						tupletStop = true;
 						needNotations = true;
 					}
@@ -1158,7 +1167,7 @@ void NMusicXMLExport::outputNote(NNote *note, NVoice *voice_elem, NClef *actualC
 	char notename = ' ';
 	QString noteType = "";
 	int octave = 0;
-	if ((note->status & BODY_MASK) && !drum_problem_written_)  {
+	if ((note->properties & BODY_MASK) && !drum_problem_written_)  {
 		drum_problem_written_ = true;
 		bad = new badinfo(MUSICXML_ERRDRUM_STAFF, staff_nr, lastMeasureNum_);
 		badlist_.append(bad);
@@ -1179,7 +1188,7 @@ void NMusicXMLExport::outputNote(NNote *note, NVoice *voice_elem, NClef *actualC
 	if (note_nr) {
 		out_ << "\t\t\t\t<chord/>\n";
 	}
-	if (chord->status_ & STAT_GRACE) {
+	if (chord->hasProperty( PROP_GRACE ) ) {
 		if (chord->getSubType() != INTERNAL_MARKER_OF_STROKEN_GRACE) {
 			// normal grace
 			out_ << "\t\t\t\t<grace/>\n";
@@ -1197,13 +1206,13 @@ void NMusicXMLExport::outputNote(NNote *note, NVoice *voice_elem, NClef *actualC
 	out_ << "\t\t\t\t\t<octave>" << octave + 4 << "</octave>\n";
 	out_ << "\t\t\t\t</pitch>\n";
 	// grace notes have a <type> but no <duration> element
-	if (!(chord->status_ & STAT_GRACE)) {
+	if (!(chord->hasProperty( PROP_GRACE ) )) {
 		out_ << "\t\t\t\t<duration>" << duration << "</duration>\n";
 	}
 	// accidental handling (borrowed from filehandler.cpp, NFileHandler::pitchOut)
-	if (!(note->status & STAT_PART_OF_TIE)) {
+	if (!(note->properties & PROP_PART_OF_TIE)) {
 		QString accid = "";
-		if (note->status & STAT_FORCE) {
+		if (note->properties & PROP_FORCE) {
 			switch (note->offs) {
 				case  1: accid = "sharp"; break;
 				case -1: accid = "flat"; break;
@@ -1213,12 +1222,12 @@ void NMusicXMLExport::outputNote(NNote *note, NVoice *voice_elem, NClef *actualC
 			}
 		}
 		else {
-			switch (note->status & ACC_MASK) {
-				case STAT_CROSS:  accid = "sharp"; break;
-				case STAT_FLAT:   accid = "flat"; break;
-				case STAT_NATUR:  accid = "natural"; break;
-				case STAT_DCROSS: accid = "double-sharp"; break;
-				case STAT_DFLAT:  accid = "flat-flat"; break;
+			switch (note->properties & ACC_MASK) {
+				case PROP_CROSS:  accid = "sharp"; break;
+				case PROP_FLAT:   accid = "flat"; break;
+				case PROP_NATUR:  accid = "natural"; break;
+				case PROP_DCROSS: accid = "double-sharp"; break;
+				case PROP_DFLAT:  accid = "flat-flat"; break;
 			}
 		}
 		if (accid != "") {
@@ -1229,12 +1238,12 @@ void NMusicXMLExport::outputNote(NNote *note, NVoice *voice_elem, NClef *actualC
 	bool needNotations = false;
         bool tieStart = false;
         bool tieStop  = false;
-	if (note->status & STAT_PART_OF_TIE) {
+	if (note->properties & PROP_PART_OF_TIE) {
 		tieStop = true;
 		needNotations = true;
 		out_ << "\t\t\t\t<tie type=\"stop\"/>\n";
 	}
-	if (note->status & STAT_TIED) {
+	if (note->properties & PROP_TIED) {
 		tieStart = true;
 		needNotations = true;
 		out_ << "\t\t\t\t<tie type=\"start\"/>\n";
@@ -1250,16 +1259,16 @@ void NMusicXMLExport::outputNote(NNote *note, NVoice *voice_elem, NClef *actualC
 		needNotations = true;
 	}
 	bool needArti = false;
-	if (!note_nr && (chord->status_ & (STAT_STACC | STAT_SFORZ | STAT_PORTA | STAT_STPIZ | STAT_SFZND))) {
+	if (!note_nr && (chord->properties() & (PROP_STACC | PROP_SFORZ | PROP_PORTA | PROP_STPIZ | PROP_SFZND))) {
 		needArti = true;
 		needNotations = true;
 	}
 	bool fermata = false;
-	if (!note_nr && chord->status_ & STAT_FERMT) {
+	if (!note_nr && chord->hasProperty( PROP_FERMT ) ) {
 		fermata = true;
 		needNotations = true;
 	}
-	if (chord->status_ & STAT_ARPEGG) {
+	if (chord->hasProperty( PROP_ARPEGG ) ) {
 		needNotations = true;
 	}
 	bool needTrill = false;
@@ -1271,19 +1280,19 @@ void NMusicXMLExport::outputNote(NNote *note, NVoice *voice_elem, NClef *actualC
 	out_ << "\t\t\t\t<type>" << noteType << "</type>\n";
 	outputDots(chord);
 	bool tupletStart = false;
-	if (!note_nr && (chord->status_ & STAT_TUPLET) && chord->isFirstInTuplet()) {
+	if (!note_nr && (chord->hasProperty( PROP_TUPLET ) ) && chord->isFirstInTuplet()) {
 		tupletStart = true;
 		needNotations = true;
 	}
 	bool tupletStop = false;
-	if (!note_nr && (chord->status_ & STAT_LAST_TUPLET)) {
+	if (!note_nr && (chord->hasProperty( PROP_LAST_TUPLET ) )) {
 		tupletStop = true;
 		needNotations = true;
 	}
 	outputTimeMod(chord);
 	if (chord->getSubType() <= HALF_LENGTH) {
 		QString stemType = "";
-		if (chord->status_ & STAT_STEM_UP) {
+		if (chord->hasProperty( PROP_STEM_UP ) ) {
 			stemType = "up";
 		} else {
 			stemType = "down";
@@ -1291,8 +1300,8 @@ void NMusicXMLExport::outputNote(NNote *note, NVoice *voice_elem, NClef *actualC
 		out_ << "\t\t\t\t<stem>" << stemType << "</stem>\n";
 	}
 	// LVIFIX: add <staff>
-	if (!note_nr && chord->status_ & STAT_BEAMED) {
-		QList<NChord> *beamlist = 0;		// the group of beamed notes
+	if (!note_nr && chord->hasProperty( PROP_BEAMED ) ) {
+		QPtrList<NChord> *beamlist = 0;		// the group of beamed notes
 		int currlvl = 0;			// beam level current note
 		int nextlvl = 0;			// beam level next note
 		int prevlvl = 0;			// beam level previous note
@@ -1368,7 +1377,7 @@ void NMusicXMLExport::outputNote(NNote *note, NVoice *voice_elem, NClef *actualC
 			// fermata's are generated.
 			out_ << "\t\t\t\t\t<fermata type=\"upright\"/>\n";
 		}
-		if (chord->status_ & STAT_ARPEGG) {
+		if (chord->hasProperty( PROP_ARPEGG ) ) {
 			out_ << "\t\t\t\t\t<arpeggiate/>\n";
 		}
 		// articulations, which are mutually exclusive in NoteEdit
@@ -1377,19 +1386,19 @@ void NMusicXMLExport::outputNote(NNote *note, NVoice *voice_elem, NClef *actualC
 		// <... placement="below"/>
 		if (needArti) {
 			out_ << "\t\t\t\t\t<articulations>\n";
-			if (chord->status_ & STAT_STACC) {
+			if (chord->hasProperty( PROP_STACC ) ) {
 				out_ << "\t\t\t\t\t\t<staccato/>\n";
 			}
-			if (chord->status_ & STAT_SFORZ) {
+			if (chord->hasProperty( PROP_SFORZ ) ) {
 				out_ << "\t\t\t\t\t\t<strong-accent/>\n";
 			}
-			if (chord->status_ & STAT_PORTA) {
+			if (chord->hasProperty( PROP_PORTA ) ) {
 				out_ << "\t\t\t\t\t\t<tenuto/>\n";
 			}
-			if (chord->status_ & STAT_STPIZ) {
+			if (chord->hasProperty( PROP_STPIZ ) ) {
 				out_ << "\t\t\t\t\t\t<staccatissimo/>\n";
 			}
-			if (chord->status_ & STAT_SFZND) {
+			if (chord->hasProperty( PROP_SFZND ) ) {
 				out_ << "\t\t\t\t\t\t<accent/>\n";
 			}
 			out_ << "\t\t\t\t\t</articulations>\n";
@@ -1438,13 +1447,13 @@ void NMusicXMLExport::outputVoiceNr(int voice_nr) {
 	out_ << "\t\t\t\t<voice>" << voice_nr << "</voice>\n";
 }
 
-int NMusicXMLExport::calcDuration(int len, unsigned int status) {
+int NMusicXMLExport::calcDuration(int len, property_type properties) {
 	int dur = len * divisions_ / QUARTER_LENGTH;
-	switch (status & DOT_MASK) {
-		case STAT_DOUBLE_DOT:
+	switch (properties & DOT_MASK) {
+		case PROP_DOUBLE_DOT:
 			dur = dur * 7 / 4;
 			break;
-		case STAT_SINGLE_DOT:
+		case PROP_SINGLE_DOT:
 			dur = dur * 3 / 2;
 			break;
 	}
@@ -1456,18 +1465,18 @@ int NMusicXMLExport::calcDuration(int len, unsigned int status) {
 
 void NMusicXMLExport::calcLength(NMusElement *elem, int& dur, QString& type) {
 	int len = elem->getSubType();
-	unsigned int status = elem->status_;
+	property_type properties = ( elem->playable() ? elem->playable()->properties() : 0 );
 	dur = len * divisions_;
-	switch (status & DOT_MASK) {
-		case STAT_DOUBLE_DOT:
+	switch (properties & DOT_MASK) {
+		case PROP_DOUBLE_DOT:
 			dur = dur * 7 / 4;
 			break;
-		case STAT_SINGLE_DOT:
+		case PROP_SINGLE_DOT:
 			dur = dur * 3 / 2;
 			break;
 	}
-	if (status & STAT_TUPLET) {
-		dur = dur * elem->getPlaytime() / elem->getNumNotes();
+	if (properties & PROP_TUPLET && (elem->getType() & PLAYABLE) ) {
+		dur = dur * elem->playable()->getPlaytime() / elem->playable()->getNumNotes();
 	}
 	dur /= QUARTER_LENGTH;
 	switch (len) {
@@ -1488,17 +1497,17 @@ void NMusicXMLExport::calcLength(NMusElement *elem, int& dur, QString& type) {
 
 static int calcLengthForCalcDivisions(NMusElement *elem) {
 	int len = elem->getSubType();
-	unsigned int status = elem->status_;
-	switch (status & DOT_MASK) {
-		case STAT_DOUBLE_DOT:
+	property_type properties = ( elem->playable() ? elem->playable()->properties() : 0 );
+	switch (properties & DOT_MASK) {
+		case PROP_DOUBLE_DOT:
 			len = len * 7 / 4;
 			break;
-		case STAT_SINGLE_DOT:
+		case PROP_SINGLE_DOT:
 			len = len * 3 / 2;
 			break;
 	}
-	if (status & STAT_TUPLET) {
-		len = len * elem->getPlaytime() / elem->getNumNotes();
+	if (properties & PROP_TUPLET && (elem->getType() & PLAYABLE) ) {
+		len = len * elem->playable()->getPlaytime() / elem->playable()->getNumNotes();
 	}
 	return len;
 }
@@ -1539,7 +1548,7 @@ static void divideBy(int div) {
 // divisions by prime factors. Initialize the list with QUARTER_LENGTH to make sure a quarter
 // note can always be written as an integral number of units.
 
-void NMusicXMLExport::calcDivisions(QList<NStaff> *stafflist) {
+void NMusicXMLExport::calcDivisions(QPtrList<NStaff> *stafflist) {
 	NStaff *staff_elem;
 	NVoice *voice_elem;
 	NMusElement *elem;
@@ -1673,7 +1682,7 @@ NChord * NMusicXMLExport::findVaEndChord(NStaff * staff_elem, NChord * start_cho
 
 // write the part list
 
-void NMusicXMLExport::outputStaffAndVoiceDescription(QList<NStaff> *stafflist) {
+void NMusicXMLExport::outputStaffAndVoiceDescription(QPtrList<NStaff> *stafflist) {
 	NStaff *staff_elem;
 	int staffcount;
 	int i;
@@ -1925,17 +1934,19 @@ void NMusicXMLExport::outputDirection(QString direction, QString placement = "")
 
 void NMusicXMLExport::outputDots(NMusElement *elem)
 {
-	switch (elem->status_ & DOT_MASK) {
-		case STAT_DOUBLE_DOT:
-			out_ << "\t\t\t\t<dot/>\n";
-			out_ << "\t\t\t\t<dot/>\n";
-			break;
-		case STAT_SINGLE_DOT:
-			out_ << "\t\t\t\t<dot/>\n";
-			break;
-		default:
-			// ignored
-			break;
+	if( elem->playable() ) {
+		switch (elem->playable()->properties() & DOT_MASK) {
+			case PROP_DOUBLE_DOT:
+				out_ << "\t\t\t\t<dot/>\n";
+				out_ << "\t\t\t\t<dot/>\n";
+				break;
+			case PROP_SINGLE_DOT:
+				out_ << "\t\t\t\t<dot/>\n";
+				break;
+			default:
+				// ignored
+				break;
+		}
 	}
 }
 
@@ -1964,10 +1975,10 @@ void NMusicXMLExport::outputFrame(NChordDiagram *diag)
 
 void NMusicXMLExport::outputTimeMod(NMusElement *elem)
 {
-	if (elem->status_ & STAT_TUPLET) {
+	if ((elem->getType() & PLAYABLE) && ( elem->playable()->hasProperty( PROP_TUPLET ) ) ) {
 		out_ << "\t\t\t\t<time-modification>\n";
-		out_ << "\t\t\t\t\t<actual-notes>" << (int) elem->getNumNotes() << "</actual-notes>\n";
-		out_ << "\t\t\t\t\t<normal-notes>" << (int) elem->getPlaytime() << "</normal-notes>\n";
+		out_ << "\t\t\t\t\t<actual-notes>" << (int) elem->playable()->getNumNotes() << "</actual-notes>\n";
+		out_ << "\t\t\t\t\t<normal-notes>" << (int) elem->playable()->getPlaytime() << "</normal-notes>\n";
 		out_ << "\t\t\t\t</time-modification>\n";
 	}
 }
@@ -1988,14 +1999,14 @@ void NMusicXMLExport::outputMeter(NTimeSig *timesig) {
 void NMusicXMLExport::outputKeySig(NKeySig *key) {
 	badinfo *bad;
 	int count;
-	int kind;
+	property_type kind;
 
 	out_ << "\t\t\t\t<key>\n";
 	out_ << "\t\t\t\t\t<fifths>";
 
 	if (key->isRegular(&kind, &count)) {
 		switch(kind) {
-			case STAT_CROSS:
+			case PROP_CROSS:
 				switch (count) {
 					case 0: out_ << 0; break;
 					case 1: out_ << 1; break;
@@ -2008,7 +2019,7 @@ void NMusicXMLExport::outputKeySig(NKeySig *key) {
 					default: NResource::abort("NMusicXMLExport::outputKeySig", 1);
 				}
 				break;
-			case STAT_FLAT:
+			case PROP_FLAT:
 				switch (count) {
 					case 0: out_ <<  0; break;
 					case 1: out_ << -1; break;
@@ -2021,7 +2032,7 @@ void NMusicXMLExport::outputKeySig(NKeySig *key) {
 					default: NResource::abort("NMusicXMLExport::outputKeySig", 2);
 				}
 				break;
-			case STAT_NO_ACC:
+			case PROP_NO_ACC:
 				out_ << 0;
 				break;
 			default: NResource::abort("NMusicXMLExport::outputKeySig", 3);
