@@ -19,6 +19,7 @@
 /*											*/
 /****************************************************************************************/
 
+/*		leon.vinken@hetnet.nl							*/
 
 // Import MusicXML
 
@@ -46,8 +47,6 @@
 
 // LVIFIX: tuplets generate "currentMidiTime < cvMidiEndTime" errors
 
-// LVIFIX: UTF-16 is not supported on Qt2
-
 // LVIFIX: check accel/ritard handling in multi-staff parts
 // (Dichterliebe01 measures 12 and 24)
 // append to both staves does not seem to give the desired effect
@@ -143,6 +142,7 @@ using namespace std;
 #include "parsertypes.h"
 #include "rest.h"
 #include "staff.h"
+#include "text.h"
 #include "voice.h"
 #include "../kguitar_excerpt/global.h"
 
@@ -177,7 +177,7 @@ void VoiceMapper::cleanup()
 	map.clear();
 }
 
-// get the noteedit voice number for musicxml voice staff/mxmlVoice
+// get the noteedit's voice number for musicxml voice staff/mxmlVoice
 // return -1 if not found
 
 int VoiceMapper::get(int staff, int mxmlVoice)
@@ -203,9 +203,10 @@ void VoiceMapper::set(int staff, int mxmlVoice, int ntdtVoice)
 	int k = sv2k(staff, mxmlVoice);
 	IntIntMap::Iterator it;
 	it = map.find(k);
-	if (it == map.end()) {
+	if (it == map.end())
 		map.insert(k, ntdtVoice);
-	}
+	else
+		map.replace(k, ntdtVoice);
 }
 
 
@@ -217,6 +218,10 @@ MusicXMLErrorHandler::MusicXMLErrorHandler()
 	parser = 0;
 }
 
+MusicXMLErrorHandler::~MusicXMLErrorHandler()
+{
+}
+
 bool MusicXMLErrorHandler::warning(const QXmlParseException& exception)
 {
 	cerr << "MusicXMLErrorHandler::warning"
@@ -275,13 +280,13 @@ void MusicXMLErrorHandler::setParser(MusicXMLParser * p)
 
 // readStaffs(): the public interface to the MusicXML parser
 
-bool MusicXMLParser::readStaffs(const char *fname, QList<NVoice> *voilist, QList<NStaff> *stafflist, NMainFrameWidget *mainWidget) {
+bool MusicXMLParser::readStaffs(const char *fname, QPtrList<NVoice> *voilist, QPtrList<NStaff> *stafflist, NMainFrameWidget *mainWidget) {
 	int i;
 	int parser_return;
 	NVoice *voice_elem;
 	NStaff *staff_elem;
-	QList<NVoice> newVoices;
-	QList<NStaff> newStaffs;
+	QPtrList<NVoice> newVoices;
+	QPtrList<NStaff> newStaffs;
 	layoutDef *layoutinfo;
 	int staffCount;
 
@@ -426,6 +431,7 @@ MusicXMLParser::MusicXMLParser()
 {
 	current_staff = 0;
 	current_voice = 0;
+	current_max_voice_nr = 0;
 }
 
 
@@ -561,6 +567,7 @@ bool MusicXMLParser::startElement( const QString&, const QString&,
     		// store the clef number
 		stCln = attributes.value("number");
 	} else if (qName == "direction") {
+		stPlc = attributes.value("placement");
 		initStDirect();
 	} else if (qName == "ending") {
 		stEnr = attributes.value("number");
@@ -682,7 +689,7 @@ bool MusicXMLParser::endElement( const QString&, const QString&,
 	QString Str;
 	if (false) {
 	} else if (qName == "accent") {
-		status |= STAT_SFZND;
+		properties |= PROP_SFZND;
 	} else if (qName == "accidental") {
 		stAcc = stCha;
 	} else if (qName == "actual-notes") {
@@ -757,7 +764,7 @@ bool MusicXMLParser::endElement( const QString&, const QString&,
 		stDyn = "f";
 	} else if (qName == "fermata") {
 		// NoteEdit does not distinguish between upright and inverted
-		status |= STAT_FERMT;
+		properties |= PROP_FERMT;
 	} else if (qName == "ff") {
 		stDyn = "ff";
 	} else if (qName == "fff") {
@@ -842,9 +849,9 @@ bool MusicXMLParser::endElement( const QString&, const QString&,
 	} else if (qName == "sign") {
 		if (stCln == "2") { stCsi2 = stCha; } else { stCsi = stCha; }
 	} else if (qName == "staccatissimo") {
-		status |= STAT_STPIZ;
+		properties |= PROP_STPIZ;
 	} else if (qName == "staccato") {
-		status |= STAT_STACC;
+		properties |= PROP_STACC;
 	} else if (qName == "staves") {
 		stSta = stCha;
 		if (stSta == "0") {
@@ -869,9 +876,9 @@ bool MusicXMLParser::endElement( const QString&, const QString&,
 	} else if (qName == "string") {
 		stStr = stCha;
 	} else if (qName == "strong-accent") {
-		status |= STAT_SFORZ;
+		properties |= PROP_SFORZ;
 	} else if (qName == "tenuto") {
-		status |= STAT_PORTA;
+		properties |= PROP_PORTA;
 	} else if (qName == "text") {
 		stTxt = stCha;
 		handleLyrics();
@@ -1014,12 +1021,15 @@ bool MusicXMLParser::addNote()
 	if (stGra) {
 		dur = 0;
 		if (stTyp == "eighth") {
-			status |= STAT_GRACE;
+			properties |= PROP_GRACE;
 			if (stGsl) {
 				length = INTERNAL_MARKER_OF_STROKEN_GRACE;
 			}
-		} else if (stTyp == "16th") {
-			status |= STAT_GRACE;
+		} else if ( (stTyp == "16th") || (stTyp == "32nd") ) {
+			/* FIXME: Only 8th and 16th grace notes are supported by NoteEdit. If shorter found, set it to 16th */
+			stTyp = "16th";
+			length = mxmlNoteType2Ne(stTyp);
+			properties |= PROP_GRACE;
 		} else {
 			Str = "illegal grace note <type>: " + stTyp;
 			reportWarning(Str);
@@ -1033,14 +1043,14 @@ bool MusicXMLParser::addNote()
 		}
 	}
 	if (stTie) {
-		status |= STAT_TIED;
+		properties |= PROP_TIED;
 	}
 	if (stDts == 0) {
-		/* do nothing status = 0 */ ;
+		/* do nothing properties = 0 */ ;
 	} else if (stDts == 1) {
-		status |= STAT_SINGLE_DOT;
+		properties |= PROP_SINGLE_DOT;
 	} else if (stDts == 2) {
-		status |= STAT_DOUBLE_DOT;
+		properties |= PROP_DOUBLE_DOT;
 	} else {
 		Str.setNum(stDts);
 		Str = "illegal number of dots: " + Str;
@@ -1069,15 +1079,15 @@ bool MusicXMLParser::addNote()
 		}
 	/* End of J.Anders 12-23-2003 */
 	} else if (stAcc == "flat-flat") {
-		offs = -2; status |= STAT_FORCE;
+		offs = -2; properties |= PROP_FORCE;
 	} else if (stAcc == "flat") {
-		offs = -1; status |= STAT_FORCE;
+		offs = -1; properties |= PROP_FORCE;
 	} else if (stAcc == "natural") {
-		offs =  0; status |= STAT_FORCE;
+		offs =  0; properties |= PROP_FORCE;
 	} else if (stAcc == "sharp") {
-		offs =  1; status |= STAT_FORCE;
+		offs =  1; properties |= PROP_FORCE;
 	} else if ((stAcc == "double-sharp") || (stAcc == "sharp-sharp")) {
-		offs =  2; status |= STAT_FORCE;
+		offs =  2; properties |= PROP_FORCE;
 	} else {
 		Str = "illegal <accidental> value: " + stAcc;
 		reportWarning(Str);
@@ -1109,7 +1119,9 @@ bool MusicXMLParser::addNote()
 		// default to voice 1
 		stVoi = "1";
 	}
+
 	handleVoice(stStf.toInt(), stVoi.toInt());
+	
 	// if necessary, fill the voice with hidden rests until the given time
 	// is reached (which effectively also converts all <forward>'s into
 	// hidden rests).
@@ -1137,7 +1149,7 @@ bool MusicXMLParser::addNote()
 					 &(staff->staff_props_),
 					 &(current_voice->yRestOffs_),
 					 length,
-					 status);
+					 properties);
 			current_voice->appendElem(rest);
 			handleTuplet(rest);
 			prev_time = current_time;
@@ -1170,7 +1182,7 @@ bool MusicXMLParser::addNote()
 					NNote * note = chrd->insertNewNote(line,
 								   offs,
 								   stemPol,
-								   status);
+								   properties);
 					// handle ties, for first note done
 					// by NVoice::appendElem. The .not
 					// parser first builds the chord and
@@ -1178,7 +1190,7 @@ bool MusicXMLParser::addNote()
 					// ties for all notes
 					if (note) {
 						current_voice->reconnectFileReadTies(note);
-						if (status & STAT_TIED) {
+						if (properties & PROP_TIED) {
 							current_voice->findTieMember(note);
 						}
 					}
@@ -1191,22 +1203,24 @@ bool MusicXMLParser::addNote()
 				// -> append new chord
 				NChord * chrd = new NChord(&(parser_params.mainWidget->main_props_),
 							   &(staff->staff_props_),
-						           line,
+							   current_voice,
+						       line,
 							   offs,
 							   length,
 							   stemPol,
-							   status);
+							   properties);
 				current_voice->appendElem(chrd);
 				lastChord = chrd;
 			}
 		} else {
 			NChord * chrd = new NChord(&(parser_params.mainWidget->main_props_),
 						   &(staff->staff_props_),
-					           line,
+						   current_voice,
+					       line,
 						   offs,
 						   length,
 						   stemPol,
-						   status);
+						   properties);
 			current_voice->appendElem(chrd);
 			lastChord = chrd;
 			// LVIFIX: this only handles chord diagram at notes
@@ -1391,6 +1405,30 @@ void MusicXMLParser::appendSign(int type)
 }
 
 
+// append an NText (arbitrary text) to the current stave(s)
+// QString textVal is a text itself
+
+void MusicXMLParser::appendText(QString textVal)
+{
+	NText * text;
+	NVoice * voice;
+	int type = (stPlc == "below") ? TEXT_DOWNTEXT : TEXT_UPTEXT;
+	
+	voice = current_staff->getVoiceNr(0);
+	text = new NText(voice->getMainPropsAddr(),
+			current_staff->getStaffPropsAddr(),
+			textVal, type);
+	voice->appendElem(text);
+	if (current_2ndstaff) {
+		voice = current_2ndstaff->getVoiceNr(0);
+		text = new NText(voice->getMainPropsAddr(),
+				current_2ndstaff->getStaffPropsAddr(),
+				textVal, type);
+		voice->appendElem(text);
+	}
+}
+
+
 // convert time in divisions to miditime
 // note that QUARTER_LENGTH=161280, causing an overflow when divs>13315
 // assuming a 32-bit system
@@ -1588,11 +1626,11 @@ void MusicXMLParser::handleAttributes()
 		if (res) {
 			if ((-7 <= iFif) && (iFif <= 7)) {
 				int count;
-				int kind;
+				property_type kind;
 				if (iFif < 0) {
-					count = -iFif; kind = STAT_FLAT;
+					count = -iFif; kind = PROP_FLAT;
 				} else {
-					count =  iFif; kind = STAT_CROSS;
+					count =  iFif; kind = PROP_CROSS;
 				}
 				if (count > 0) {
 					// LVIFIX: check handling accidentals and key signature
@@ -1741,6 +1779,20 @@ void MusicXMLParser::handleBarline()
 			reportWarning(Str);
 		}
 	} else if (stBll == "right") {
+		/* fill the first voice with rests until the needed MIDI time
+		   to place the bar is achieved */
+		current_voice->computeMidiTime(false, false);
+		int neededMidiTime = current_voice->getMidiEndTime();
+		current_voice = current_staff->getVoiceNr(0);
+		fillUntil(neededMidiTime, true, false);
+		
+		/* and do the same for 2nd staff if present */
+		if (current_2ndstaff) {
+			current_voice = current_2ndstaff->getVoiceNr(0);
+			fillUntil(neededMidiTime, true, false);
+			current_voice = current_staff->getVoiceNr(0);
+		}
+				
 		// note: changing the list of supported subtypes means
 		// also changing handleEndOfMeasure()
 		if ((stBst == "") && (stRdi == "")) {
@@ -1960,9 +2012,9 @@ void MusicXMLParser::handlePedal(NChord * chord)
 	if (stPdl == "") {
 		return; // nothing to do
 	} else if (stPdl == "start") {
-		chord->status2_ |= STAT2_PEDAL_ON;
+		chord->addProperty( PROP_PEDAL_ON );
 	} else if (stPdl == "stop") {
-		chord->status2_ |= STAT2_PEDAL_OFF;
+		chord->addProperty( PROP_PEDAL_OFF );
 	} else {
 		Str = "illegal pedal type: " + stPdl;
 		reportWarning(Str);
@@ -2466,6 +2518,9 @@ void MusicXMLParser::handleVoice(int staff_nr, int voice_nr)
 void MusicXMLParser::handleVoiceDoStaff(int staff_nr, int voice_nr,
 				NStaff * & staff, bool & mapped)
 {
+	if (voice_nr > current_max_voice_nr)
+		current_max_voice_nr = voice_nr;
+		
 	int ntdtVnr = vm.get(staff_nr, voice_nr);
 	if (ntdtVnr >= 0) {
 		// voice already exists
@@ -2480,14 +2535,31 @@ void MusicXMLParser::handleVoiceDoStaff(int staff_nr, int voice_nr,
 		mapped = true;
 		current_voice = staff->getVoiceNr(0);
 	} else {
-		// new voice for this staff
+		// add a new voice in this staff
 		// create and map a new voice
 		staff->addVoices(1);
 		int nv = staff->voiceCount() - 1;
+
+		/* sort NoteEdit voices like they're sorted in MusicXML file for that staff */
+		/* int tmpVnr;
+		for (int i = 1; voice_nr+i <= current_max_voice_nr; i++) {
+			if (tmpVnr = vm.get(staff_nr, voice_nr+i) == -1) continue;
+			if (tmpVnr < nv) {
+				vm.set(staff_nr, voice_nr+i, nv);
+				vm.set(staff_nr, voice_nr, tmpVnr);
+				staff->moveVoice(nv, tmpVnr);
+				staff->moveVoice(tmpVnr+1, nv+1);
+				nv = tmpVnr;
+				break;
+			}
+		} */ /* disabled, because we cannot move between non-first voices and first voices */
+		
 		current_voice = staff->getVoiceNr(nv);
 		vm.set(staff_nr, voice_nr, nv);
 		parser_params.newVoices->append(current_voice);
+
 	}
+
 	int k = sv2k(staff_nr, voice_nr);
 	beamStarts[k] = 0;
 }
@@ -2517,8 +2589,7 @@ void MusicXMLParser::handleWords()
 	} else if (stWrd == "ritard.") {
 		type = RITARDANDO;
 	} else {
-		Str = "not supported: <words> " + stWrd;
-		reportWarning(Str);
+		appendText(stWrd); // if none of the standard words are found, place an arbitrary text then
 		return;
 	}
 	appendSign(type);
@@ -2606,7 +2677,7 @@ void MusicXMLParser::initStHarmony()
 
 void MusicXMLParser::initStNote()
 {
-	status = 0;
+	properties = 0;
 	stAcc = "";
 	stAlt = "";
 	stAno = "";
@@ -2666,7 +2737,7 @@ void MusicXMLParser::insertRest(int length, bool hidden)
 {
 	for (int i = DOUBLE_WHOLE_LENGTH; i >= NOTE128_LENGTH; i /= 2) {
 		while (length >= i) {
-			int stat = hidden ? STAT_HIDDEN : 0;
+			int stat = hidden ? PROP_HIDDEN : 0;
 			NRest * rest = new NRest(&(parser_params.mainWidget->main_props_),
 						 &(current_voice->getStaff()->staff_props_),
 						 &(current_voice->yRestOffs_),
@@ -2819,9 +2890,9 @@ void MusicXMLParser::wdghStEl(const QString& tp)
 		} else if (wdghFirstChordPtr == 0) {
 			Str = "wedge without chords";
 			reportWarning(Str);
-		} else {
-			wdghFirstChordPtr->dynamicAlign_ = wdghTypeCres;
-			wdghFirstChordPtr->dynamic_ =
+		} else if ( wdghFirstChordPtr->chord() ) {
+			wdghFirstChordPtr->chord()->dynamicAlign_ = wdghTypeCres;
+			wdghFirstChordPtr->chord()->dynamic_ =
 				(dm << 16) | (dt / MULTIPLICATOR);
 		}
 		wdghInit();
