@@ -20,7 +20,9 @@
 /*											*/
 /****************************************************************************************/
 
+#ifndef WITH_SCONS
 #include "config.h"
+#endif
 #if GCC_MAJ_VERS > 2
 #include <iostream>
 #include <sstream>
@@ -77,7 +79,7 @@ NMusiXTeX::NMusiXTeX() {
 }
 
 
-void NMusiXTeX::exportStaffs(QString filen, QList<NStaff> *stafflist, exportFrm *form, NMainFrameWidget *mainWidget) {
+void NMusiXTeX::exportStaffs(QString filen, QPtrList<NStaff> *stafflist, exportFrm *form, NMainFrameWidget *mainWidget) {
 	mainWidget_ = mainWidget;
 	staffList_ = stafflist;
 	staffCount_ = stafflist->count();
@@ -92,8 +94,8 @@ void NMusiXTeX::doExport() {
 	NExportError *exerr;
 	NExportError *errptr;
 	NPositStr *posit;
-	QList<NPositStr> plist;
-	char *notesString;
+	QPtrList<NPositStr> plist;
+	char notesString[10];
 	bool withLyrics;
 #if GCC_MAJ_VERS > 2
 	ostringstream os;
@@ -103,7 +105,7 @@ void NMusiXTeX::doExport() {
 #endif
 	NStaff *staff_elem;
 	NVoice *voice_elem;
-	QList<QString> lyrNames;
+	QPtrList<QString> lyrNames;
 	QString *lyrName;
 	int myTime_ = 0;
 	int num_positions, maxwidth, min_time = (1 << 30);
@@ -115,14 +117,15 @@ void NMusiXTeX::doExport() {
 	QString lyricslist[NUM_LYRICS];
 	QString *staffname;
 	int count_of_lyrics;
-	int kind, z;
+	property_type kind;
+	int z;
 	bool lyrcsLineCounts[NUM_LYRICS];
 	bool somethingProduced;
 	bool tex_special = false;
 	bool generalmeter_set;
 	int voice_count;
 	int staffs_to_export;
-	int real_staff_nr, staff_nr;
+	int real_staff_nr = -1, staff_nr; // RK: Was not initialized, is this correct ?
 	int dummy, multistaffnr;
 	int rst_nr;
 	int numOfStaffsInMultistaff;
@@ -137,9 +140,11 @@ void NMusiXTeX::doExport() {
 	maxSlurs_ = 6;
 	spare_ = false;
 	newTempo_ = -1;
-	limitMeasures_ = exportDialog_->texMeasures_->isChecked();
+	// Read options from export Dialog
+	exportDialog_->getMusiXTeXOptions( musixOpts_ );
+	limitMeasures_ = musixOpts_.measures;
 	if (limitMeasures_) {
-		maxMeasuresPerLine_ = exportDialog_->measureVal->value();
+		maxMeasuresPerLine_ = musixOpts_.measureVal;
 	}
 	if (NResource::staffSelExport_ == 0) {
 		NResource::staffSelExport_ = new bool[staffCount_];
@@ -191,6 +196,7 @@ void NMusiXTeX::doExport() {
 		lyrcsLineCounts[i] = false;
 	}
 	for (i = 0, staff_elem = staffList_->first(); staff_elem; staff_elem = staffList_->next(), i++) {
+		real_staff_nr = staffList_->find(staff_elem);
 		voice_elem = staff_elem->getVoiceNr(0);
 		if (voice_elem->getLastBarNr() > lastBarNr_) lastBarNr_ = voice_elem->getLastBarNr();
 		maxlyrics = voice_elem->countOfLyricsLines();
@@ -220,10 +226,10 @@ void NMusiXTeX::doExport() {
 	out_ << "\\documentclass{article}"  << endl;
 	out_ << "\\usepackage{musixtex}" << endl << endl;
 
-	switch(exportDialog_->texOutputEncoding->currentItem()) {
+	switch(musixOpts_.outputEncoding) {
 		case 1: out_ << "\\usepackage[utf8]{inputenc}" << endl; break;
 	}
-	switch(exportDialog_->texFontModule->currentItem()) {
+	switch(musixOpts_.fontModule) {
 		case 1: out_ << "\\usepackage[T2A]{fontenc}" << endl; break;
 		case 2: out_ << "\\usepackage[T2B]{fontenc}" << endl; break;
 		case 3: out_ << "\\usepackage[T2C]{fontenc}" << endl; break;
@@ -232,13 +238,13 @@ void NMusiXTeX::doExport() {
 		case 6: out_ << "\\usepackage[X2]{fontenc}" << endl; break;
 		case 7: out_ << "\\usepackage[LCY]{fontenc}" << endl; break;
 	}
-	switch(exportDialog_->texInputEncoding->currentItem()) {
+	switch(musixOpts_.inputEncoding) {
 		case 1: out_ << "\\usepackage[latin1]{inputenc}" << endl; break;
 		case 2: out_ << "\\usepackage[cp1251]{inputenc}" << endl; break;
 		case 3: out_ << "\\usepackage[koi8-u]{fontenc}" << endl; break;
 		case 4: out_ << "\\usepackage[koi8-r]{fontenc}" << endl; break;
 	}
-	if (exportDialog_->texUcs->isChecked()) {
+	if (musixOpts_.ucs) {
 		out_ << "\\usepackage{ucs}" << endl;
 	}
 	out_ << "\\input musixper.tex" << endl;
@@ -251,35 +257,35 @@ void NMusiXTeX::doExport() {
 		badMeasures_.append(exerr);
 		out_ << "\\input musixdbr.tex" << endl;
 	}
-	if (exportDialog_->texMLyr->isChecked()) {
+	if (musixOpts_.mLyr) {
 		out_ << "\\input musixlyr.tex"  << endl;
 	}
-	if (exportDialog_->texOmitPageNumbering->isChecked()) {
+	if (musixOpts_.omitPageNumbering) {
 	               out_ << endl << "\\pagestyle{empty}" << endl << endl;
 	}
 	out_ << "\\input musixgui.tex" << endl << endl;
-	out_ << "\\setlength{\\parindent}{" << exportDialog_->texParindent->text() << "mm}" << endl;
-	out_ << "\\setlength{\\textwidth}{" << exportDialog_->texWidth->text() << "mm}" << endl;
-	out_ << "\\setlength{\\textheight}{" << exportDialog_->texHeight->text() << "mm}" << endl;
-	out_ << "\\setlength{\\topmargin}{" << exportDialog_->texTop->text() << "mm}" << endl;
-	out_ << "\\setlength{\\oddsidemargin}{" << exportDialog_->texLeft->text() << "mm}" << endl << endl;
-	switch (exportDialog_->texSize->currentItem()) {
+	out_ << "\\setlength{\\parindent}{" << musixOpts_.parindent << "mm}" << endl;
+	out_ << "\\setlength{\\textwidth}{" << musixOpts_.width << "mm}" << endl;
+	out_ << "\\setlength{\\textheight}{" << musixOpts_.height << "mm}" << endl;
+	out_ << "\\setlength{\\topmargin}{" << musixOpts_.top << "mm}" << endl;
+	out_ << "\\setlength{\\oddsidemargin}{" << musixOpts_.left << "mm}" << endl << endl;
+	switch (musixOpts_.size) {
 		case 0: out_ << "\\smallmusicsize" << endl; break;
 		case 2: out_ << "\\largemusicsize" << endl; break;
 		case 3: out_ << "\\Largemusicsize" << endl; break;
 	}
-	if (!exportDialog_->texBar->isChecked()) {
+	if (musixOpts_.bar) {
 		out_ << "\\nobarnumbers" << endl;
 	}
 
 	out_ << "\\raiseguitar{20}" << endl;
 
-	spare_ = exportDialog_->texTies->isChecked();
+	spare_ = musixOpts_.ties;
 	out_ << "\\begin{document}" << endl << endl;
 
 	lyrNames.setAutoDelete(true);
 	k = 0;
-	for (i = 0, staff_elem = staffList_->first(); exportDialog_->texMLyr->isChecked() && staff_elem; staff_elem = staffList_->next(), i++) {
+	for (i = 0, staff_elem = staffList_->first(); musixOpts_.mLyr && staff_elem; staff_elem = staffList_->next(), i++) {
 		if (!NResource::staffSelExport_[i]) continue;
 		voice_elem = staff_elem->getVoiceNr(0);
 		voice_elem->setIdx(i);
@@ -358,7 +364,7 @@ void NMusiXTeX::doExport() {
 	if (!mStaffInf_->ContinuedBarLines()) {
 		if (mStaffInf_->DiscontOutsidePiano()) {
 			out_ << "\\indivbarrules" << endl << "\\allbarrules\\sepbarrule";
-			for (i = 0; i < staffCount_; i++) {
+			for (i = 0; i < (int)staffCount_; i++) {
 				if (mainWidget_->barCont_[i].valid) {
 					for (j = mainWidget_->barCont_[i].beg; j < mainWidget_->barCont_[i].end; j++) {
 						idx = mStaffInf_->multistaffIdxOfStaff(j, &multistaffnr, &numOfStaffsInMultistaff);
@@ -396,7 +402,7 @@ void NMusiXTeX::doExport() {
 		if (ksig) {
 			if (ksig->isRegular(&kind, &z)) {
 				if (z != 0) {
-					out_ << "\\setsign{" << i << "}{" << ((kind == STAT_CROSS) ? z : -z) << "}" << endl;
+					out_ << "\\setsign{" << i << "}{" << ((kind == PROP_CROSS) ? z : -z) << "}" << endl;
 				}
 			}
 			else {
@@ -481,7 +487,7 @@ void NMusiXTeX::doExport() {
 			if (width > maxwidth) maxwidth = width;
 			switch(posit->elem->getType()) {
 			case T_CHORD:
-				if (posit->ev_type & STAT_GRACE) grace_notes = true;
+				if (posit->ev_type & PROP_GRACE) grace_notes = true;
 				break;
 			case T_SIGN:
 				switch (posit->elem->getSubType()) {
@@ -500,27 +506,27 @@ void NMusiXTeX::doExport() {
 				if (posit->elem->getMidiLength() < minlength) minlength = posit->elem->getMidiLength();
 			}
 		}
-		if (!exportDialog_->texMLyr->isChecked() && withLyrics) {
-			if (maxwidth < 12) notesString = "\\notes";
-			else if (maxwidth < 14) notesString = "\\notesp";
-			else if (maxwidth < 16) notesString = "\\Notes";
-			else if (maxwidth < 18) notesString = "\\Notesp";
-			else if (maxwidth < 20) notesString = "\\NOtes";
-			else if (maxwidth < 22) notesString = "\\NOtesp";
-			else if (maxwidth < 24) notesString = "\\NOTes";
-			else if (maxwidth < 26) notesString = "\\NOTesp";
-			else notesString = "\\NOTEs";
+		if (!musixOpts_.mLyr && withLyrics) {
+			if (maxwidth < 12)      strcpy( notesString, "\\notes" );
+			else if (maxwidth < 14) strcpy( notesString, "\\notesp" );
+			else if (maxwidth < 16) strcpy( notesString, "\\Notes" );
+			else if (maxwidth < 18) strcpy( notesString, "\\Notesp" );
+			else if (maxwidth < 20) strcpy( notesString, "\\NOtes" );
+			else if (maxwidth < 22) strcpy( notesString, "\\NOtesp" );
+			else if (maxwidth < 24) strcpy( notesString, "\\NOTes" );
+			else if (maxwidth < 26) strcpy( notesString, "\\NOTesp" );
+			else                    strcpy( notesString, "\\NOTEs" );
 		}
 		else {
-			if (grace_notes) notesString = "\\notes";
-			else if (minlength >= HALF_LENGTH*3/2) notesString = "\\NOTEs";
-			else if (minlength >= HALF_LENGTH) notesString = "\\NOTes";
-			else if (minlength >= QUARTER_LENGTH*3/2) notesString = "\\NOtesp";
-			else if (minlength >= QUARTER_LENGTH) notesString = "\\NOtes";
-			else if (minlength >= NOTE8_LENGTH*3/2) notesString = "\\Notesp";
-			else if (minlength >= NOTE8_LENGTH) notesString = "\\Notes";
-			else if (minlength >= NOTE16_LENGTH*3/2) notesString = "\\notesp";
-			else notesString = "\\notes";
+			if (grace_notes)                          strcpy( notesString, "\\notes" );
+			else if (minlength >= HALF_LENGTH*3/2)    strcpy( notesString, "\\NOTEs" );
+			else if (minlength >= HALF_LENGTH)        strcpy( notesString, "\\NOTes" );
+			else if (minlength >= QUARTER_LENGTH*3/2) strcpy( notesString, "\\NOtesp" );
+			else if (minlength >= QUARTER_LENGTH)     strcpy( notesString, "\\NOtes" );
+			else if (minlength >= NOTE8_LENGTH*3/2)   strcpy( notesString, "\\Notesp" );
+			else if (minlength >= NOTE8_LENGTH)       strcpy( notesString, "\\Notes" );
+			else if (minlength >= NOTE16_LENGTH*3/2)  strcpy( notesString, "\\notesp" );
+			else                                      strcpy( notesString, "\\notes" );
 		}
 
 		somethingProduced = false;
@@ -611,9 +617,7 @@ void NMusiXTeX::doExport() {
 	if (!badMeasures_.isEmpty()) {
 		QString output;
 		output = i18n
-			("Noteedit has exported the score to MusiXTeX but there are some\n"
-			 "constructs which cannot be expressed in MusiXTeX. The score will\n"
-			 "work with MusiXTeX but Noteedit omitted these constructs.\n");
+			("NoteEdit has exported the score to MusiXTeX format but there are some problems which can prevent successful PostScript/PDF output or can change the final score layout.\n");
 		output += i18n("-----------------------------------------------------\n");
 		for (errptr = badMeasures_.first(); errptr; errptr = badMeasures_.next()) {
 			switch (errptr->reason) {
@@ -679,12 +683,12 @@ void NMusiXTeX::doExport() {
 		
 	}
 	// do musixtex-postprocessing if desired
-  	if (exportDialog_->musixtexcmd->text().isEmpty() || exportDialog_->musixtexcmd->text().isNull()) {
+  	if (musixOpts_.musixtexcmd.isEmpty() || musixOpts_.musixtexcmd.isNull()) {
 	  NResource::musixScript_.truncate(0);
 	}
 	else {
-	  externalCmd(exportDialog_->musixtexcmd->text(),fileName);
-	  NResource::musixScript_ = exportDialog_->musixtexcmd->text();
+	  externalCmd(musixOpts_.musixtexcmd,fileName);
+	  NResource::musixScript_ = musixOpts_.musixtexcmd;
   	}
 	
 }
@@ -738,10 +742,10 @@ void NMusiXTeX::writeContextChange() {
 }
 
 void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelimiter, NMusElement *elem, NStaff *staff_elem, NVoice *ac_voice) {
-	QList<NNote> *notelist;
+	QPtrList<NNote> *notelist;
 	NExportError *exerr;
 	QString *s;
-	char *bodyString;
+	char bodyString[5];
 	int lastBodyState;
 	bool first, body_changed;
 	QString stemdir;
@@ -752,16 +756,18 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 	QString musi_length;
 	NNote *base_note;
 	NChord *chord;
+	NRest *rest;
 	NChordDiagram *diag;
-	QList<NNote> *notes_to_be_shifted, *notes_not_to_be_shifted;
+	QPtrList<NNote> *notes_to_be_shifted, *notes_not_to_be_shifted;
 	
 	int countLyricsLines;
 	bool shift_needed;
 	bool toomany, nested, problem128;
 	int num;
-	int kind, z, i;
+	property_type kind;
+	int z, i;
 	int hline;
-	QList<NNote> *acc_list;
+	QPtrList<NNote> *acc_list;
 
 	lastSignWasBar_ = false;
 	lastSignWasRepeatClose_ = false;
@@ -770,11 +776,11 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 			     writeStaffTexts(real_staff_nr);
 			     chord = (NChord *) elem;
 			     chord->initialize_acc_pos_computation();
-			     if ((chord->status_ & STAT_GRACE) && noteSizeIsNormal_) {
+			     if ((chord->hasProperty( PROP_GRACE ) ) && noteSizeIsNormal_) {
 					out_ << "\\multnoteskip\\tinyvalue\\tinynotesize";
 					noteSizeIsNormal_ = false;
 			     }
-			     else if (!(chord->status_ & STAT_GRACE) && !noteSizeIsNormal_) {
+			     else if (!(chord->hasProperty( PROP_GRACE ) ) && !noteSizeIsNormal_) {
 					out_ << "\\multnoteskip\\normalvalue\\normalnotesize";
 					noteSizeIsNormal_ = true;
 			     }
@@ -783,13 +789,13 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 					newTempo_ = -1;
 			     }
 			     notelist = chord->getNoteList();
-			     if (chord->status_ & STAT_ARPEGG) {
+			     if (chord->hasProperty( PROP_ARPEGG ) ) {
 			     		note = notelist->first();
 					note2 = notelist->last();
 					out_ << "\\hsk\\arpeggio{" << staff_elem->actualClef_.line2TexTab_[note->line+LINE_OVERFLOW-1] <<
 						"}{" << (note2->line - note->line + 3) / 2 << '}';
 			     }
-			     if ((diag = elem->getChordChordDiagram()) != 0) {
+			     if ((diag = chord->getChordChordDiagram()) != 0) {
 				writeChordDiagram(diag);
 			     }
 			     for (z = 0, i = chord->getNumOfTexAccRows() - 1; i >= 0; i--, z++) {
@@ -810,9 +816,9 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 				   }
 				}
 			     }
-			     stemdir = ((elem->status_ & STAT_STEM_UP) ? QString("u") : QString("l"));
-			     countLyricsLines = ((NChord *) elem)->countOfLyricsLines();
-			     if (!exportDialog_->texMLyr->isChecked()) {
+			     stemdir = ((chord->hasProperty( PROP_STEM_UP ) ) ? QString("u") : QString("l"));
+			     countLyricsLines = chord->countOfLyricsLines();
+			     if (!musixOpts_.mLyr) {
 			     	for (i = countLyricsLines-1; i >= 0; i--) {
 						lyrics = chord->getLyrics(i);
 						if (lyrics) {
@@ -820,7 +826,7 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 						}
 			     	}
 			     }
-			     s = elem->computeTeXTuplet(&(staff_elem->actualClef_));
+			     s = chord->computeTeXTuplet(&(staff_elem->actualClef_));
 			     if (s) {
 				out_ << *s;
 				delete s;
@@ -843,7 +849,7 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 				out_ << *s;
 				delete s;
 			     }
-			     if (elem->status_ & STAT_BEAMED) {
+			     if (chord->hasProperty( PROP_BEAMED ) ) {
 				 s = chord->computeTeXBeam(MAXSTAFFSANDBEAMS, &beamPool_, &(ac_voice->beamNr_), &(ac_voice->beamCount_),
 						 &(staff_elem->actualClef_), MAXFLAGS, &problem128, &toomany);
 				 if (problem128) {
@@ -890,7 +896,7 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 			     }
 			     if (chord->va_ != 0) {
 			     	hline = ac_voice->findBorderLineInVa(chord);
-				s = chord->computeTeXVa(chord->va_ < 0, hline, &vaPool_, &(staff_elem->actualClef_),
+				s = chord->computeTeXVa(hline, &vaPool_, &(staff_elem->actualClef_),
 					&(va_descr_[staff_nr]), &nested, &toomany);
 				if (nested) {
 					exerr = new NExportError(MUSIXTEX_ERR_NESTED_VAS, real_staff_nr + 1);
@@ -917,31 +923,31 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 				dysymDescr_[staff_nr].lastDynSym = 0;
 				dysymDescr_[staff_nr].dynEndPos = 0;
 			     } 
-			     if (chord->status2_ & STAT2_PEDAL_ON) {
+			     if (chord->hasProperty( PROP_PEDAL_ON ) ) {
 			     	out_ << "\\PED";
 			     }
-			     if (chord->status2_ & STAT2_PEDAL_OFF) {
+			     if (chord->hasProperty( PROP_PEDAL_OFF ) ) {
 			     	out_ << "\\DEP";
 			     }
 #ifdef AAA
 			     for (note = notelist->first(); note; note = notelist->next()) {
-				if (note->status & STAT_FORCE) continue;
+				if (note->properties & PROP_FORCE) continue;
 				switch (note->needed_acc) {
-					case STAT_NO_ACC:break;
-					case STAT_CROSS: out_ << "\\sh " << staff_elem->actualClef_.line2TexTab_[note->line+LINE_OVERFLOW];
+					case PROP_NO_ACC:break;
+					case PROP_CROSS: out_ << "\\sh " << staff_elem->actualClef_.line2TexTab_[note->line+LINE_OVERFLOW];
 						      break;
-					case STAT_NATUR: out_ << "\\na " << staff_elem->actualClef_.line2TexTab_[note->line+LINE_OVERFLOW];
+					case PROP_NATUR: out_ << "\\na " << staff_elem->actualClef_.line2TexTab_[note->line+LINE_OVERFLOW];
 						      break;
-					case STAT_FLAT:  out_ << "\\fl " << staff_elem->actualClef_.line2TexTab_[note->line+LINE_OVERFLOW];
+					case PROP_FLAT:  out_ << "\\fl " << staff_elem->actualClef_.line2TexTab_[note->line+LINE_OVERFLOW];
 						      break;
-					case STAT_DCROSS:out_ << "\\dsh " << staff_elem->actualClef_.line2TexTab_[note->line+LINE_OVERFLOW];
+					case PROP_DCROSS:out_ << "\\dsh " << staff_elem->actualClef_.line2TexTab_[note->line+LINE_OVERFLOW];
 						      break;
-					case STAT_DFLAT: out_ << "\\dfl " << staff_elem->actualClef_.line2TexTab_[note->line+LINE_OVERFLOW];
+					case PROP_DFLAT: out_ << "\\dfl " << staff_elem->actualClef_.line2TexTab_[note->line+LINE_OVERFLOW];
 						      break;
 				}
 			     }
 			     for (note = notelist->first(); note; note = notelist->next()) {
-				if (!(note->status & STAT_FORCE)) continue;
+				if (!(note->properties & PROP_FORCE)) continue;
 				switch (note->offs) {
 					case  1: out_ << "\\sh " << staff_elem->actualClef_.line2TexTab_[note->line+LINE_OVERFLOW];
 						      break;
@@ -958,7 +964,7 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 #endif
 			     shiftes_notes_.clear(); non_shifted_notes_.clear(); shift_needed = false;
 			     for (note = notelist->first(); note; note = notelist->next()) {
-				if (note->status & STAT_SHIFTED) {
+				if (note->properties & PROP_SHIFTED) {
 					shift_needed = true;
 					shiftes_notes_.append(note);
 				}
@@ -967,15 +973,15 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 				}
 			     }
 			     if (shift_needed) {
-			     	notes_to_be_shifted = (elem->status_ & STAT_STEM_UP) ? &shiftes_notes_ : &non_shifted_notes_;
-			     	notes_not_to_be_shifted = (elem->status_ & STAT_STEM_UP) ? &non_shifted_notes_ : &shiftes_notes_;
+			     	notes_to_be_shifted = (chord->hasProperty( PROP_STEM_UP ) ) ? &shiftes_notes_ : &non_shifted_notes_;
+			     	notes_not_to_be_shifted = (chord->hasProperty( PROP_STEM_UP ) ) ? &non_shifted_notes_ : &shiftes_notes_;
 			     }
 			     else {
 				notes_to_be_shifted = &shiftes_notes_;
 			     	notes_not_to_be_shifted = &non_shifted_notes_;
 			     }
 			     base_note = notes_not_to_be_shifted->first();
-			     if (shift_needed && !(elem->status_ & STAT_STEM_UP)) {
+			     if (shift_needed && !(chord->hasProperty( PROP_STEM_UP ))) {
 				out_ << "\\roff{";
 			     }
 			     if (notes_not_to_be_shifted->count() > 1) {
@@ -983,27 +989,27 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 				for (first = true, note = notes_not_to_be_shifted->first(); note; note = notes_not_to_be_shifted->next()) {
 					if (note == base_note) continue;
 					body_changed = false;
-					if (lastBodyState != (note->status & BODY_MASK)) {
+					if (lastBodyState != (int)(note->properties & BODY_MASK)) {
 						body_changed = true;
-						switch (lastBodyState = (note->status & BODY_MASK)) {
-							case STAT_BODY_CROSS: bodyString = "x"; break;
-							case STAT_BODY_CROSS2: bodyString = "k"; break;
-							case STAT_BODY_CIRCLE_CROSS: bodyString = "ox"; break;
-							case STAT_BODY_RECT: bodyString = "ro"; break;
-							case STAT_BODY_TRIA: bodyString = "tg"; break;
-							default: bodyString = ""; break;
+						switch (lastBodyState = (int)(note->properties & BODY_MASK)) {
+							case PROP_BODY_CROSS:        strcpy( bodyString, "x" ); break;
+							case PROP_BODY_CROSS2:       strcpy( bodyString, "k" ); break;
+							case PROP_BODY_CIRCLE_CROSS: strcpy( bodyString, "ox" ); break;
+							case PROP_BODY_RECT:         strcpy( bodyString, "ro" ); break;
+							case PROP_BODY_TRIA:         strcpy( bodyString, "tg" ); break;
+							default: bodyString[0] = 0; break;
 						}
 					}
 					if (body_changed || first) {
 						if (!first) out_ << '}';
-						switch (elem->getSubType()) {
+						switch (chord->getSubType()) {
 							case DOUBLE_WHOLE_LENGTH: out_ << '\\' << bodyString << "zwq{"; break;
 							case WHOLE_LENGTH       : out_ << '\\' << bodyString << "zw{"; break;
 							case HALF_LENGTH        : out_ << '\\' << bodyString << "zh{"; break;
 							default   : out_ << '\\' << bodyString << "zq{"; break;
 						}
 					}
-					switch(elem->status_ & DOT_MASK) {
+					switch(chord->properties() & DOT_MASK) {
 						case 1: out_ << '.'; break;
 						/*case 2:  don't know what to do ? ; break;*/
 					}
@@ -1013,19 +1019,19 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 				out_ << "}";
 			     }
 			     if (shift_needed) {
-				out_ << ((elem->status_ & STAT_STEM_UP) ? "\\roff{" : "\\loff{"); 
+				out_ << ((chord->hasProperty( PROP_STEM_UP ) ) ? "\\roff{" : "\\loff{"); 
 				lastBodyState = -1;
 				for (first = true, note = notes_to_be_shifted->first() ;note ; note = notes_to_be_shifted->next(), first = false) {
 					body_changed = false;
-					if (lastBodyState != (note->status & BODY_MASK)) {
+					if (lastBodyState != (int)(note->properties & BODY_MASK)) {
 						body_changed = true;
-						switch (lastBodyState = (note->status & BODY_MASK)) {
-							case STAT_BODY_CROSS: bodyString = "x"; break;
-							case STAT_BODY_CROSS2: bodyString = "k"; break;
-							case STAT_BODY_CIRCLE_CROSS: bodyString = "ox"; break;
-							case STAT_BODY_RECT: bodyString = "ro"; break;
-							case STAT_BODY_TRIA: bodyString = "tg"; break;
-							default: bodyString = ""; break;
+						switch (lastBodyState = (int)(note->properties & BODY_MASK)) {
+							case PROP_BODY_CROSS:        strcpy( bodyString, "x" ); break;
+							case PROP_BODY_CROSS2:       strcpy( bodyString, "k" ); break;
+							case PROP_BODY_CIRCLE_CROSS: strcpy( bodyString, "ox" ); break;
+							case PROP_BODY_RECT:         strcpy( bodyString, "ro" ); break;
+							case PROP_BODY_TRIA:         strcpy( bodyString, "tg" ); break;
+							default: bodyString[0] = 0; break;
 						}
 					}
 					if (body_changed || first) {
@@ -1037,7 +1043,7 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 							default   : out_ << '\\' << bodyString << "zq{"; break;
 						}
 					}
-					switch(elem->status_ & DOT_MASK) {
+					switch(chord->properties() & DOT_MASK) {
 						case 1: out_ << '.'; break;
 						/*case 2:  don't know what to do ? ; break;*/
 					}
@@ -1045,18 +1051,18 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 				}
 				out_ << "}}";
 			     }
-			     switch (base_note->status & BODY_MASK) {
-				case STAT_BODY_CROSS: bodyString = "x"; break;
-				case STAT_BODY_CROSS2: bodyString = "k"; break;
-				case STAT_BODY_CIRCLE_CROSS: bodyString = "ox"; break;
-				case STAT_BODY_RECT: bodyString = "ro"; break;
-				case STAT_BODY_TRIA: bodyString = "tg"; break;
-				default: bodyString = ""; break;
+			     switch (base_note->properties & BODY_MASK) {
+				case PROP_BODY_CROSS:        strcpy( bodyString, "x" ); break;
+				case PROP_BODY_CROSS2:       strcpy( bodyString, "k" ); break;
+				case PROP_BODY_CIRCLE_CROSS: strcpy( bodyString, "ox" ); break;
+				case PROP_BODY_RECT:         strcpy( bodyString, "ro" ); break;
+				case PROP_BODY_TRIA:         strcpy( bodyString, "tg" ); break;
+				default: bodyString[0] = 0; break;
 			     }
-			     if (elem->status_ & STAT_BEAMED && ac_voice->beamNr_ >= 0) {
+			     if (chord->hasProperty( PROP_BEAMED ) && ac_voice->beamNr_ >= 0) {
 				musi_length.sprintf("%sqb%d", bodyString, ac_voice->beamNr_);
 			     }
-			     else switch (elem->getSubType()) {
+			     else switch (chord->getSubType()) {
 				case DOUBLE_WHOLE_LENGTH: musi_length = QString("wq"); break;
 				case WHOLE_LENGTH       : musi_length = QString(bodyString) + QString("wh"); break;
 				case HALF_LENGTH        : musi_length = QString(bodyString) + QString("h")+stemdir; break;
@@ -1064,40 +1070,40 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 				case NOTE8_LENGTH       : musi_length = QString(bodyString) + QString("c")+stemdir; break;
 				case NOTE16_LENGTH      : musi_length = QString(bodyString) + QString("cc")+stemdir; break;
 				/* case INTERNAL_MARKER_OF_STROKEN_GRACE: */
-				case NOTE32_LENGTH      : if (elem->status_ & STAT_GRACE) {
+				case NOTE32_LENGTH      : if (chord->hasProperty( PROP_GRACE ) ) {
 						musi_length = QString("grcu"); break;
 					    }
 					    musi_length = QString(bodyString) + QString("ccc")+stemdir; break;
 				case NOTE64_LENGTH      : musi_length = QString(bodyString) + QString("cccc")+stemdir; break;
 					    musi_length = QString(bodyString) + QString("ccccc")+stemdir; break;
 			     }
-			     switch(elem->status_ & DOT_MASK) {
+			     switch(chord->properties() & DOT_MASK) {
 				case 1: out_ << "\\pt " << staff_elem->actualClef_.line2TexTab_[base_note->line + LINE_OVERFLOW]; break;
 				case 2: out_ << "\\ppt " <<  staff_elem->actualClef_.line2TexTab_[base_note->line + LINE_OVERFLOW]; break;
 			     }
-			     if (elem->status_ & STAT_STACC || elem->status_ & STAT_SFORZ ||
-			         elem->status_ & STAT_PORTA || elem->status_ & STAT_STPIZ ||
-				 elem->status_ & STAT_SFZND) {
+			     if (chord->hasProperty( PROP_STACC ) || chord->hasProperty( PROP_SFORZ ) ||
+			         chord->hasProperty( PROP_PORTA ) || chord->hasProperty( PROP_STPIZ ) ||
+				 chord->hasProperty( PROP_SFZND ) ) {
 				out_ << '\\';
-				out_ << ((elem->status_ & STAT_STEM_UP) ? "l" : "u");
-				if (elem->status_ & STAT_STACC) out_ << "pz";
-				if (elem->status_ & STAT_SFORZ) out_ << "sfz";
-				if (elem->status_ & STAT_PORTA) out_ << "st";
-				if (elem->status_ & STAT_STPIZ) out_ << "ppz";
-				if (elem->status_ & STAT_SFZND) out_ << "sf";
+				out_ << ((chord->hasProperty( PROP_STEM_UP )) ? "l" : "u");
+				if (chord->hasProperty( PROP_STACC ) ) out_ << "pz";
+				if (chord->hasProperty( PROP_SFORZ ) ) out_ << "sfz";
+				if (chord->hasProperty( PROP_PORTA ) ) out_ << "st";
+				if (chord->hasProperty( PROP_STPIZ ) ) out_ << "ppz";
+				if (chord->hasProperty( PROP_SFZND ) ) out_ << "sf";
 				out_ << " " << staff_elem->actualClef_.line2TexTab_[base_note->line+LINE_OVERFLOW];
 			     }
 			     
-			     if(elem->status_ & STAT_FERMT) {
-			     	    note2 = (elem->status_ & STAT_STEM_UP) ? notelist->first() :  notelist->last();
-			    	    out_ << "\\fermata" << ((elem->status_ & STAT_STEM_UP) ? "down" : "up")
+			     if(chord->hasProperty( PROP_FERMT ) ) {
+			     	    note2 = (chord->hasProperty( PROP_STEM_UP ) ) ? notelist->first() :  notelist->last();
+			    	    out_ << "\\fermata" << ((chord->hasProperty( PROP_STEM_UP ) ) ? "down" : "up")
 				         << " "
 				         << staff_elem->actualClef_.line2TexTab_[note2->line+LINE_OVERFLOW];
 				    }
 			     
 			     out_ << "\\" << musi_length << ' ';
 			     out_ << staff_elem->actualClef_.line2TexTab_[base_note->line+LINE_OVERFLOW];
-			     if (shift_needed && !(elem->status_ & STAT_STEM_UP)) {
+			     if (shift_needed && !(chord->hasProperty( PROP_STEM_UP ) )) {
 				out_ << '}';
 			     }
 			     for (i = chord->getNumOfTexAccRows() - 1; i >= 0; i--) {
@@ -1107,22 +1113,23 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 				if (i % 2) out_ << "\\hsk";
 			     }
 			     break;
-		case T_REST: writeStaffTexts(real_staff_nr);
-			     if (elem->status_ & STAT_HIDDEN) break;
+		case T_REST: rest = elem->rest();
+			     writeStaffTexts(real_staff_nr);
+			     if (rest->hasProperty( PROP_HIDDEN ) ) break;
 			     if (extraDelimiter) out_ << extraDelimiter;
 			     if (staff_nr == 0 && newTempo_ >= 0) {
 					out_ << "\\Uptext{\\metron{\\nq}{" << newTempo_ << "}}";
 					newTempo_ = -1;
 			     }
-			     if ((diag = elem->getChordChordDiagram()) != 0) {
+			     if ((diag = rest->getChordChordDiagram()) != 0) {
 				writeChordDiagram(diag);
 			     }
-			     s = elem->computeTeXTuplet(&(staff_elem->actualClef_));
+			     s = rest->computeTeXTuplet(&(staff_elem->actualClef_));
 			     if (s) {
 				out_ << *s;
 				delete s;
 			     }
-			     switch(elem->status_ & DOT_MASK) {
+			     switch(rest->properties() & DOT_MASK) {
 				case 1: out_ << "\\pt " <<  staff_elem->actualClef_.line2TexTab_[4 + LINE_OVERFLOW - 2*ac_voice->yRestOffs_]; break;
 				case 2: out_ << "\\ppt " <<  staff_elem->actualClef_.line2TexTab_[4 + LINE_OVERFLOW - 2*ac_voice->yRestOffs_]; break;
 			     }
@@ -1142,13 +1149,13 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 								badMeasures_.append(exerr);
 					    break;
 			     }
-			     if(elem->status_ & STAT_FERMT) {
+			     if(rest->hasProperty( PROP_FERMT ) ) {
 				// LVIFIX does fermataup need a parameter and, if so, what should it be ?
 				// the "k" below is a random choice
 				out_ << "\\fermataup k";
 			     }
 			     if (elem->getSubType() == MULTIREST)
-				out_ << "\\Hpause32\\uptext{\\sk\\meterfont{" << ((NRest *)elem)->getMultiRestLength() << "}}\\sk\\sk\\hsk";
+				out_ << "\\Hpause32\\uptext{\\sk\\meterfont{" << rest->getMultiRestLength() << "}}\\sk\\sk\\hsk";
 			     else 
 			        out_ << "\\" << musi_length;
 			     break;
@@ -1222,10 +1229,10 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 						   }
 						break;
 				case TEMPO_SIGNATURE: 
-						   if (!exportDialog_->texTempo->isChecked()) break;
+						   if (!musixOpts_.tempo) break;
 						   newTempo_ = ((NSign *) elem)->getTempo();
 						break;
-				case VOLUME_SIG: if (!exportDialog_->texVolume->isChecked()) break;
+				case VOLUME_SIG: if (!musixOpts_.volume) break;
 						out_ << "\\zchar{-7}";
 							switch(((NSign *) elem)->getVolType()) {
 								case V_PPPIANO : out_ << "\\ppp"; break;
@@ -1268,7 +1275,7 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 			     ksig = (NKeySig *) elem;
 			     if (ksig->isRegular(&kind, &z)) {
 				if (z != 0 || barNr_ > 1) {
-					pending_key_changes_.append(new pending_context_change_class(real_staff_nr, (kind == STAT_CROSS) ? z : -z));
+					pending_key_changes_.append(new pending_context_change_class(real_staff_nr, (kind == PROP_CROSS) ? z : -z));
 				}
 			     }
 			     break;
@@ -1404,14 +1411,14 @@ QString NMusiXTeX::lyrics2TeX(QString *lyrics) {
 	if (ret.find(reg) != -1) {
 		return QString("");
 	}
-	if (exportDialog_->texOutputEncoding->currentItem() == 0) {
+	if (musixOpts_.outputEncoding == 0) {
 		NResource::germanUmlautsToTeX(&ret);
 	}
 	reg = QRegExp("#");
 	ret.replace (reg, "\\#");
 	reg = QRegExp("_");
 	ret.replace (reg, "\\_");
-	if (exportDialog_->texMLyr->isChecked()) {
+	if (musixOpts_.mLyr) {
 		reg = QRegExp("<");
 		ret.replace (reg, "{");
 		reg = QRegExp(">");
@@ -1421,7 +1428,7 @@ QString NMusiXTeX::lyrics2TeX(QString *lyrics) {
 		reg = QRegExp("[<>]");
 		ret.replace (reg, "");
 	}
-	if (exportDialog_->texOutputEncoding->currentItem() == 0) {
+	if (musixOpts_.outputEncoding == 0) {
 		return ret;
 	}
 	return ret.utf8();
@@ -1444,7 +1451,7 @@ void NMusiXTeX::externalCmd (QString command, QString filename) {
   }
   // change directory to place ".dvi" where ".tex" is
   if ((slashidx = filename.findRev('/')) >= 0) {
-  	if (slashidx < filename.length() - 1) {
+  	if (slashidx < (int)filename.length() - 1) {
 		destDir = filename.left(slashidx + 1);
 		command = "cd " + destDir + ';' + command;
 	}
