@@ -70,7 +70,7 @@
 
 #define PMX_FAC 0.5
 
-void NPmxExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFrm *frmWin, NMainFrameWidget *mainWidget) {
+void NPmxExport::exportStaffs(QString fname, QPtrList<NStaff> *stafflist, exportFrm *frmWin, NMainFrameWidget *mainWidget) {
 	mainWidget_ = mainWidget;
 	staffList_ = stafflist;
 	exportDialog_ = frmWin;
@@ -86,10 +86,11 @@ void NPmxExport::doExport() {
 	NTimeSig *timesig;
 	NKeySig  *keysig;
 	NClef *clef;
-	QList<QString> lyrNames;
+	QPtrList<QString> lyrNames;
 	QString *lyrName;
 	QString lyricslist[NUM_LYRICS];
-	int kind, count;
+	property_type kind;
+	int count;
 	int acr;
 	bool staffsWritten, first;
 	const char *endOfLine;
@@ -125,6 +126,7 @@ void NPmxExport::doExport() {
 	pendingKeySig_ = 0;
 	pendingSpecialEnd_ = 0;
 	drum_problem_written_ = false;
+	exportDialog_->getPMXOptions( pmxOpts_ );
 
 	specialCharList_.clear();
 	badlist_.clear();
@@ -132,12 +134,12 @@ void NPmxExport::doExport() {
 		return;
 	if (NResource::staffSelExport_ == 0) {
 		NResource::staffSelExport_ = new bool[staffList_->count()];
-		for (i = 0; i < staffList_->count(); NResource::staffSelExport_[i++] = true);
+		for (i = 0; i < (int)staffList_->count(); NResource::staffSelExport_[i++] = true);
 		staffsToExport_ = staffList_->count();
 	}
 	else {
 		staffsToExport_ = 0;
-		for (i = 0; i < staffList_->count(); i++) {
+		for (i = 0; i < (int)staffList_->count(); i++) {
 			if (NResource::staffSelExport_[i]) {
 				staffsToExport_++;
 			}
@@ -190,7 +192,7 @@ void NPmxExport::doExport() {
 	out_ << "% PMX output generated by \"NoteEdit\"    %" << endl;
 	out_ << "%                                         %" << endl;
 	out_ << "%-----------------------------------------%" << endl;
-	if (exportDialog_->pmxMLyr->isChecked()) {
+	if (pmxOpts_.mLyr) {
 		out_ << "---" << endl;
 		out_ << "\\input musixtex" << endl;
 		out_ << "\\input pmx" << endl;
@@ -246,21 +248,22 @@ void NPmxExport::doExport() {
 	}
         out_ << timesig->getNumerator() << "      " <<  timesig->getDenominator() << "        " <<
 		timesig->getNumerator() << "      " <<  timesig->getDenominator();
-	if (acr = voice_elem->determineAnacrusis()) {
+	acr = voice_elem->determineAnacrusis();
+	if (acr>0) {
 		out_ << "        " << ((double) acr / (128.0 / (double) timesig->getDenominator())) << "      ";
 	}
 	else {
 		out_ << "        0      ";
 	}
 	if (keysig->isRegular(&kind, &count)) {
-		if (kind == STAT_FLAT) count = -count;
+		if (kind == PROP_FLAT) count = -count;
 		out_ << count << endl;
 	}
 	else {
 		out_ << "0" << endl;
 	}
 	out_ << "% npages,nsyst,musicsize,fracindent" << endl;
-	out_ << "    " << exportDialog_->pmxNum->getValue() << "    " << exportDialog_->pmxSystem->getValue() << "      20       0.07" << endl;
+	out_ << "    " << pmxOpts_.num << "    " << pmxOpts_.system << "      20       0.07" << endl;
 	out_ << "%" << endl;
 
 	for (i = 0; i < mStaffInf_->getMultiStaffCount(); i++) {
@@ -312,7 +315,7 @@ void NPmxExport::doExport() {
 			badlist_.append(bad);
 			out_ << "\\\\input musixdbr.tex\\relax\\" << endl;
 			out_ << "\\\\indivbarrules\\" << endl << "\\\\allbarrules\\sepbarrule";
-			for (i = 0; i < staffList_->count(); i++) {
+			for (i = 0; i < (int)staffList_->count(); i++) {
 				if (mainWidget_->barCont_[i].valid) {
 					for (j = mainWidget_->barCont_[i].beg; j < mainWidget_->barCont_[i].end; j++) {
 						idx = mStaffInf_->multistaffIdxOfStaff(j, &multistaffnr, &numOfStaffsInMultistaff);
@@ -328,8 +331,8 @@ void NPmxExport::doExport() {
 		}
 		out_ << "\\" << endl;
 	}
-	out_ << "w" << exportDialog_->pmxWidth->text() << "m" << endl;
-	out_ << "h" << exportDialog_->pmxHeight->text() << "m" << endl;
+	out_ << "w" << pmxOpts_.width << "m" << endl;
+	out_ << "h" << pmxOpts_.height << "m" << endl;
 	if (!mainWidget_->scTitle_.isEmpty()) {
 		out_ << "Tt" << endl << '{' << mainWidget_->scTitle_ << '}' << endl;
 	}
@@ -346,7 +349,7 @@ void NPmxExport::doExport() {
 		staffsWritten = false;
 		first = true;
 		out_ << endl << "% Measure " << barNr_ << " - " <<
-			  barNr_ + exportDialog_->pmxMeasure->getValue() - 1 << endl;
+			  barNr_ + pmxOpts_.measure - 1 << endl;
 		for (i = staffList_->count(), staff_elem = staffList_->last(); staff_elem; staff_elem = staffList_->prev(), i--) {
 			if (!NResource::staffSelExport_[i-1]) continue;
 			voice_count = staff_elem->voiceCount();
@@ -358,7 +361,7 @@ void NPmxExport::doExport() {
 				lastLength_ = 1000; /* invalidate */
 				lastTone_ = 1000; /* invalidate */
 				if (writeTrack(voice_elem, i, j, 
-					voice_count, exportDialog_->pmxMeasure->getValue(), first, endOfLine, &barpos)) {
+					voice_count, pmxOpts_.measure, first, endOfLine, &barpos)) {
 					staffsWritten = true;
 				}
 			}
@@ -375,7 +378,7 @@ void NPmxExport::doExport() {
 				}
 			}
 		}
-		barNr_ += exportDialog_->pmxMeasure->getValue();
+		barNr_ += pmxOpts_.measure;
 	}
 	while (staffsWritten);
 	out_.close();
@@ -387,8 +390,7 @@ void NPmxExport::doExport() {
 	if (!badlist_.isEmpty()) {
 		QString output;
 		output = i18n
-			("Noteedit has exported the score to PMX but there are some\n"
-			 "problems which will probably prevent successful PMX output.\n");
+			("NoteEdit has exported the score to PMX format but there are some problems which can prevent successful PostScript/PDF output or can change the final score layout.\n");
 		output += i18n("-----------------------------------------------------\n");
 		for (bad = badlist_.first(); bad; bad = badlist_.next()) {
 			switch (bad->kind) {
@@ -480,10 +482,12 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 	NStaff *actual_staff;
 	NChord *chord;
 	NNote *note;
+	NRest *rest;
 	NKeySig *ksig;
 	NClef *clef;
 	badmeasure *bad;
-	int kind, count, i;
+	property_type kind;
+	int count, i = 0;
 	char lastDynSym = 0;
 	int dynEndPos = 0;
 	int lastbarpos = *barpos;
@@ -495,7 +499,7 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 	int hline;
 	QString specialChar;
 	QString *s;
-	int grace_status;
+	property_type grace_status;
 	bool inGraceGroup = false;
 	bool nested, toomany;
 	QString graceString;
@@ -517,7 +521,7 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 	}
 	if (pendingKeySig_ && first) {
 		if (pendingKeySig_->isRegular(&kind, &count)) {
-			if (kind == STAT_CROSS) {
+			if (kind == PROP_CROSS) {
 				specialChar.sprintf("K+0+%d ", count);
 			}
 			else {
@@ -551,17 +555,18 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 		elempos = elem->getXpos();
 		switch (elem->getType()) {
 			case T_CHORD: 
+				     chord = (NChord *) elem;
 				     part = elem->getSubType(); 
-				     if (!(elem->status_ & STAT_GRACE)) {
+				     if (!(chord->hasProperty( PROP_GRACE ) )) {
 					inGraceGroup = false;
-					if (elem->status_ & STAT_TUPLET) {
-						total += elem->getPlaytime() * part / elem->getNumNotes();
+					if (chord->hasProperty( PROP_TUPLET ) ) {
+						total += chord->getPlaytime() * part / chord->getNumNotes();
 					}
 					else {
 						total += part;
 					}
 				     }
-				     switch (elem->status_ & DOT_MASK) {
+				     switch (chord->properties() & DOT_MASK ) {
 					case 1: total += part / 2; break;
 					case 2: total += 3 * part / 4; break;
 				     }
@@ -570,7 +575,6 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 					bad = new badmeasure(PMX_ERR_BAD_NOTE_COUNT, staff_nr, barNr_+numMeasures, total / 3, countof128th_);
 					badlist_.append(bad);
 				     }
-				     chord = (NChord *) elem;
 				     if (va_descr_[staff_nr-1].trill_nr >= 0 && 	
 					chord->getBbox()->right() > va_descr_[staff_nr-1].endpos) {
 					*pmxout_ << "\\Toctfin" << va_descr_[staff_nr-1].trill_nr << "\\ ";
@@ -579,7 +583,7 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 				     }
 				     if (chord->va_ != 0) {
 					hline = voice->findBorderLineInVa(chord);
-					s = chord->computeTeXVa(chord->va_ < 0, hline, &vaPool_, &(actual_staff->actualClef_),
+					s = chord->computeTeXVa(hline, &vaPool_, &(actual_staff->actualClef_),
 						&(va_descr_[staff_nr-1]), &nested, &toomany);
 					if (nested) {
 						bad = new badmeasure(PMX_ERR_NESTED_VAS, staff_nr, barNr_+numMeasures, 3 /* dummy */, 3 /* dummy */);
@@ -594,10 +598,10 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 						delete s;
 					}
 				      }
-				     if (exportDialog_->pmxKeepBeams->isChecked()) {
-					if ((chord->status_ & STAT_BEAMED) && beamstatus == OUTSIDE_BEAM) {
+				     if (pmxOpts_.keepBeams) {
+					if ((chord->hasProperty( PROP_BEAMED ) ) && beamstatus == OUTSIDE_BEAM) {
 						*pmxout_ << '[';
-						if (chord->status_ & STAT_STEM_UP) {
+						if (chord->hasProperty( PROP_STEM_UP ) ) {
 							beamstatus = IN_BEAM_UP;
 							*pmxout_ << "u ";
 						}
@@ -607,7 +611,7 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 						}
 				        }
 				     } 
-				     if (!exportDialog_->pmxMLyr->isChecked()) {
+				     if (!pmxOpts_.mLyr) {
 					countLyricsLines = chord->countOfLyricsLines();
 					for (i = countLyricsLines-1; i >= 0; i--) {
 						lyrics = chord->getLyrics(i);
@@ -619,7 +623,7 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 				     		}
 					}
 				     }
-				     if (!inGraceGroup && elem->status_ & STAT_GRACE) {
+				     if (!inGraceGroup && chord->hasProperty( PROP_GRACE ) ) {
 					graceString =  voice->determineGraceKind(&grace_status);
 					inGraceGroup = true;
 					if (grace_status == WARN_MIXED_GRACES) {
@@ -633,42 +637,42 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 				        *pmxout_ << graceString;
 				     }
 				     if (beamstatus == IN_BEAM_UP) {
-				     	note = elem->getNoteList()->last();
+				     	note = chord->getNoteList()->last();
 				     }
 				     else {
-				     	note = elem->getNoteList()->first();
+				     	note = chord->getNoteList()->first();
 				     }
-				     pitchOut(&(actual_staff->actualKeysig_), note, elem->getSubType(), &(actual_staff->actualClef_), (NChord *) elem, staff_nr, barNr_+numMeasures);
-				     if (!drum_problem_written_ && (note->status & BODY_MASK)) {
+				     pitchOut(&(actual_staff->actualKeysig_), note, elem->getSubType(), &(actual_staff->actualClef_), chord, staff_nr, barNr_+numMeasures);
+				     if (!drum_problem_written_ && (note->properties & BODY_MASK)) {
 					drum_problem_written_ = true;
 					bad = new badmeasure(PMX_ERR_DRUM_STAFF, staff_nr, barNr_+numMeasures, total / 3, countof128th_);
 					badlist_.append(bad);
 				     }
-				     switch (elem->status_ & DOT_MASK) {
+				     switch (chord->properties() & DOT_MASK ) {
 					case 1: *pmxout_ << "d"; break;
 					case 2: *pmxout_ << "dd"; break;
 				     }
-				     if ((elem->status_ & STAT_TUPLET) && elem->getSubType() != tupletBase_)  *pmxout_ << 'D';
+				     if ((chord->hasProperty( PROP_TUPLET ) ) && elem->getSubType() != tupletBase_)  *pmxout_ << 'D';
 #ifdef THIS_IS_WRONG
-				     base_shifted = note->status & STAT_SHIFTED;
+				     base_shifted = note->properties & PROP_SHIFTED;
 #endif
 				     *pmxout_ << ' ';
-				     if (elem->status_ & STAT_STACC) {
+				     if (chord->hasProperty( PROP_STACC ) ) {
 					*pmxout_ << "ou ";
 				     }
-				     if (elem->status_ & STAT_SFORZ) {
+				     if (chord->hasProperty( PROP_SFORZ ) ) {
 					*pmxout_ << "o^ ";
 				     }
-				     if (elem->status_ & STAT_PORTA) {
+				     if (chord->hasProperty( PROP_PORTA ) ) {
 					*pmxout_ << "o_ ";
 				     }
-				     if (elem->status_ & STAT_SFZND) {
+				     if (chord->hasProperty( PROP_SFZND ) ) {
 					*pmxout_ << "o> ";
 				     }
-				     if (elem->status_ & STAT_FERMT) {
+				     if (chord->hasProperty( PROP_FERMT ) ) {
 				        *pmxout_ << "of ";
 				     }
-				     if (elem->status_ & STAT_ARPEGG) {
+				     if (chord->hasProperty( PROP_ARPEGG ) ) {
 				        *pmxout_ << "? ";
 				     }
 				     if (chord->trill_ < 0) {
@@ -688,43 +692,43 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 					dynEndPos = 0;
 				     }
 				     setTie(note, staff_nr, barNr_+numMeasures);
-				     setSlur((NChord *) elem, staff_nr, barNr_+numMeasures);
+				     setSlur(chord, staff_nr, barNr_+numMeasures);
 	
 			             if (beamstatus == IN_BEAM_UP) {
-					note = elem->getNoteList()->prev();
+					note = chord->getNoteList()->prev();
 				     }
 				     else {
-					note = elem->getNoteList()->next();
+					note = chord->getNoteList()->next();
 				      }		
 			  	     while (note) {
 					     *pmxout_ << "z";
-					     pitchOut(&(actual_staff->actualKeysig_), note, -1, &(actual_staff->actualClef_), (NChord *) elem, staff_nr, barNr_+numMeasures);
-					     if (!drum_problem_written_ && (note->status & BODY_MASK)) {
+					     pitchOut(&(actual_staff->actualKeysig_), note, -1, &(actual_staff->actualClef_), chord, staff_nr, barNr_+numMeasures);
+					     if (!drum_problem_written_ && (note->properties & BODY_MASK)) {
 						drum_problem_written_ = true;
 						bad = new badmeasure(PMX_ERR_DRUM_STAFF, staff_nr, barNr_+numMeasures, total / 3, countof128th_);
 						badlist_.append(bad);
 					     }
 #ifdef THIS_IS_WRONG
 					     if (base_shifted) {
-						if (!(note->status & STAT_SHIFTED)) *pmxout_ << "r";
+						if (!(note->properties & PROP_SHIFTED)) *pmxout_ << "r";
 					     }
 					     else {
-				     	     	if (note->status & STAT_SHIFTED) *pmxout_ << "r";
+				     	     	if (note->properties & PROP_SHIFTED) *pmxout_ << "r";
 					     }
 #endif
 				     	     *pmxout_ << ' ';
 					     setTie(note, staff_nr, barNr_+numMeasures);
 			             	     if (beamstatus == IN_BEAM_UP) {
-						note = elem->getNoteList()->prev();
+						note = chord->getNoteList()->prev();
 				     	     }
 				     	     else {
-						note = elem->getNoteList()->next();
+						note = chord->getNoteList()->next();
 				      	     }		
 				     }
-				     if (elem->status_ & STAT_ARPEGG) {
+				     if (chord->hasProperty( PROP_ARPEGG ) ) {
 				     		*pmxout_ << "? ";
 				     }
-				     if (exportDialog_->pmxKeepBeams->isChecked()) {
+				     if (pmxOpts_.keepBeams) {
 					if (beamstatus != OUTSIDE_BEAM && chord->lastBeamed()) {
 						beamstatus = OUTSIDE_BEAM;
 						*pmxout_ << " ] ";
@@ -732,20 +736,21 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 				     } 
 				     break;
 			case T_REST:
+				     rest = elem->rest();
 				     inGraceGroup = false;
 				     part = elem->getSubType(); 
 				     if (part == MULTIREST) {
 						total += MULTIPLICATOR*countof128th_;
 				     }
 				     else {
-					     if (elem->status_ & STAT_TUPLET) {
-						total += elem->getPlaytime() * part / elem->getNumNotes();
+					     if (rest->hasProperty( PROP_TUPLET ) ) {
+						total += rest->getPlaytime() * part / rest->getNumNotes();
 					     }
 					     else {
 						total += part;
 					     }
 				     }
-				     switch (elem->status_ & DOT_MASK) {
+				     switch (rest->properties() & DOT_MASK ) {
 					case 1: total += part / 2; break;
 					case 2: total += 3 * part / 4; break;
 				     }
@@ -756,12 +761,12 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 				     }
 					
 				     *pmxout_ << 'r';
-				     if (elem->status_ & STAT_HIDDEN) *pmxout_ << 'b';
-				     if (elem->status_ & STAT_TUPLET) {
-					if (elem->isFirstInTuplet()) {
-						inspectTuplet(elem, staff_nr, barNr_+numMeasures);
-						*pmxout_  << computePMXTupletLength(elem->getPlaytime()*tupletBase_, staff_nr, barNr_+numMeasures);
-						lastLength_ = elem->getPlaytime()*tupletBase_;
+				     if (rest->hasProperty( PROP_HIDDEN ) ) *pmxout_ << 'b';
+				     if (rest->hasProperty( PROP_TUPLET ) ) {
+					if (rest->isFirstInTuplet()) {
+						inspectTuplet(rest, staff_nr, barNr_+numMeasures);
+						*pmxout_  << computePMXTupletLength(rest->getPlaytime()*tupletBase_, staff_nr, barNr_+numMeasures);
+						lastLength_ = rest->getPlaytime()*tupletBase_;
 					}
 				     }
 				     else if (part == MULTIREST) {
@@ -770,18 +775,18 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 						badlist_.append(bad);
 					}
 					lastLength_ = 1111; /* invalidate */
-					*pmxout_ << 'm' << ((NRest *) elem)->getMultiRestLength();
+					*pmxout_ << 'm' << rest->getMultiRestLength();
 				     }
 				     else if (lastLength_ != elem->getSubType()) {
 				     	*pmxout_ << computePMXLength(elem->getSubType());
 					lastLength_ = elem->getSubType();
 				     }
-				     switch (elem->status_ & DOT_MASK) {
+				     switch (rest->properties() & DOT_MASK) {
 					case 1: *pmxout_ << "d"; break;
 					case 2: *pmxout_ << "dd"; break;
 				     }
-				     if (elem->status_ & STAT_TUPLET) {
-						if (elem->isFirstInTuplet()) *pmxout_ << "x" << (int) (elem->getNumNotes());
+				     if (rest->hasProperty( PROP_TUPLET ) ) {
+						if (rest->isFirstInTuplet()) *pmxout_ << "x" << (int) (rest->getNumNotes());
 						if (elem->getSubType() != tupletBase_) *pmxout_ << 'D';
 				     }
 				     *pmxout_ << ' ';
@@ -901,7 +906,7 @@ bool NPmxExport::writeTrack(NVoice *voice,  int staff_nr, int voice_nr, int voic
 				if (barNr_ < 2) break;
 				ksig = (NKeySig *) elem;
 				if (ksig->isRegular(&kind, &count)) {
-					if (kind == STAT_CROSS) {
+					if (kind == PROP_CROSS) {
 						specialChar.sprintf("K+0+%d ", count);
 					}
 					else {
@@ -971,9 +976,9 @@ void NPmxExport::pitchOut(NKeySig *ksig, const NNote *note, int length, NClef *a
 	bool firstTuplet = false;
 
 	*pmxout_ << ac_clef->line2PMXName(note->line, &octave);
-	tone = ac_clef->line2midiTab_[note->line+LINE_OVERFLOW];
+	tone = ac_clef->line2Midi( note->line, 0 );
 	octaveneeded = abs(lastTone_ - tone) > 5;
-	if (chord->status_ & STAT_TUPLET) {
+	if (chord->hasProperty( PROP_TUPLET ) ) {
 		if (chord->isFirstInTuplet() &&  length >= 0) {
 			inspectTuplet(chord, staff_nr, barnr);
 			firstTuplet = true;
@@ -981,27 +986,27 @@ void NPmxExport::pitchOut(NKeySig *ksig, const NNote *note, int length, NClef *a
 			lastLength_ = chord->getPlaytime()*tupletBase_;
 		}
 	}
-	else if (!(chord->status_ & STAT_GRACE) && length >= 0 && (lastLength_ != length || octaveneeded)) {
+	else if (!(chord->hasProperty( PROP_GRACE ) ) && length >= 0 && (lastLength_ != length || octaveneeded)) {
 		*pmxout_  << computePMXLength(length);
 		lastLength_ = length;
 	}
-	if (!(note->status & STAT_PART_OF_TIE)) {
-		if (!(note->status & STAT_FORCE)) {
+	if (!(note->properties & PROP_PART_OF_TIE)) {
+		if (!(note->properties & PROP_FORCE)) {
 			switch (note->needed_acc) {
-				case STAT_CROSS: *pmxout_ << "s"; ksig->setTempAcc(note->line, STAT_CROSS); break;
-				case STAT_FLAT: *pmxout_ << "f"; ksig->setTempAcc(note->line, STAT_FLAT); break;
-				case STAT_NATUR: *pmxout_ << "n"; ksig->setTempAcc(note->line, STAT_NATUR); break;
-				case STAT_DCROSS: *pmxout_ << "ss"; ksig->setTempAcc(note->line, STAT_DCROSS); break;
-				case STAT_DFLAT: *pmxout_ << "ff"; ksig->setTempAcc(note->line, STAT_DFLAT); break;
+				case PROP_CROSS: *pmxout_ << "s"; ksig->setTempAccent(note->line, PROP_CROSS); break;
+				case PROP_FLAT: *pmxout_ << "f"; ksig->setTempAccent(note->line, PROP_FLAT); break;
+				case PROP_NATUR: *pmxout_ << "n"; ksig->setTempAccent(note->line, PROP_NATUR); break;
+				case PROP_DCROSS: *pmxout_ << "ss"; ksig->setTempAccent(note->line, PROP_DCROSS); break;
+				case PROP_DFLAT: *pmxout_ << "ff"; ksig->setTempAccent(note->line, PROP_DFLAT); break;
 			}
 		}
 		else {
 			switch (note->offs) {
-				case  1: *pmxout_ << "s"; ksig->setTempAcc(note->line, STAT_CROSS); break;
-				case -1: *pmxout_ << "f"; ksig->setTempAcc(note->line, STAT_FLAT); break;
-				case  0: *pmxout_ << "n"; ksig->setTempAcc(note->line, STAT_NATUR); break;
-				case  2: *pmxout_ << "ss"; ksig->setTempAcc(note->line, STAT_DCROSS); break;
-				case -2: *pmxout_ << "ff"; ksig->setTempAcc(note->line, STAT_DFLAT); break;
+				case  1: *pmxout_ << "s"; ksig->setTempAccent(note->line, PROP_CROSS); break;
+				case -1: *pmxout_ << "f"; ksig->setTempAccent(note->line, PROP_FLAT); break;
+				case  0: *pmxout_ << "n"; ksig->setTempAccent(note->line, PROP_NATUR); break;
+				case  2: *pmxout_ << "ss"; ksig->setTempAccent(note->line, PROP_DCROSS); break;
+				case -2: *pmxout_ << "ff"; ksig->setTempAccent(note->line, PROP_DFLAT); break;
 			}
 		}
 	}
@@ -1089,7 +1094,7 @@ void NPmxExport::setTie(NNote *note, int staff_nr, int barnr) {
 	int i;
 	bool found = false;
 
-	if ((note->status & STAT_TIED) && !(note->status & STAT_PART_OF_TIE)) { 
+	if ((note->properties & PROP_TIED) && !(note->properties & PROP_PART_OF_TIE)) { 
 		for (i = 0; i < MAXTIES && !found; i++) {
 			found = !((1 << i) & tiePool_);
 		}
@@ -1107,13 +1112,13 @@ void NPmxExport::setTie(NNote *note, int staff_nr, int barnr) {
 			tieMember->TeXTieNr = i;
 		}
 	}
-	else if ((note->status & STAT_PART_OF_TIE) && (note->status & STAT_TIED)) {
+	else if ((note->properties & PROP_PART_OF_TIE) && (note->properties & PROP_TIED)) {
 		if (note->TeXTieNr >= 0) {
 			*pmxout_ << "s" << note->TeXTieNr << ' ';
 			*pmxout_ << "s" << note->TeXTieNr << ' ';
 		}
 	}
-	else if ((note->status & STAT_PART_OF_TIE) && !(note->status & STAT_TIED)) {
+	else if ((note->properties & PROP_PART_OF_TIE) && !(note->properties & PROP_TIED)) {
 		if (note->TeXTieNr >= 0) {
 			*pmxout_ << "s" << note->TeXTieNr << ' ';
 			tiePool_ = tiePool_ & (~(1 << note->TeXTieNr));
@@ -1126,13 +1131,13 @@ void NPmxExport::setSlur(NChord *chord, int staff_nr, int barnr) {
 	int i;
 	bool found = false;
 
-	if (chord->status_ & STAT_GRACE) {
-		if ((chord->status_ & STAT_SLURED)) {
+	if (chord->hasProperty( PROP_GRACE ) ) {
+		if ((chord->hasProperty( PROP_SLURED ) )) {
 			chord->setPartnerSlurNr(-1);
 		}
 		return;
 	}
-	if ((chord->status_ & STAT_SLURED) && !(chord->status_ & STAT_PART_OF_SLUR)) { 
+	if ((chord->hasProperty( PROP_SLURED ) ) && !(chord->hasProperty( PROP_PART_OF_SLUR ) )) { 
 		for (i = 0; i < MAXSLURS && !found; i++) {
 			found = !((1 << i) & slurPool_);
 		}
@@ -1149,14 +1154,14 @@ void NPmxExport::setSlur(NChord *chord, int staff_nr, int barnr) {
 		chord->setTeXSlurNr(i);
 		chord->setPartnerSlurNr(i);
 	}
-	else if ((chord->status_ & STAT_PART_OF_SLUR) && (chord->status_ & STAT_SLURED)) {
+	else if ((chord->hasProperty( PROP_PART_OF_SLUR ) ) && (chord->hasProperty( PROP_SLURED ) )) {
 		if (chord->getTeXSlurNr() >= 0) {
 			*pmxout_ << "s" << chord->getTeXSlurNr() << ' ';
 			*pmxout_ << "s" << chord->getTeXSlurNr() << ' ';
 			chord->setPartnerSlurNr(chord->getTeXSlurNr());
 		}
 	}
-	else if ((chord->status_ & STAT_PART_OF_SLUR) && ! (chord->status_ & STAT_SLURED)) {
+	else if ((chord->hasProperty( PROP_PART_OF_SLUR)) && ! (chord->hasProperty( PROP_SLURED ))) {
 		if (chord->getTeXSlurNr() >= 0) {
 			*pmxout_ << "s" << chord->getTeXSlurNr() << ' ';
 			slurPool_ = slurPool_ & (~(1 << chord->getTeXSlurNr()));
@@ -1260,16 +1265,16 @@ bool NPmxExport::testContextChange(int voice_nr, NVoice *voice, bool first) {
 	return false;
 }
 		
-void NPmxExport::inspectTuplet(NMusElement *elem, int staff_nr, int barnr_) {
-	QList<NMusElement> *tupletlist;
+void NPmxExport::inspectTuplet(NPlayable *elem, int staff_nr, int barnr_) {
+	QPtrList<NPlayable> *tupletlist;
 	badmeasure *bad;
 	int len1, len2;
-	NMusElement *elem2;
+	NPlayable *elem2;
 	bool len2set = false;
 
 	tupletlist = elem->getTupletList();
 
-	if (tupletlist->count() != elem->getNumNotes()) {
+	if ((int)(tupletlist->count()) != elem->getNumNotes()) {
 		elem2 = tupletlist->first();
 		len1 = len2 = elem2->getSubType();
 		for (elem2 = tupletlist->next(); elem2; elem2 = tupletlist->next()) {
@@ -1324,7 +1329,7 @@ QString NPmxExport::lyrics2TeX(QString *lyrics) {
 	NResource::germanUmlautsToTeX(&ret);
 	reg = QRegExp("_");
 	ret.replace (reg, "\\_");
-	if (exportDialog_->pmxMLyr->isChecked()) {
+	if (pmxOpts_.mLyr) {
 		reg = QRegExp("<");
 		ret.replace (reg, "{");
 		reg = QRegExp(">");
