@@ -20,7 +20,9 @@
 /*											*/
 /****************************************************************************************/
 
+#ifndef WITH_SCONS
 #include "config.h"
+#endif
 #if GCC_MAJ_VERS > 2
 #include <iostream>
 #else
@@ -69,26 +71,26 @@ using namespace std;
 
 #define BEAM_LINE_WIDTH 2
 
-char *NResource::volume[] =
+const char *NResource::volume[] =
 {I18N_NOOP("ppp"), I18N_NOOP("pp"), I18N_NOOP("p"),  I18N_NOOP("mp"),
  I18N_NOOP("mf"),  I18N_NOOP("f"),  I18N_NOOP("ff"), I18N_NOOP("fff")
 };
 
-char *NResource::noteVal[] =
+const char *NResource::noteVal[] =
 {I18N_NOOP("full"),         I18N_NOOP("dotted half"), I18N_NOOP("half"),
  I18N_NOOP("dotted quarter"), I18N_NOOP("quarter"),   I18N_NOOP("dotted 8th"),
  I18N_NOOP("8th"),          I18N_NOOP("dotted 16th"), I18N_NOOP("16th"),
  I18N_NOOP("dotted 32th"),  I18N_NOOP("32th"),        I18N_NOOP("64th")
 };
 
-char *NResource::tripletVal[] =
+const char *NResource::tripletVal[] =
 {I18N_NOOP("half"),
  I18N_NOOP("quarter"),
  I18N_NOOP("8th"),
  I18N_NOOP("16th")
 };
 
-char *NResource::instrTab[128] =
+const char *NResource::instrTab[128] =
 {I18N_NOOP("Piano 1"),          I18N_NOOP("Piano 2"),
  I18N_NOOP("Piano 3"),          I18N_NOOP("Honky-tonk"),
  I18N_NOOP("E.Piano 1"),        I18N_NOOP("E.Piano 2"),
@@ -165,6 +167,7 @@ QBrush NResource::redBrush_;
 QBrush NResource::contextBrush_;
 QPen NResource::noPen_;
 QPen NResource::staffPen_;
+QPen NResource::editModeBorderPen_;
 QPen NResource::selectedStaffPen_;
 QPen NResource::barPen_;
 QPen NResource::selectedBarPen_;
@@ -450,6 +453,19 @@ unsigned int NResource::turnOverPoint_;
 //  Startup
 bool NResource::startupLoadLastScore_;
 
+#ifdef WITH_DIRECT_PRINTING
+
+int NResource::typesettingProgram_;
+int NResource::typesettingProgramFormat_;
+char NResource::typesettingProgramInvokation_[MAX_PROGRAM_LENGTH];
+char NResource::typesettingOptions_[MAX_OPTIONS_LENGTH];
+
+//  Preview program
+int NResource::previewProgram_;
+char NResource::previewProgramInvokation_[MAX_PROGRAM_LENGTH];
+char NResource::previewOptions_[MAX_OPTIONS_LENGTH];
+
+#endif
 
 bool NResource::showStaffNrs_ = true;
 bool NResource::showStaffNames_ = true;
@@ -469,7 +485,7 @@ int  NResource::overlength_ = DEFAULT_OVERLENGTH;
 int  NResource::schedulerRequest_ = ALL_SCHEDULERS;
 int  NResource::defZoomval_ = PREFERRED_ZOOM_VAL;
 staff_props_str NResource::nullprops_;
-QList<NMainWindow> NResource::windowList_;
+QPtrList<NMainWindow> NResource::windowList_;
 NMidiMapper *NResource::mapper_;
 int NResource::lastWindowX_ = 0;
 int NResource::lastWindowY_ = 0;
@@ -488,7 +504,7 @@ int NResource::globalFlatPlus_ = 0;
 QString NResource::lyrics_[5];
 #if KDE_VERSION < 220
 int NResource::tipNo_;
-QList<QString> NResource::theTips_;
+QPtrList<QString> NResource::theTips_;
 #endif
 bool NResource::dontShowMupWarnings_ = false;
 bool *NResource::staffSelMute_ = 0;
@@ -612,7 +628,6 @@ void NResource::abort( QString s, signed char no ) {
 }
 
 NResource::NResource() {
-	char e[128];
 	NResource::nresourceobj_ = this;
 	kapp->config()->setGroup("Autosave");
 	autosaveEnable_ = kapp->config()->readBoolEntry("Enable", AUTOSAVE_ENABLE);
@@ -639,6 +654,32 @@ NResource::NResource() {
 	startupLoadLastScore_ = kapp->config()->readBoolEntry
 		("LoadLastScore", STARTUP_LOAD_LAST_SCORE);
 
+#ifdef WITH_DIRECT_PRINTING
+
+	//  PRINTING
+
+	//  Typesetting program
+	kapp->config()->setGroup("Printing");
+	typesettingProgram_ = kapp->config()->readNumEntry(
+                ("Typesetting program"), PRINTING_TYPESETTING_PROGRAM);
+	typesettingProgramFormat_ = kapp->config()->readNumEntry(
+                ("Format"), PRINTING_TYPESETTING_PROGRAM_FORMAT );
+	strcpy( typesettingProgramInvokation_, kapp->config()->readEntry(
+                ("Invokation"), PRINTING_TYPESETTING_PROGRAM_INVOKATION ).ascii() );
+	strcpy( typesettingOptions_, kapp->config()->readEntry(
+                ("Options"), PRINTING_DEFAULT_OPTIONS ).ascii() );
+
+	//  Preview program
+	kapp->config()->setGroup("Print preview");
+	previewProgram_ = kapp->config()->readNumEntry(
+                ("Preview program"), PRINTING_PREVIEW_PROGRAM );
+	strcpy(previewProgramInvokation_, kapp->config()->readEntry(
+                ("Invokation"), PRINTING_PREVIEW_PROGRAM_INVOKATION ).ascii() );
+	strcpy( previewOptions_, kapp->config()->readEntry(
+                ("Options"), PRINTING_DEFAULT_OPTIONS ).ascii() );
+
+#endif
+
 	kapp->config()->setGroup("Colors");
 	backgroundBrush_ =	QBrush
 		(kapp->config()->readColorEntry("Background", &COLORS_BACKGROUND));
@@ -653,6 +694,7 @@ NResource::NResource() {
 		);
 	staffPen_ = QPen
 		(kapp->config()->readColorEntry("Staff", &COLORS_STAFF));
+	editModeBorderPen_ = QPen(Qt::red, 2);
 	selectedStaffPen_ = QPen
 		(kapp->config()->readColorEntry("SelectedStaff", &COLORS_SELECTED_STAFF));
 	barPen_ = QPen
@@ -701,7 +743,7 @@ NResource::NResource() {
 		);
 	lyricPen_ = QPen
 		(kapp->config()->readColorEntry(QString("Lyric"), &COLORS_LYRIC));
-
+	
 	//  Others:
 	blackBrush_ = QBrush(Qt::black);
 	redBrush_   = QBrush(Qt::red);
@@ -953,6 +995,7 @@ NResource::NResource() {
 	// check current LilyPond version to decide about the export format.
 	lilytest lt;
 	lt.check();
+
 }
 
 void NResource::setAutosave(bool enable, int intervall) {
@@ -986,6 +1029,24 @@ NResource::~NResource() {
 	kapp->config()->setGroup("Startup");
 	kapp->config()->writeEntry(QString("LoadLastScore"), startupLoadLastScore_);
 
+#ifdef WITH_DIRECT_PRINTING
+
+	//  PRINTING
+
+	//  Typesetting program
+	kapp->config()->setGroup("Printing");
+	kapp->config()->writeEntry(QString("Typesetting program"), typesettingProgram_);
+	kapp->config()->writeEntry(QString("Format"),  typesettingProgramFormat_);
+	kapp->config()->writeEntry(QString("Invokation"), typesettingProgramInvokation_);
+	kapp->config()->writeEntry(QString("Options"), typesettingOptions_ );
+
+	//  Preview program
+	kapp->config()->setGroup("Print preview");
+	kapp->config()->writeEntry(QString("Preview program"), previewProgram_);
+	kapp->config()->writeEntry(QString("Invokation"), previewProgramInvokation_);
+	kapp->config()->writeEntry(QString("Options"), previewOptions_ );
+
+#endif
 
 	//  COLORS
 
@@ -1104,7 +1165,7 @@ void NResource::autosave() {
 	}
 }
 
-QCursor *NResource::loadCursor(char *fname) {
+QCursor *NResource::loadCursor(const char *fname) {
 	QBitmap shape;
 	QCursor *cursor;
 	QString s;
@@ -1257,15 +1318,15 @@ void NResource::loadTips(QString fname) {
 int NResource::noteLength2Button_(int length) {
 	int res = -1;
 	switch (length) {
-		case NOTE128_LENGTH      : res = 9; break;
-		case NOTE64_LENGTH       : res = 8; break;
-		case NOTE32_LENGTH       : res = 7; break;
-		case NOTE16_LENGTH       : res = 6; break;
-		case NOTE8_LENGTH        : res = 5; break;
-		case QUARTER_LENGTH      : res = 4; break;
-		case HALF_LENGTH         : res = 3; break;
-		case WHOLE_LENGTH        : res = 2; break;
-		case DOUBLE_WHOLE_LENGTH : res = 1; break;
+		case NOTE128_LENGTH      : res = 8; break;
+		case NOTE64_LENGTH       : res = 7; break;
+		case NOTE32_LENGTH       : res = 6; break;
+		case NOTE16_LENGTH       : res = 5; break;
+		case NOTE8_LENGTH        : res = 4; break;
+		case QUARTER_LENGTH      : res = 3; break;
+		case HALF_LENGTH         : res = 2; break;
+		case WHOLE_LENGTH        : res = 1; break;
+		case DOUBLE_WHOLE_LENGTH : res = 0; break;
 	}
 	return res;
 }
@@ -1288,16 +1349,20 @@ QCursor * NResource::determineCursor(int length) {
 int NResource::button2Notelength_(int buNr) {
 	int res = -1;
 	switch (buNr) {
-		case 9: res = NOTE128_LENGTH     ; break;
-		case 8: res = NOTE64_LENGTH      ; break;
-		case 7: res = NOTE32_LENGTH      ; break;
-		case 6: res = NOTE16_LENGTH      ; break;
-		case 5: res = NOTE8_LENGTH       ; break;
-		case 4: res = QUARTER_LENGTH     ; break;
-		case 3: res = HALF_LENGTH        ; break;
-		case 2: res = WHOLE_LENGTH       ; break;
-		case 1: res = DOUBLE_WHOLE_LENGTH; break;
+		case 0: res = DOUBLE_WHOLE_LENGTH; break;
+		case 1: res = WHOLE_LENGTH       ; break;
+		case 2: res = HALF_LENGTH        ; break;
+		case 3: res = QUARTER_LENGTH     ; break;
+		case 4: res = NOTE8_LENGTH       ; break;
+		case 5: res = NOTE16_LENGTH      ; break;
+		case 6: res = NOTE32_LENGTH      ; break;
+		case 7: res = NOTE64_LENGTH      ; break;
+		case 8: res = NOTE128_LENGTH     ; break;
+		case 9: res = NOTE8_LENGTH       ; break;
+		case 10: res = NOTE16_LENGTH     ; break;
+		case 11: res = INTERNAL_MARKER_OF_STROKEN_GRACE; break;
 	}
+
 	return res;
 }
 
