@@ -28,7 +28,7 @@
 #include <ktoolbar.h>
 
 #include <qcolor.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 #include <qregexp.h>
 
@@ -41,28 +41,29 @@
 #define DEFAULT_UNDERLENGTH DEFAULT_OVERLENGTH
 #define DEFAULT_LYRICSDIST 60
 
-/* brace in layout */
+/* braces layout */
 
 #define LAYOUT_BRACE_X_POS 4
-#define LAYOUT_BRACE_WIDTH 8 
+#define LAYOUT_BRACE_WIDTH 10 
 #define LAYOUT_BR_ARROW_XRAD 20
-#define LAYOUT_BR_ARROW_YRAD 20
+#define LAYOUT_BR_ARROW_YRAD 30
 #define LAYOUT_BRACEX_ARROW 20
-#define LAYOUT_BRACE_ARC_LENGTH 90
+#define LAYOUT_BRACE_ARC_LENGTH 100
 #define LAYOUT_MID_ROUNDDIST 16 
 #define LAYOUT_BRACEX_TOTAL (LAYOUT_BRACE_X_POS+LAYOUT_BRACE_WIDTH+LAYOUT_BRACEX_ARROW+LAYOUT_BR_ARROW_XRAD)
 
-/* bracket in layout: */
+/* brackets layout */
 
-#define BRACE_BRACKET_DIST 6
+#define BRACE_BRACKET_DIST 2
 #define DEFAULT_LAYOUT_BRACKET_X_POS 20
 #define LAYOUT_BRACKET_X_OVERLAP 10
-#define LAYOUT_BRACKET_WIDTH1 8
-#define LAYOUT_BRACKET_WIDTH2 6
+#define LAYOUT_BRACKET_WIDTH1 10
+#define LAYOUT_BRACKET_WIDTH2 4
 #define LAYOUT_BRACKET_XRAD 60
 #define LAYOUT_BRACKET_YRAD 100
 #define LAYOUT_BRACKET_ARC_LENGTH 25
-#define LAYOUT_BRACKET_X_TOTAL (DEFAULT_LAYOUT_BRACKET_X_POS+LAYOUT_BRACKET_WIDTH1+13 /* LAYOUT_BRACKET_XRAD/2*sin(LAYOUT_BRACKET_ARC_LENGTH*16)*PI/180.0 */)
+#define LAYOUT_BRACKET_X_TOTAL (DEFAULT_LAYOUT_BRACKET_X_POS+LAYOUT_BRACKET_WIDTH1+13)
+/* LAYOUT_BRACKET_XRAD/2*sin(LAYOUT_BRACKET_ARC_LENGTH*16)*PI/180.0 or ~13 */
 
 
 
@@ -103,6 +104,22 @@
 #define LYRICS_LINE_LENGTH 1024
 #define LENGTH_OF_BAR_CHECK_ARRAY 20
 
+/* printing */
+
+#define MAX_PROGRAM_LENGTH 50
+#define MAX_OPTIONS_LENGTH 200
+
+typedef enum
+{
+  EXP_ABC = 0,
+  EXP_PMX,
+  EXP_Lilypond,
+  EXP_MusiXTeX,
+  EXP_Midi,
+  EXP_MusicXML,
+  EXP_NoteEdit
+} exportFormat_T;
+
 class staff_props_str;
 class NMainWindow;
 class NMidiMapper;
@@ -131,6 +148,8 @@ struct lily_properties {
 	bool lilySluresInGraces;
 	bool lilyVersion2;
 	bool lilyVersion24;
+	bool lilyVersion26;
+	bool lilyVersion28;
 	bool lilyProperties;
 };
 
@@ -152,6 +171,7 @@ class NResource : public QObject  {
 		static QBrush contextBrush_;
 		static QPen noPen_;
 		static QPen staffPen_;
+		static QPen editModeBorderPen_;
 		static QPen selectedStaffPen_;
 		static QPen barPen_;
 		static QPen selectedBarPen_;
@@ -444,6 +464,22 @@ class NResource : public QObject  {
 		//  Startup
 		static bool startupLoadLastScore_;
 
+#ifdef WITH_DIRECT_PRINTING
+
+		//  PRINTING
+
+		//  Typesetting program
+		static int typesettingProgram_;
+		static int typesettingProgramFormat_;
+		static char typesettingProgramInvokation_[MAX_PROGRAM_LENGTH];
+		static char typesettingOptions_[MAX_OPTIONS_LENGTH];
+
+		//  Preview program
+		static int previewProgram_;
+		static char previewProgramInvokation_[MAX_PROGRAM_LENGTH];
+		static char previewOptions_[MAX_OPTIONS_LENGTH];
+
+#endif
 
 		//  showStaffNrs_, showStaffNames_, showAuxLines_, showContext_ and showDrumToolbar_ are cached versions
 		//  kapp->config()->readBoolEntry(QString("ShowStaffNrs"), true),
@@ -474,7 +510,7 @@ class NResource : public QObject  {
 		static staff_props_str nullprops_;
 		static NKeySig *nullKeySig_;
 		static NClef *nullClef_;
-		static QList<NMainWindow> windowList_;
+		static QPtrList<NMainWindow> windowList_;
 		static NMidiMapper *mapper_;
 		static int lastWindowX_, lastWindowY_;
 		static NVoice *voiceWithSelectedRegion_;
@@ -486,7 +522,7 @@ class NResource : public QObject  {
 		static bool dontShowMupWarnings_;
 #if KDE_VERSION < 220
 		static int tipNo_;
-		static QList<QString> theTips_;
+		static QPtrList<QString> theTips_;
 		void loadTips(QString fname);
 #endif
 		static bool *staffSelMute_;
@@ -508,14 +544,14 @@ class NResource : public QObject  {
 
 		static int yPosOfOrchestralBar(int bar_xpos);
 		static void resetBarCkeckArray(int newYpos, bool clear);
-		static char *volume[];
-		static char *noteVal[];
-		static char *tripletVal[];
-		static char *instrTab[];
+		static const char *volume[];
+		static const char *noteVal[];
+		static const char *tripletVal[];
+		static const char *instrTab[];
 	private:
 		bool loadPixmaps(QPixmap **black_pixmap, QPixmap **red_pixmap, QString fname);
 		bool loadAlternativePixmap(QPixmap **grey_pixmap, QString fname, QString suffix);
-		QCursor *loadCursor(char *fname);
+		QCursor *loadCursor(const char *fname);
 		static QRegExp germanAE_;
 		static QRegExp germanOE_;
 		static QRegExp germanUE_;
