@@ -43,12 +43,12 @@ actualClef_(&(mainWidget->main_props_) , &staff_props_) {
 	voicelist_.setAutoDelete(true);
 	voicelist_.append(theFirstVoice_ = actualVoice_ = new NVoice(this, mainWidget, true));
 	actualVoiceNr_ = -1;
-	labelDrawPoint_ = QPoint(XLABEL_DIST, base - YLABEL_DIST);
 	yTop_ = base - ((LINE_OVERFLOW + 1) / 2) * LINE_DIST;
 	yBottom_ = base + (4 + (LINE_OVERFLOW + 1) / 2) * LINE_DIST;
 	yMid_ = yBottom_ + (yTop_ - yBottom_) / 2;
 	main_props_ = &(mainWidget->main_props_);
 	mainWidget_ = mainWidget;
+	labelDrawPoint_ = QPoint(main_props_->left_page_border + XLABEL_DIST, base - YLABEL_DIST);
 	staff_props_.base = base;
 	staff_props_.lyricsdist = DEFAULT_LYRICSDIST;
 	staff_props_.is_actual = false;
@@ -101,7 +101,14 @@ void NStaff::addVoices(int nvoices) {
 	}
 }
 
-void NStaff::updateVoiceList(QList<NVoice> *voicelist) {
+/* Move the voice numbered srcNr before the voice numbered tgtNr and becomes the actual voice */
+void NStaff::moveVoice(uint srcNr, uint tgtNr) {
+	voicelist_.insert(tgtNr, voicelist_.at(srcNr));
+	voicelist_.remove(srcNr+1);
+	actualVoice_ = voicelist_.at(tgtNr);
+}
+
+void NStaff::updateVoiceList(QPtrList<NVoice> *voicelist) {
 	NVoice *voice_elem;
 
 	for (voice_elem = voicelist_.first(); voice_elem; voice_elem = voicelist_.next()) {
@@ -224,7 +231,7 @@ void NStaff::startRepositioning() {
 	for (voice_elem = voicelist_.first(); voice_elem; voice_elem = voicelist_.next()) {
 		voice_elem->startRepositioning();
 	}
-	actualKeysig_.resetAtBar();
+	actualKeysig_.deleteTempAccents();
 }
 
 void NStaff::validateKeysig(int startidx, int insertpos) {
@@ -239,7 +246,7 @@ void NStaff::validateKeysig(int startidx, int insertpos) {
 }
 
 
-void NStaff::getElementsAfter(QList<NPositStr> *plist, int mytime, int *num_positions, int *min_time) {
+void NStaff::getElementsAfter(QPtrList<NPositStr> *plist, int mytime, int *num_positions, int *min_time) {
 	NPositStr *posit;
 	NVoice *voice_elem;
 	int i;
@@ -256,7 +263,7 @@ void NStaff::getElementsAfter(QList<NPositStr> *plist, int mytime, int *num_posi
 	}
 }
 
-bool NStaff::trimmRegionToWholeStaff(int *x0, int *x1) {
+bool NStaff::trimmRegionToWholeStaff(unsigned int *x0, unsigned int *x1) {
 	return voicelist_.first()->trimmRegionToWholeStaff(x0, x1);
 }
 
@@ -378,7 +385,7 @@ void NStaff::transpose(int semitones) {
 	}
 }
 
-void NStaff::setHalfsTo(int type) {
+void NStaff::setHalfsTo(property_type type) {
 	NVoice *voice_elem;
 
 	if (actualVoiceNr_ == -1) {
@@ -579,7 +586,7 @@ void NStaff::handleEnding1() {
 void NStaff::pasteAtPosition(int xpos, NStaff *from) {
 	NVoice *srcVoice, *destVoice;
 	bool complete = true;
-	QList<NMusElement> *clipboard;
+	QPtrList<NMusElement> *clipboard;
 	int countof128th, dest_time, part_in_measure;
 
 	if (actualVoiceNr_ == -1) {
@@ -596,8 +603,8 @@ void NStaff::pasteAtPosition(int xpos, NStaff *from) {
 			if (from->voiceCount() > voiceCount()) {
 				KMessageBox::sorry
 					(0,
-					 i18n("The destination staff has less voices than source staff"),
-					 kapp->makeStdCaption("paste")
+					 i18n("Unable to paste! The destination staff has less voices than the source staff."),
+					 kapp->makeStdCaption("Paste")
 					);
 				return;
 			}
@@ -619,10 +626,10 @@ void NStaff::pasteAtPosition(int xpos, NStaff *from) {
 		else {
 			srcVoice = from->getActualVoice(); 
 			if (!actualVoice_->isFirstVoice() && srcVoice->isFirstVoice()) {
-				KMessageBox::sorry
+				KMessageBox::information
 					(0,
-					 i18n("You paste a first voice to no-first voice! This deletes all non-first-voice elements!"),
-					 kapp->makeStdCaption("paste")
+					 i18n("You are going to copy elements from the first voice and paste them to the non-first voice!\nSpecial elements that can only be expressed in the first voice are not going to be copied!"),
+					 kapp->makeStdCaption("Paste")
 					);
 				complete = false;
 			}
@@ -653,6 +660,7 @@ void NStaff::draw(int left, int right) {
 	for (i = 0; i < 5; ++i) {
 		 main_props_->p->drawLine(main_props_->left_page_border, staff_props_.base + i * LINE_DIST, main_props_->left_page_border + nettoWidth_, staff_props_.base + i * LINE_DIST);
 	}
+
 	main_props_->p->end();
 	if (NResource::showStaffNames_ && !staffName_.isEmpty()) {
 		main_props_->p->beginUnclippedYtranslated();
@@ -699,10 +707,10 @@ void NStaff::correctPitchBecauseOfVa()
 	     elem;
 	     elem = voice_elem->getNextPosition()) {
 		if (elem->getType() != T_CHORD) continue;
-		switch (elem->va_ & 0x00030000) {
+		switch (elem->chord()->va_ & 0x00030000) {
 		case 0x00010000:
 			tstart = elem->midiTime_;
-			sign = (elem->va_ & 0x8000) ? -1 : 1;
+			sign = (elem->chord()->va_ & 0x8000) ? -1 : 1;
 			break;
 		case 0x00030000:
 			tend = elem->midiTime_ + elem->getMidiLength();
