@@ -37,10 +37,10 @@ class NStaff {
 	public:
 		NStaff(int base, int midi_channel, int voice, NMainFrameWidget *mainWidget);
 		~NStaff();
-		QList<NVoice> voicelist_;
+		QPtrList<NVoice> voicelist_;
 		void setBase(int base);
 		void paperDimensiones(int width);
-		int getBase() const {return staff_props_.base;}
+		unsigned int getBase() const {return staff_props_.base;}
 		void setActual(bool actual) {staff_props_.is_actual = actual;}
 		void changeVoice(int voice) {midiVoice_ = voice;}
 		int getVoice() const {return midiVoice_;}
@@ -49,10 +49,10 @@ class NStaff {
 		int determineMultiRest();
 		void setVolume(int vol) {midiVolume_ = vol;}
 		int getChannel() const {return midiChannel_;}
-		void getElementsAfter(QList<NPositStr> *plist, int mytime, int *num_positions, int *min_time);
+		void getElementsAfter(QPtrList<NPositStr> *plist, int mytime, int *num_positions, int *min_time);
 		int getWidth() {return width_;}
 		void validateKeysig(int startidx, int insertpos);
-		int voiceCount() {return voicelist_.count();}
+		unsigned int voiceCount() {return voicelist_.count();}
 		void startRepositioning();
 		void grabElements(NVoice *preferredVoice);
 		void grabElementsAccording();
@@ -68,9 +68,9 @@ class NStaff {
 		void drawContext();
 		QString staffName_;
 		int overlength_, underlength_;
-		bool trimmRegionToWholeStaff(int *x0, int *x1);
-		int checkElementForNoteInsertion(const int line, const QPoint p, int *state, int *state2, bool *playable, bool *delete_elem, bool *insertNewNote, int offs) {
-			return actualVoice_->checkElementForNoteInsertion(line, p, state, state2, playable, delete_elem, insertNewNote, offs); }
+		bool trimmRegionToWholeStaff(unsigned int *x0, unsigned int *x1);
+		int checkElementForNoteInsertion(const int line, const QPoint p, property_type *properties, bool *playable, bool *delete_elem, bool *insertNewNote, int offs) {
+			return actualVoice_->checkElementForNoteInsertion(line, p, properties, playable, delete_elem, insertNewNote, offs); }
 		bool checkElementForElementInsertion(const QPoint p) {
 			return actualVoice_->checkElementForElementInsertion(p); }
 		int findLineOf(int pitchNumber, int acYLine, int xpos);
@@ -90,8 +90,11 @@ class NStaff {
 		void setCorrectClefAccordingTime(int miditime) {
 			voicelist_.getFirst()->setCorrectClefAccordingTime(miditime);
 		}
+		void setCorrectKeySigAccordingTime(int miditime) {
+			voicelist_.getFirst()->setCorrectKeySigAccordingTime(miditime);
+		}
 		void transpose(int semitones);
-		void setHalfsTo(int type);
+		void setHalfsTo(property_type type);
 		void cleanupRests(int shortestRest);
 		void checkContext(int xpos) {theFirstVoice_->checkContext(xpos);}
 		void resetSpecialElement() {theFirstVoice_->resetSpecialElement();}
@@ -109,7 +112,8 @@ class NStaff {
 		void collChords();
 		void setHalfsAccordingKeySig();
 		void addVoices(int nvoices);
-		void updateVoiceList(QList<NVoice> *voicelist);
+		void moveVoice(uint srcNr, uint tgtNr); /* move the voice from number src to tgt */
+		void updateVoiceList(QPtrList<NVoice> *voicelist);
 		void setMuted(bool muted);
 		bool getMuted() {return actualVoice_->muted_;}
 		int deleteVoice(NVoice *oldVoice, VoiceDialog *voicedialog, staffPropFrm *staffPropForm);
