@@ -20,7 +20,7 @@
 /*											*/
 /****************************************************************************************/
 
-#include "config.h"
+#include "tse3handler.h"
 #ifdef WITH_TSE3
 #if GCC_MAJ_VERS > 2
 #include <fstream>
@@ -28,7 +28,6 @@
 #include <fstream.h>
 #endif
 #include <stdio.h>
-#include "tse3handler.h"
 #include <tse3/TSE3.h>
 #include <tse3/MidiFile.h>
 #include <tse3/TempoTrack.h>
@@ -45,7 +44,6 @@
 #include "uiconnect.h"
 #include "scaleedit_impl.h"
 #include "tempotrack.h"
-#include <config.h>
 #include <qtextview.h>
 #include <qslider.h>
 #include <kprogress.h>
@@ -71,10 +69,9 @@ static double TripletSnapVal_, TripletSnapVal_2_;
 static int TripletSnapInt_;
 static int TripletPart1_, TripletPart2_;
 static bool snapToTriplet_ = false;
-static QList<NMusElement> *tripletList_ = 0;
+static QPtrList<NMusElement> *tripletList_ = 0;
 #endif
 
-extern char *instrTab[];
 
 #ifdef WITH_TSE3
 
@@ -102,7 +99,7 @@ NTSE3Handler::~NTSE3Handler() {
 #define MYTIME2TSE3TIME(t) ((int) (double) (TSE3::Clock::PPQN) * (double) (t) / (double) (QUARTER_LENGTH))
 #define TSE3TIME2MYMIDITIME(t) ((int) ((double) (t) * (double) QUARTER_LENGTH / (double) (TSE3::Clock::PPQN)))
 
-void NTSE3Handler::createTSE3(QList<NVoice> *voices) {
+void NTSE3Handler::createTSE3(QPtrList<NVoice> *voices) {
 	NVoice *voice;
 	NSign *sign;
 	int i;
@@ -144,16 +141,17 @@ TSE3::Track *NTSE3Handler::createTSE3Track(NVoice *voice, int nr, TSE3::Song *so
 	char trackName[20];
 	unsigned int myTime, noteoff;
 	int deviceNumber = NResource::mapper_->getActualDeviceNumber();
-	QList<NMidiEventStr> stopList;
+	QPtrList<NMidiEventStr> stopList;
 	stopList.setAutoDelete(false);
 
 	thePhraseEditor.reset();
-	int sign = 0, kind;
+	int sign = 0;
+	property_type kind;
 
 	voice->getStaff()->startPlaying();  /* necessary to reset some member variables in all staffs (EndIdx_) */
 	actual_staff = voice->getStaff();
 	if (actual_staff->actualKeysig_.isRegular(&kind, &sign)) {
-		if (kind == STAT_FLAT) {
+		if (kind == PROP_FLAT) {
 			sign = -sign;
 		}
 	}
@@ -195,7 +193,7 @@ TSE3::Track *NTSE3Handler::createTSE3Track(NVoice *voice, int nr, TSE3::Song *so
 				if (m_events->ev_time <= m_evt->ev_time) {
 					noteoff = MYTIME2TSE3TIME(m_events->ev_time) - 1;
 					for (note = m_events->notelist->first(); note; note = m_events->notelist->next()) {
-					  if (!(note->status & STAT_TIED) || (m_evt->special & TRILL_SPECS)) {
+					  if (!(note->properties & PROP_TIED) || (m_evt->special & TRILL_SPECS)) {
 					    thePhraseEditor.insert(
 					        TSE3::MidiEvent( TSE3::MidiCommand(TSE3::MidiCommand_NoteOff,
 					           m_events->midi_channel, deviceNumber, note->midiPitch+m_events->trilloffs, 0), noteoff)
@@ -239,7 +237,7 @@ TSE3::Track *NTSE3Handler::createTSE3Track(NVoice *voice, int nr, TSE3::Song *so
 					}
 				}
 				for (i = 0, note = m_evt->notelist->first(); note; note = m_evt->notelist->next(), i++) {
-			   		if ((note->status & STAT_PART_OF_TIE) && !(m_evt->special & TRILL_SPECS)) {
+			   		if ((note->properties & PROP_PART_OF_TIE) && !(m_evt->special & TRILL_SPECS)) {
 						note->midiPitch = note->tie_backward->midiPitch; /* for note off */
 					}
 			   		else if (m_evt->special != SPEC_ARPEGGIO || i == m_evt->arpegg_current) {
@@ -281,7 +279,7 @@ TSE3::Track *NTSE3Handler::createTSE3Track(NVoice *voice, int nr, TSE3::Song *so
 	while (m_events) {
 		noteoff = MYTIME2TSE3TIME(m_events->ev_time) - 1;
 		for (note = m_events->notelist->first(); note; note = m_events->notelist->next()) {
-			if (!(note->status & STAT_TIED)) {
+			if (!(note->properties & PROP_TIED)) {
 				thePhraseEditor.insert(
 				        TSE3::MidiEvent( TSE3::MidiCommand(TSE3::MidiCommand_NoteOff,
 					           m_events->midi_channel, deviceNumber, note->midiPitch+m_events->trilloffs, 0), noteoff)
@@ -462,14 +460,17 @@ void NTSE3Handler::TSE3PhraseEditToStaff(TSE3::PhraseEdit *phraseEdit, NStaff *s
 	emit endRecorded(true);
 }
 
-bool  NTSE3Handler::TSE3record(int channel) {
+bool  NTSE3Handler::TSE3record(int channel, QPtrList<NVoice> *voices) {
 	if (theSong_ == 0) {
+#ifdef IS_NOT_SO_GOOG
 		KMessageBox::sorry
 			(0,
 			 i18n("First create a TSE3 song structure!"),
 			 kapp->makeStdCaption(i18n("Record AAAAAAAAAAAAAA")) //  FIXME: What should it say here?
 			);
 		return false;
+#endif
+		createTSE3(voices);
 	}
 	targetChannel_ = channel;
 	filterDialog_->show();
@@ -534,7 +535,7 @@ void NTSE3Handler::printSongInformation() {
 		items_[l]->setText( 2, QString( "%1" ).arg( staffsPerTrack_ ) );
 		for (j = 0; j < staffsPerTrack_; ++j) {
 			items_[l]->setText(3, i18n("Staff %1%2").arg(j < 9 ? " " : "").arg(j + 1));
-			items_[l]->setText(4, i18n(instrTab[TrackVoice_]));
+			items_[l]->setText(4, i18n(NResource::instrTab[TrackVoice_]));
 			items_[l]->setText(5, i18n("Channel %1").arg(staffInfo_[j].channel));
 			items_[l]->setText(6, i18n("Volume %1").arg( staffInfo_[j].volume));
 			items_[l]->setText(7, staffInfo_[j].clefType == BASS_CLEF ? i18n("bass") : i18n("treble"));
@@ -578,10 +579,10 @@ void NTSE3Handler::TSE3Merge() {
 	TSE3::Phrase *newPhrase;
 	TSE3::Clock maxtime, endtime;
 	TSE3::Part *newPart = new TSE3::Part(), *part;
-	QList<TSE3::Track> removeableTracks;
+	QPtrList<TSE3::Track> removeableTracks;
 	QString phraseTitle;
 
-	for (i = 0; i < theSong_->size(); ++i) {
+	for (z = 0, i = 0; i < theSong_->size(); ++i) {
 		if (NResource::staffSelMerge_[i]) z++;
 	}
 	if (z < 2) return;
@@ -614,7 +615,7 @@ void NTSE3Handler::TSE3Merge() {
 }
 		
 
-void NTSE3Handler::TSE3toScore(QList<NStaff> *staffs, QList<NVoice> *voices) {
+void NTSE3Handler::TSE3toScore(QPtrList<NStaff> *staffs, QPtrList<NVoice> *voices, bool keep) {
 	oldvoiceList_ = voices;
 	oldstaffList_ = staffs;
 	if (theSong_ == 0) {
@@ -622,25 +623,31 @@ void NTSE3Handler::TSE3toScore(QList<NStaff> *staffs, QList<NVoice> *voices) {
 		return;
 	}
 
-	multiStaff_->boot( 0, STAFF_ID_TRACK, theSong_->size() );
-	if( multiStaff_->abort_ ) return;
-	bool f = false;
-	for( int i = 0; i < theSong_->size(); ++i )
-	    f += NResource::staffSelTrack_[i];
-	if( !f ) {
-		KMessageBox::sorry
-			(0,
-			 i18n("No staff selected for import."),
-			 kapp->makeStdCaption(i18n("Import TSE3")));
-		return;
+	keep_ = keep;
+	if (keep_) {
+		multiStaff_->boot( 0, STAFF_ID_TRACK, theSong_->size() );
+		if( multiStaff_->abort_ ) return;
+		bool f = false;
+		for( int i = 0; i < theSong_->size(); ++i )
+		    f += NResource::staffSelTrack_[i];
+		if( !f ) {
+			KMessageBox::sorry
+				(0,
+				 i18n("No staff selected for import."),
+				 kapp->makeStdCaption(i18n("Import TSE3")));
+			return;
+		}
+	}
+	else {
+		NResource::staffSelTrack_ = new bool[theSong_->size()];  // dummy
 	}
 	TSE3::Track *tr;
 	TSE3::PlayableIterator *ttritr;
 	TSE3::PhraseEdit phraseEdit;
 	NStaff *staff;
 	NVoice *voice;
-	QList<NVoice> newVoices;
-	QList<NStaff> newStaffs;
+	QPtrList<NVoice> newVoices;
+	QPtrList<NStaff> newStaffs;
 	NSign *sign;
 	unsigned int i, j, k, l;
 	int noteCount;
@@ -687,14 +694,16 @@ void NTSE3Handler::TSE3toScore(QList<NStaff> *staffs, QList<NVoice> *voices) {
 		for (j = 0; j < staffsPerTrack_; ++j) {
 			staff = new NStaff(k*(NResource::overlength_+STAFF_HIGHT+NResource::underlength_)+NResource::overlength_, l, 0, mainWidget_);
 			trackInfoArray_[k] = i;
-			++k;
-			if (!TSE3Track2Staff(j, staff, tr)) {
-				NResource::progress_->hide();
-				emit endTSE3toScore(false);
-				delete [] NResource::staffSelTrack_;
-				NResource::staffSelTrack_ = 0;
-				return;
+			if (!keep_ || NResource::staffSelTrack_[trackInfoArray_[k]]) {
+				if (!TSE3Track2Staff(j, staff, tr)) {
+					NResource::progress_->hide();
+					emit endTSE3toScore(false);
+					delete [] NResource::staffSelTrack_;
+					NResource::staffSelTrack_ = 0;
+					return;
+				}
 			}
+			++k;
 			newStaffs.append(staff);
 			for (voice = staff->voicelist_.first(); voice; voice = staff->voicelist_.next()) {
 				newVoices.append(voice);
@@ -723,12 +732,29 @@ void NTSE3Handler::TSE3toScore(QList<NStaff> *staffs, QList<NVoice> *voices) {
 
 	delete ttritr;
 
-	oldstaffCount = oldstaffList_->count();
 	newStaffCount = newStaffs.count();
+	if (!keep) {
+		while (oldStaffElem = oldstaffList_->first()) {
+			oldStaffElem->updateVoiceList(oldvoiceList_);
+			delete oldStaffElem;
+			oldstaffList_->remove();
+		}
+		for (i = 0; i < newStaffCount; i++) {
+			newStaffElem = newStaffs.at(i);
+			oldstaffList_->append(newStaffElem);
+			j = newStaffElem->voiceCount();
+			for (k = 0; k < j; k++) {
+				oldvoiceList_->append(newStaffElem->getVoiceNr(k));
+			}
+		}
+		emit endTSE3toScore(true);
+		return;
+	}
+	oldstaffCount = oldstaffList_->count();
 	for (i = 0; i < newStaffCount; i++) {
 		newStaffElem = newStaffs.at(i);
-		if (NResource::staffSelTrack_[trackInfoArray_[i]]) {
-			if (i < oldstaffCount) {
+		if (i < oldstaffCount) {
+			if (NResource::staffSelTrack_[trackInfoArray_[i]]) {
 				oldStaffElem = oldstaffList_->at(i);
 				oldStaffElem->updateVoiceList(oldvoiceList_);
 				oldstaffList_->remove();
@@ -738,24 +764,25 @@ void NTSE3Handler::TSE3toScore(QList<NStaff> *staffs, QList<NVoice> *voices) {
 					oldvoiceList_->append(newStaffElem->getVoiceNr(k));
 				}
 			}
-			else {
-				oldstaffList_->append(newStaffElem);
-				j = newStaffElem->voiceCount();
-				for (k = 0; k < j; k++) {
-					oldvoiceList_->append(newStaffElem->getVoiceNr(k));
-				}
+		}
+		else {
+			oldstaffList_->append(newStaffElem);
+			j = newStaffElem->voiceCount();
+			for (k = 0; k < j; k++) {
+				oldvoiceList_->append(newStaffElem->getVoiceNr(k));
 			}
 		}
 	}
-	for (i = j  = newStaffCount; i < oldstaffCount; i++) {
-		oldStaffElem = oldstaffList_->at(j);
+	for (i = newStaffCount; i < oldstaffCount; i++) {
+		oldStaffElem = oldstaffList_->at(i);
+		if (!oldStaffElem) continue;
 		oldStaffElem->updateVoiceList(oldvoiceList_);
 		oldstaffList_->remove();
 	}
 	emit endTSE3toScore(true);
 }
 
-void NTSE3Handler::insertTimeAndKeySigs(QList<NStaff> *staffs) {
+void NTSE3Handler::insertTimeAndKeySigs(QPtrList<NStaff> *staffs) {
 	//TSE3::TimeSigTrackIterator *tmtritr;
 	TSE3::PlayableIterator *tmtritr;
 	//TSE3::KeySigTrackIterator *kstritr;
@@ -777,13 +804,13 @@ void NTSE3Handler::insertTimeAndKeySigs(QList<NStaff> *staffs) {
 		NResource::progress_->setValue((int) (readyPart + (double) (j+1) / partTime));
 		for (i = 0, staff = staffs->first(); staff; staff = staffs->next(), i++) {
 			voice = staff->getVoiceNr(0);
-			if (NResource::staffSelTrack_[trackInfoArray_[i]] && staff->getChannel() != DRUM_CHANNEL) {
+			if (!keep_ || NResource::staffSelTrack_[trackInfoArray_[i]] && staff->getChannel() != DRUM_CHANNEL) {
 				keysig = new NKeySig(voice->getMainPropsAddr(), voice->getStaff()->getStaffPropsAddr());
 				if ((*kstritr)->data.data2 & 0xf) {
-					keysig->setRegular(((*kstritr)->data.data2 & 0xf), STAT_FLAT);
+					keysig->setRegular(((*kstritr)->data.data2 & 0xf), PROP_FLAT);
 				}
 				else if ((*kstritr)->data.data2 & 0xf0) {
-					keysig->setRegular(((((*kstritr)->data.data2) >> 4)) & 0xf, STAT_CROSS);
+					keysig->setRegular(((((*kstritr)->data.data2) >> 4)) & 0xf, PROP_CROSS);
 				}
 				else continue;
 				voice->insertAtTime(TSE3TIME2MYMIDITIME((*kstritr)->time.pulses), keysig, true);
@@ -803,7 +830,7 @@ void NTSE3Handler::insertTimeAndKeySigs(QList<NStaff> *staffs) {
 		NResource::progress_->setValue((int) (readyPart + (double) (j+1) / partTime));
 		for (i = 0, staff = staffs->first(); staff; staff = staffs->next(), i++) {
 			voice = staff->getVoiceNr(0);
-			if (NResource::staffSelTrack_[trackInfoArray_[i]]) {
+			if (!keep_ || NResource::staffSelTrack_[trackInfoArray_[i]]) {
 				timesig = new NTimeSig(voice->getMainPropsAddr(), voice->getStaff()->getStaffPropsAddr());
 				timesig->setSignature((0xf & ((*tmtritr)->data.data2) >> 4), (0xf & ((*tmtritr)->data.data2)));
 				voice->insertAtTime(TSE3TIME2MYMIDITIME((*tmtritr)->time.pulses), timesig, true);
@@ -962,10 +989,12 @@ int NTSE3Handler::threwCase( int item ) {
 }
 
 
-void NTSE3Handler::TSE3Rec2Staff(NStaff *staff) {
+void NTSE3Handler::TSE3Rec2Staff(NStaff *staff, QPtrList<NVoice> *voice_list) {
 	int noteCount;
-	int n;
+	int n, i, nr_voices;
 	NVoice *voice;
+	QPtrList<NVoice> oldvoices;
+
 	if (recNum_ == 0) {
 		KMessageBox::sorry
 			(0,
@@ -1008,7 +1037,22 @@ void NTSE3Handler::TSE3Rec2Staff(NStaff *staff) {
 		emit endRecorded(false);
 		return;
 	}
+	nr_voices = staff->voiceCount();
+	for (i = 1; i < nr_voices; i++) {
+		oldvoices.append(staff->getVoiceNr(i));
+	}
 	TSE3Track2Staff(0, staff, recTrack_, false);
+	while (voice = oldvoices.first()) {
+		if (voice_list->find(voice) == -1) {
+			NResource::abort("NTSE3Handler::TSE3Track2Staff");
+		}
+		voice_list->remove();
+		oldvoices.remove();
+	}
+	nr_voices = staff->voiceCount();
+	for (i = 1; i < nr_voices; i++) {
+		voice_list->append(staff->getVoiceNr(i));
+	}
 	emit endRecorded(true);
 }
 
@@ -1040,20 +1084,57 @@ bool NTSE3Handler::TSE3Track2Staff(int nr, NStaff *staff, TSE3::Track *tr, bool
 	else {
 		staff->setVolume(actualVolume = staffInfo_[nr].volume);
 	}
-	return CreateTSE3StaffFromIterator(nr, staff, tri, actualVolume);
+	return CreateTSE3StaffFromIterator(nr, staff, tri, actualVolume, assignChannel);
+}
+
+int NTSE3Handler::minimalNote(int nr)  {
+	switch (nr) {
+		case  1: return WHOLE_LENGTH;
+		case  2: return HALF_LENGTH * 3 / 2;
+		case  3: return HALF_LENGTH;
+		case  4: return QUARTER_LENGTH * 3 / 2;
+		case  5: return QUARTER_LENGTH;
+		case  6: return NOTE8_LENGTH * 3 / 2;
+		case  7: return NOTE8_LENGTH;
+		case  8: return NOTE16_LENGTH * 3 / 2;
+		case  9: return NOTE16_LENGTH;
+		case 10: return NOTE32_LENGTH * 3 / 2;
+		case 11: return NOTE32_LENGTH;
+		case 12: return NOTE64_LENGTH;
+	}
+	return -1;
+}
+
+int NTSE3Handler::minimalTripletNote(int nr)  {
+	switch (nr) {
+		case 0: return -2;
+		case 1: return -1;
+		case 2: return HALF_LENGTH;
+		case 3: return QUARTER_LENGTH;
+		case 4: return NOTE8_LENGTH;
+		case 5: return NOTE16_LENGTH;
+	}
+	return -1;
 }
 	
-bool NTSE3Handler::CreateTSE3StaffFromIterator(int nr, NStaff *staff,  TSE3::PlayableIterator *tri, unsigned int actualVolume) {
+bool NTSE3Handler::CreateTSE3StaffFromIterator(int nr, NStaff *staff,  TSE3::PlayableIterator *tri, unsigned int actualVolume, bool assignChannel) {
 	TSE3::MidiEvent m_evt;
-	NMidiTimeScale mTimeScale;
+	TSE3::PlayableIterator *tmtritr;
+	NMidiTimeScale mTimeScale(minimalNote(filterDialog_->filSnapDist->currentItem()), minimalTripletNote(filterDialog_->filSmTripletNote->currentItem()));
 
+	tmtritr = theSong_->timeSigTrack()->iterator(TSE3::Clock(0));
+	while (tmtritr->more()) {
+		mTimeScale.insertTimeOfTimesig(TSE3TIME2MYMIDITIME((*tmtritr)->time.pulses));
+		++(*tmtritr);
+	}
+	delete tmtritr;
 	for (;tri->more(); ++(*tri)) {
 		m_evt = **tri;
 		mTimeScale.insertMidiEvent(&m_evt, staffInfo_[nr].minMidi, staffInfo_[nr].maxMidi);
 	}
 	delete tri;
 	mTimeScale.createStaff(staff, staffInfo_[nr].channel == DRUM_CHANNEL, filterDialog_->filVolDist->getValue(), filterDialog_->filAvVol->isChecked(), actualVolume, averageVolume_, filterDialog_->filVal1->getValue());
-	staff->changeVoice(mTimeScale.getMidiProgram());
+	if (assignChannel) staff->changeVoice(mTimeScale.getMidiProgram());
 	return true;
 }
 #endif
