@@ -27,9 +27,24 @@
 #include <qbuttongroup.h> 
 #include <qhbox.h>
 
+#ifndef WITH_SCONS
 #include "config.h"
+#endif
 #include "lines.h"
+#include "abcexportform.h"
+#include "lilypondexportform.h"
+#include "midiexportform.h"
+#include "musicxmlexportform.h"
+#include "musixtexexportform.h"
+#include "pmxexportform.h"
 #include "exports.h"
+#include "saveparametersform.h"
+#include "midiexport.h"
+#include "pmxexport.h"
+#include "abcexport.h"
+#include "lilyexport.h"
+#include "musicxmlexport.h"
+#include "musixtex.h"
 #include "scaleEd.h"
 #include "smRest.h"
 #include "volume.h"
@@ -59,7 +74,6 @@
 #define PMX_PAGE	3
 #define LILY_PAGE	4
 #define MUSICXML_PAGE	5
-#define PARAM_PAGE	6
 
 class NTSE3Handler;
 class noteSel;
@@ -71,6 +85,12 @@ class staffFrm;
 class QCheckListItem;
 class NMusElement;
 struct main_props_str;
+struct abc_options;
+struct lily_options;
+struct midi_options;
+struct musixtex_options;
+struct musicxml_options;
+struct pmx_options;
 
 class lineSelWg : public lineSel {
 
@@ -93,20 +113,54 @@ class exportFrm : public exportForm {
     public:
 	exportFrm( NMainFrameWidget *mainWidget, QWidget *parent = 0 );
 	~exportFrm();
-	void initialize( QList<NStaff> *stafflist, QList<NVoice> *voicelist, QString fname );
+	void initialize( QPtrList<NStaff> *stafflist, QPtrList<NVoice> *voicelist, QString fname );
 	void boot();
-	bool paramsEnabled();
-	void setEnabled(bool ok);
-	int getSaveWidth();
-	int getSaveHeight();
-	bool withMeasureNums();
-	void setWithMeasureNums(bool with);
-	void setSaveWidth(int width);
-	void setSaveHeight(int height);
-	
+	// Updating (Reading/Saving) predefined form export widgets
+	void getABCOptions(ABCExportForm &abcExportWidget, struct abc_options &abcOpts);
+	void setABCOptions(ABCExportForm &abcExportWidget, struct abc_options abcOpts);
+	void getLilyOptions(LilypondExportForm &lilyExportWidget, struct lily_options &lilyOpts);
+	void setLilyOptions(LilypondExportForm &lilyExportWidget, struct lily_options lilyOpts);
+	void getMidiOptions(MidiExportForm &midiExportWidget, struct midi_options &midiOpts);
+	void setMidiOptions(MidiExportForm &midiExportWidget, struct midi_options midiOpts);
+	void getMusiXTeXOptions(MusiXTeXExportForm &musixtexExportWidget, struct musixtex_options &musixtexOpts);
+	void setMusiXTeXOptions(MusiXTeXExportForm &musixtexExportWidget, struct musixtex_options musixtexOpts);
+	void getMusicXMLOptions(MusicXMLExportForm &musicxmlExportWidget, struct musicxml_options &musicxmlOpts);
+	void setMusicXMLOptions(MusicXMLExportForm &musicxmlExportWidget, struct musicxml_options musicxmlOpts);
+	void getPMXOptions(PMXExportForm &pmxExportWidget, struct pmx_options &pmxOpts);
+	void setPMXOptions(PMXExportForm &pmxExportWidget, struct pmx_options pmxOpts);
+	// Same as above for updating form export widgets from this class
+	inline void getABCOptions(struct abc_options &abcOpts)
+	{ getABCOptions(*abcExportWidget_, abcOpts); };
+	inline void setABCOptions(struct abc_options abcOpts)
+	{ setABCOptions(*abcExportWidget_, abcOpts); };
+	inline void getLilyOptions(struct lily_options &lilyOpts)
+	{ getLilyOptions(*lilyExportWidget_, lilyOpts); };
+	inline void setLilyOptions(struct lily_options lilyOpts)
+	{ setLilyOptions(*lilyExportWidget_, lilyOpts); };
+	inline void getMidiOptions(struct midi_options &midiOpts)
+	{ getMidiOptions(*midiExportWidget_, midiOpts); };
+	inline void setMidiOptions(struct midi_options midiOpts)
+	{ setMidiOptions(*midiExportWidget_, midiOpts); };
+	inline void getMusiXTeXOptions(struct musixtex_options &musixtexOpts)
+	{ getMusiXTeXOptions(*musixtexExportWidget_, musixtexOpts); };
+	inline void setMusiXTeXOptions(struct musixtex_options musixtexOpts)
+	{ setMusiXTeXOptions(*musixtexExportWidget_, musixtexOpts); };
+	inline void getMusicXMLOptions(struct musicxml_options &musicxmlOpts)
+	{ getMusicXMLOptions(*musicxmlExportWidget_, musicxmlOpts); };
+	inline void setMusicXMLOptions(struct musicxml_options musicxmlOpts)
+	{ setMusicXMLOptions(*musicxmlExportWidget_, musicxmlOpts); };
+	inline void getPMXOptions(struct pmx_options &pmxOpts)
+	{ getPMXOptions(*pmxExportWidget_, pmxOpts); };
+	inline void setPMXOptions(struct pmx_options pmxOpts)
+	{ setPMXOptions(*pmxExportWidget_, pmxOpts); };
+	void doExport(int type, QString fileName,  bool bSMsg = true);
+
+    public slots:	
+	void showExportForm( int );
+
     private slots:
-	void closeIt();
 	void startExport();
+	void closeIt();
 	void texMeasures();
 	void musixStaffSig();
 	void pmxStaffSig();
@@ -116,22 +170,48 @@ class exportFrm : public exportForm {
 	void lilyLandSlot();
 	void lilyStaffSig();
 	void abcLandSlot();
-	void paramLandSlot();
 	
     private:
-	QList<NStaff> *staffList_;
-	QList<NVoice> *voiceList_;
+	QPtrList<NStaff> *staffList_;
+	QPtrList<NVoice> *voiceList_;
 	QString sourceFile_;
 	staffFrm *staffDialog_;
 	NMainFrameWidget *mainWidget_;
+	ABCExportForm *abcExportWidget_;
+	LilypondExportForm *lilyExportWidget_;
+	MidiExportForm *midiExportWidget_;
+	MusiXTeXExportForm *musixtexExportWidget_;
+	MusicXMLExportForm *musicxmlExportWidget_;
+	PMXExportForm *pmxExportWidget_;
+	int iCurrentPage_;
+    };
 
-    };    
+class saveParametersFrm : public SaveParametersForm
+{
+    public:
+	saveParametersFrm( NMainFrameWidget *mainWidget, QWidget *parent = 0 );
+	int getSaveWidth();
+	int getSaveHeight();
+	void setSaveWidth(int width);
+	void setSaveHeight(int height);
+	bool paramsEnabled();
+	void setEnabled(bool ok);
+	bool withMeasureNums();
+	void setWithMeasureNums(bool with);
+
+    private slots:
+	void paramLandSlot();
+	void closeIt();
+
+    private:
+	NMainFrameWidget *mainWidget_;
+};
 
 class scaleFrm : public scaleForm {
 
     public:
 	scaleFrm( QWidget *parent );
-	void boot( QList<NStaff> *staffList_, QScrollBar *scrollx_  );
+	void boot( QPtrList<NStaff> *staffList_, QScrollBar *scrollx_  );
 	bool boot( main_props_str *props_str_, NStaff *currentStaff_, NVoice *currentVoice, NMusElement **tmpElem_, int subtype );
 	int boot();
 	
@@ -214,7 +294,7 @@ class listFrm : public listForm {
 
     public:
 	listFrm( QWidget *parent );
-	bool boot( int val, short int type, const QString & caption, const QString & title, QList<NStaff> *staff = 0 );
+	bool boot( int val, short int type, const QString & caption, const QString & title, QPtrList<NStaff> *staff = 0 );
 	
     private slots:
 	void okSlot();
@@ -289,7 +369,7 @@ class staffFrm : public staffForm {
 
     public:
 	staffFrm( QWidget *parent );
-	void boot( QList<NStaff> *stafflist, char unsigned id, int amount = 0 );
+	void boot( QPtrList<NStaff> *stafflist, char unsigned id, int amount = 0 );
 
     private slots:
 	void slCh();
@@ -372,7 +452,7 @@ class staffelFrm : public staffelForm {
 	staffelFrm( NMainFrameWidget *mainWidget );
 	int boot( unsigned char type );
 
-    private slots:
+    public slots:
 	void slOk();
 	void slCh();
 
