@@ -55,7 +55,7 @@ class NPositStr {
 
 class undostr {
 	public:
-		QList<NMusElement> *backup_area;
+		QPtrList<NMusElement> *backup_area;
 		int first_replaced_item;
 		int num_of_replaced_items;
 		NVoice *ref;
@@ -104,7 +104,7 @@ class NVoice {
 		void setHalfsAccordingKeySig(bool withUndo);
 		void setHalfsTo(int type, bool region);
 		void emptyVoice();
-		void getChordDiagramms(QList<chordDiagramName> *cdiagList, bool *gridsused, bool firstcall, bool *gridproblem);
+		void getChordDiagramms(QPtrList<chordDiagramName> *cdiagList, bool *gridsused, bool firstcall, bool *gridproblem);
 		int getMidiEndTime() {return midiEndTime_;}
 		bool isLast () {return musElementList_.current() == musElementList_.getLast();}
 		bool isLastElem(NMusElement *elem) {return elem == musElementList_.getLast();}
@@ -127,23 +127,24 @@ class NVoice {
 		bool voiceSet_;
 		int yRestOffs_;
 /*--------------------------------- search for something in voice ----------------------------- */
-		int checkElementForNoteInsertion(const int line, const QPoint p, int *state, int *state2, bool *playable, bool *delete_elem, bool *insertNewNote, int offs);
+		int checkElementForNoteInsertion(const int line, const QPoint p, property_type *properties, bool *playable, bool *delete_elem, bool *insertNewNote, int offs);
 		bool checkElementForElementInsertion(const QPoint p);
 		bool deleteActualNote();
-		int getElemState(int *state, int *state2, bool *playable);
+		int getElemState(property_type *properties, bool *playable);
 		void grabElements();
 		void findAppropriateElems();
-		void trimmRegion(int *x0, int *x1);
-		bool trimmRegionToWholeStaff(int *x0, int *x1);
+		void trimmRegion(unsigned int *x0, unsigned int *x1);
+		bool trimmRegionToWholeStaff(unsigned int *x0, unsigned int *x1);
 		void deleteBlock();
 		void findStartElemAt(int x0, int x1);
-		bool wholeTupletDeleted(NMusElement *ac_elem, int posOfFirst, int posOfLast);
+		bool wholeTupletDeleted(NPlayable *ac_elem, int posOfFirst, int posOfLast);
 		bool wholeBeamDeleted(NChord *ac_elem, int posOfFirst, int posOfLast);
-		void pasteAtMidiTime(int dest_time, int part_in_measure, int countof128th, QList<NMusElement> *clipboard);
-		void pasteAtPosition(int xpos, QList<NMusElement> *clipboard, bool complete, int *part_in_current_measure, int *dest_midi_time, int *countof128th);
-		void pasteAtIndex(QList<NMusElement> *clipBoard, int idx);
-		QList<NMusElement> *getClipBoard() {return &clipBoard_;}
+		void pasteAtMidiTime(int dest_time, int part_in_measure, int countof128th, QPtrList<NMusElement> *clipboard);
+		void pasteAtPosition(int xpos, QPtrList<NMusElement> *clipboard, bool complete, int *part_in_current_measure, int *dest_midi_time, int *countof128th);
+		void pasteAtIndex(QPtrList<NMusElement> *clipBoard, int idx);
+		QPtrList<NMusElement> *getClipBoard() {return &clipBoard_;}
 		int getBarsymTimeBefore(int till_meascount, int miditime);
+		NMusElement *getNearestMidiEvent(int MidiTime, bool nearestRight = false);
 		int computeSlurDist(NChord *chord);
 		int findTimeOfTrillEnd(NChord *chord, int *destmestime, int *mescount);
 		int findTimeOfSlurEnd(NChord *chord, int *destmestime, int *mescount);
@@ -160,6 +161,7 @@ class NVoice {
 		int validateKeysig(int lastbaridx, int insertpos);
 		void validateKeysigAccordingPos(int lastbarstartpos, int insertpos);
 		void setCorrectClefAccordingTime(int miditime);
+		void setCorrectKeySigAccordingTime(int miditime);
 /*--------------------- changes due to user interaction ------------------------------------*/
 		void release();
 		void makeKeysigAndClefActual();
@@ -167,8 +169,8 @@ class NVoice {
 		void moveDown(int down);
 		void moveSemiToneUp();
 		void moveSemiToneDown();
-		int makePreviousElementActual(int *state, int *state2);
-		int makeNextElementActual(int *state, int *state2);
+		int makePreviousElementActual(property_type *properties);
+		int makeNextElementActual(property_type *properties);
 		void changeActualChord();
 		void changeBodyOfActualElement();
 		void changeActualStem();
@@ -178,11 +180,12 @@ class NVoice {
 		void breakBeames();
 		void breakTuplet();
 		void breakCopiedTuplets();
-		bool checkTuplets(QList<NMusElement> *copielist, QList<NMusElement> *tupletlist);
-		bool lastChordContained(QList<NMusElement> *clonelist, QList<NChord> *beamlist);
-		bool lastElemContained(QList<NMusElement> *clonelist, QList<NMusElement> *tupletlist);
-		bool allElemsContained(QList<NMusElement> *clonelist, QList<NMusElement> *tupletlist);
+		bool checkTuplets(QPtrList<NMusElement> *copielist, QPtrList<NPlayable> *tupletlist);
+		bool lastChordContained(QPtrList<NMusElement> *clonelist, QPtrList<NChord> *beamlist);
+		bool lastElemContained(QPtrList<NMusElement> *clonelist, QPtrList<NPlayable> *tupletlist);
+		bool allElemsContained(QPtrList<NMusElement> *clonelist, QPtrList<NPlayable> *tupletlist);
 		void setActualTied();
+		void setHidden(); /* toggle hidden rest */
 		void setArpeggio();
 		void setPedalOn();
 		void setPedalOff();
@@ -190,7 +193,7 @@ class NVoice {
 		void resetSlured();
 		void setBeamed();
 		void setTuplet(char numNotes, char playtime);
-		int deleteActualElem(int *state, int *state2, bool backspace);
+		int deleteActualElem(property_type *properties, bool backspace);
 		bool deleteAtPosition(int y);
 		void autoBar();
 		void autoBarVoice123andSoOn();
@@ -205,7 +208,7 @@ class NVoice {
 		void insertAtPosition(int el_type, int xpos, int line, int sub_type, int offs, NMusElement *tmpElem = 0);
 		bool insertNewNoteAt(int line, const QPoint p, int offs);
 		bool insertNewNoteAtCurrent(int line, int offs);
-		void insertAfterCurrent(int el_type, int subtype);
+		NMusElement *insertAfterCurrent(int el_type, int subtype);
 		bool insertAfterCurrent(NMusElement *elem);
 		void insertBarAt(int xpos);
 /*------------------------ playing voice -------------------------------------*/
@@ -267,11 +270,12 @@ class NVoice {
 		NClef *getFirstClef();
 		NTimeSig *getFirstTimeSig();
 		NKeySig *getFirstKeysig();
-		QString determineGraceKind(int *status);
+		QString determineGraceKind(property_type *properties);
 		NMusElement *getCurrentPosition();
 		NMusElement *getNextPosition();
 		NMusElement *getPrevPosition();
 		NMusElement *getCurrentElement() {return currentElement_;}
+		bool setCurrentElement(NMusElement *elt);
 		bool firstVolume_;
 		bool inBeam_, inTuplet_;
 /*--------------------------- import MusicXML --------------------------------*/
@@ -284,15 +288,15 @@ class NVoice {
 		NChord *findLastChordBetweenXpos(int xpos1, int xpos2);
 		int getVaAtXpos(int xpos);
 /*--------------------------- appending due to reading ---------------------------*/
-		void appendNoteAt(int line, int offs, unsigned int status);
-		void appendElem(int el_type, int line, int sub_type, int offs = 0, unsigned int status = 0);
+		void appendNoteAt(int line, int offs, property_type properties);
+		void appendElem(int el_type, int line, int sub_type, int offs = 0, property_type properties = 0);
 		void appendElem(NMusElement *elem);
 		void correctReadTrillsSlursAndDynamicsStringsAndVAs();
 		bool setProvisionalTrill(int kind, unsigned int at, unsigned int till_meascount, unsigned int till, NMusElement *last_bar_sym);
 		bool setProvisionalDynamic(int kind, unsigned int at, unsigned int till_meascount, unsigned int till, NMusElement *last_bar_sym);
 		bool setProvisionalSlur(unsigned int at, unsigned int till_meascount, unsigned int till, NMusElement *last_bar_sym);
 		bool setProvisionalOctaviation(int kind, unsigned int at, unsigned int till_meascount, unsigned int till, NMusElement *last_bar_sym);
-		void setProvisionalString(char *text, int type, unsigned int at, NMusElement *last_bar_sym);
+		void setProvisionalString(QString text, int type, unsigned int at, NMusElement *last_bar_sym);
 		bool setReadArpeggio(unsigned int at, NMusElement *last_bar_sym);
 		bool setReadPedalOn(unsigned int at, NMusElement *last_bar_sym);
 		bool setReadPedalOff(unsigned int at, NMusElement *last_bar_sym);
@@ -305,10 +309,10 @@ class NVoice {
 		void insertAtTime(unsigned int time, NMusElement *elem, bool splitRests = false);
 		void handleEndAfterMidiImport(int difftime);
 		bool insertElemAtTime(unsigned int at, NSign *sign, NMusElement *last_bar_sym);
-		void addLyrics(char *charlyrics, int verse);
+		void addLyrics(const char *charlyrics, int verse);
 		void copyLyricsToEditor();
 		void collChords();
-		QList<NText> provStrings_;
+		QPtrList<NText> provStrings_;
 /*------------------------------ Lyrics -------------------------------------------*/
 		void updateLyrics();
 		int countOfLyricsLines();
@@ -320,14 +324,15 @@ class NVoice {
 		void performClefChange(int type, int shift, bool region, int *dist, int *stop_x);
 /* ------------------------------- MuxiXTeX-Export (notice) ------------------------------*/
 		NMusElement *getLast() {return musElementList_.getLast();}
+		NMusElement *getFirst() {return musElementList_.getFirst();}
 		int beamCount_;
 		int beamNr_;
 	private: 
 /*------------------------------ voice properies -----------------------------------------*/
 		bool	firstVoice_;
-		QList<NMusElement> musElementList_;
-		NMusElement *currentElement_;			// the selected element (drawn in red)
-								// if no element is selected, then 0
+		QPtrList<NMusElement> musElementList_;
+		NMusElement *currentElement_;			// the actual element (drawn in red)
+		                             			// if no element is selected, then 0
 		NMusElement *specialElement_;
 		NStaff  *theStaff_;
 /*-------------------------------- drawing voice ----------------------------------------------*/
@@ -354,11 +359,11 @@ class NVoice {
 		void combineChords(int firstIdx, int lastIdx);
 
 /*----------------------- dealing with beams -------------------------------------*/
-		void reconnectBeames();
-		bool beameEndRequired(QList<NChord> *beamlist_so_far, NTimeSig *timesig, int beats);
+		void reconnectBeames(uint neededNumber = 0);
+		bool beameEndRequired(QPtrList<NChord> *beamlist_so_far, NTimeSig *timesig, int beats);
 /*----------------------- dealing with tuplets -------------------------------------*/
 		void reconnectTuplets();
-		bool buildTupletList(int x0, int x1, char numNotes, QList<NMusElement> *elemlist);
+		bool buildTupletList(int x0, int x1, char numNotes, QPtrList<NPlayable> *elemlist);
 		void tryToBuildAutoTriplet();
 /*----------------------- search -------------------------------------*/
 		int searchPositionAndUpdateSigns(int dest_xpos, NMusElement **elem, bool *found, NMusElement **elem_before = 0, 
@@ -371,7 +376,7 @@ class NVoice {
 		int savePosition_;
 		int midiEndTime_;
 		NPositStr *pPtr_;
-		QList<NNote> virtualChord_;
+		QPtrList<NNote> virtualChord_;
 /*--------------------------- bar numbering -------------------------------------*/
 		int barNr_;
 /*---------------------------------- undo ---------------------------------------*/
@@ -390,9 +395,9 @@ class NVoice {
 
 		QRegExp wordPattern1_, wordPattern2_, escapedApostroph_;
 		main_props_str *main_props_;
-		QList<NMusElement> clipBoard_;
-		void eliminateRests(QList<NMusElement> *foundRests, int restSum, int over, NChord *lastChord);
-		void collectAndInsertPlayable(int startTime, QList<NMusElement> *patterns, int targetLength,
+		QPtrList<NMusElement> clipBoard_;
+		void eliminateRests(QPtrList<NMusElement> *foundRests, int restSum, int over, NChord *lastChord);
+		void collectAndInsertPlayable(int startTime, QPtrList<NMusElement> *patterns, int targetLength,
 			bool useExistingElement,
 			bool beforeBarSig = false );	// if true: first the short note, then the long one
 		static undostr undoelem_[MAXUNDO];
@@ -411,8 +416,8 @@ class NVoice {
 		void deleteLastUndo();
 		void invalidateReUndo(bool with_undo = false);
 		void setCountOfAddedItems(int count_of_added_items);
-		void freeCloneGroup(QList<NMusElement> *group);
-		QList<NMusElement> *cloneGroup(int firstidx, int lastidx);
+		void freeCloneGroup(QPtrList<NMusElement> *group);
+		QPtrList<NMusElement> *cloneGroup(int firstidx, int lastidx);
 };
 
 #endif // VOICE_H
